@@ -27,27 +27,25 @@
 
 #include <config.h>
 #include "nautilus-adapter.h"
-#include "nautilus-adapter-load-strategy.h"
-#include "nautilus-adapter-embed-strategy.h"
-#include "nautilus-adapter-embed-strategy-private.h"
 
+#include "nautilus-adapter-embed-strategy-private.h"
+#include "nautilus-adapter-embed-strategy.h"
+#include "nautilus-adapter-load-strategy.h"
 #include <bonobo/bonobo-control.h>
 #include <bonobo/bonobo-item-container.h>
-#include <bonobo/bonobo-view-frame.h>
-#include <bonobo/bonobo-object-client.h>
-#include <gtk/gtksignal.h>
+#include <eel/eel-generous-bin.h>
+#include <eel/eel-gtk-macros.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gtk/gtksignal.h>
 #include <libgnome/gnome-i18n.h>
-#include <libgnomeui/gnome-stock.h>
-#include <libnautilus/nautilus-bonobo-ui.h>
-#include <libnautilus-extensions/nautilus-gtk-macros.h>
-#include <libnautilus-extensions/nautilus-generous-bin.h>
+#include <libgnomeui/gnome-stock-icons.h>
 #include <libnautilus-adapter/nautilus-adapter-factory.h>
+#include <libnautilus/nautilus-bonobo-ui.h>
 
 struct NautilusAdapterDetails {
-	NautilusView                 *nautilus_view;
+	NautilusView *nautilus_view;
 	NautilusAdapterEmbedStrategy *embed_strategy;
-	NautilusAdapterLoadStrategy  *load_strategy;
+	NautilusAdapterLoadStrategy *load_strategy;
 	guint report_load_underway_id;
 	guint report_load_progress_id;
 	guint report_load_complete_id;
@@ -55,61 +53,48 @@ struct NautilusAdapterDetails {
 };
 
 
-static void nautilus_adapter_load_location_callback (NautilusView    *view,
-						     const char      *uri,
-						     NautilusAdapter *adapter);
-static void nautilus_adapter_stop_loading_callback  (NautilusView    *view,
-						     NautilusAdapter *adapter);
-
-static void nautilus_adapter_activate_callback      (BonoboControl   *control,
-						     gboolean         state,
-						     NautilusAdapter *adapter);
+static void nautilus_adapter_load_location_callback (NautilusView                 *view,
+						     const char                   *uri,
+						     NautilusAdapter              *adapter);
+static void nautilus_adapter_stop_loading_callback  (NautilusView                 *view,
+						     NautilusAdapter              *adapter);
+static void nautilus_adapter_activate_callback      (BonoboControl                *control,
+						     gboolean                      state,
+						     NautilusAdapter              *adapter);
 static void nautilus_adapter_open_location_callback (NautilusAdapterEmbedStrategy *strategy,
 						     const char                   *uri,
 						     NautilusAdapter              *adapter);
-
-static void nautilus_adapter_load_underway_callback (NautilusAdapter             *adapter);
-static void nautilus_adapter_load_progress_callback (NautilusAdapter             *adapter,
-						     double                       fraction_complete);
-static void nautilus_adapter_load_complete_callback (NautilusAdapter             *adapter);
-static void nautilus_adapter_load_failed_callback   (NautilusAdapter             *adapter);
+static void nautilus_adapter_load_underway_callback (NautilusAdapter              *adapter);
+static void nautilus_adapter_load_progress_callback (NautilusAdapter              *adapter,
+						     double                        fraction_complete);
+static void nautilus_adapter_load_complete_callback (NautilusAdapter              *adapter);
+static void nautilus_adapter_load_failed_callback   (NautilusAdapter              *adapter);
+static void nautilus_adapter_class_init       (NautilusAdapterClass         *klass);
+static void nautilus_adapter_init             (NautilusAdapter              *server);
+static void nautilus_adapter_destroy                (GtkObject                    *object);
 
 
-
-static void nautilus_adapter_initialize_class (NautilusAdapterClass *klass);
-static void nautilus_adapter_initialize       (NautilusAdapter      *server);
-static void nautilus_adapter_destroy          (GtkObject                      *object);
-
-
-NAUTILUS_DEFINE_CLASS_BOILERPLATE (NautilusAdapter,
-				   nautilus_adapter,
-				   GTK_TYPE_OBJECT)
+EEL_CLASS_BOILERPLATE (NautilusAdapter,
+			      nautilus_adapter,
+			      GTK_TYPE_OBJECT)
 
      
 static void
-nautilus_adapter_initialize_class (NautilusAdapterClass *klass)
+nautilus_adapter_class_init (NautilusAdapterClass *klass)
 {
 	GtkObjectClass *object_class;
 	
-	g_assert (NAUTILUS_IS_ADAPTER_CLASS (klass));
-
 	object_class = GTK_OBJECT_CLASS (klass);
 	
 	object_class->destroy = nautilus_adapter_destroy;
 }
 
 static void
-nautilus_adapter_initialize (NautilusAdapter *adapter)
+nautilus_adapter_init (NautilusAdapter *adapter)
 {
-	CORBA_Environment ev;
-
-	CORBA_exception_init (&ev);
-	
-	g_assert (NAUTILUS_IS_ADAPTER (adapter));
-
 	adapter->details = g_new0 (NautilusAdapterDetails, 1);
-	
-	CORBA_exception_free (&ev);
+	g_object_ref (adapter);
+	gtk_object_sink (GTK_OBJECT (adapter));
 }
 
 static void
@@ -134,16 +119,16 @@ nautilus_adapter_destroy (GtkObject *object)
 
 	if (adapter->details->load_strategy != NULL) {
 		nautilus_adapter_load_strategy_stop_loading (adapter->details->load_strategy);
-		gtk_object_unref (GTK_OBJECT (adapter->details->load_strategy));
+		g_object_unref (adapter->details->load_strategy);
 	}
 
 	if (adapter->details->embed_strategy != NULL) {
-		gtk_object_unref (GTK_OBJECT (adapter->details->embed_strategy));
+		g_object_unref (adapter->details->embed_strategy);
 	}
 
 	g_free (adapter->details);
 	
-	NAUTILUS_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
 }
 
 NautilusAdapter *
@@ -153,36 +138,26 @@ nautilus_adapter_new (Bonobo_Unknown component)
 	BonoboControl        *control;
 	GtkWidget            *bin;
 	BonoboObject         *zoomable;
-	CORBA_Environment     ev;
 
-
-	/* FIXME bugzilla.eazel.com 4405: should be done with
+	/* FIXME bugzilla.gnome.org 44405: should be done with
 	 * construct args 
 	 */
 
-	CORBA_exception_init (&ev);
-
-	adapter = NAUTILUS_ADAPTER (gtk_object_new (NAUTILUS_TYPE_ADAPTER, NULL));
-
+	adapter = NAUTILUS_ADAPTER (g_object_new (NAUTILUS_TYPE_ADAPTER, NULL));
 
 	/* Set up a few wrapper framework details */
-	bin =  gtk_widget_new (NAUTILUS_TYPE_GENEROUS_BIN, NULL);
+	bin = gtk_widget_new (EEL_TYPE_GENEROUS_BIN, NULL);
 	gtk_widget_show (bin);
 	control = bonobo_control_new (bin);
 	adapter->details->nautilus_view = nautilus_view_new_from_bonobo_control (control);
 
-	gtk_signal_connect_object (GTK_OBJECT (adapter->details->nautilus_view),
-				   "destroy",
-				   gtk_object_unref,
-				   GTK_OBJECT (adapter));
+	g_object_weak_ref (G_OBJECT (adapter->details->nautilus_view),
+			   (GWeakNotify)g_object_unref, adapter);
 
 	/* Get the class to handle embedding this kind of component. */
-	adapter->details->embed_strategy = nautilus_adapter_embed_strategy_get
-		(component);
-
+	adapter->details->embed_strategy = nautilus_adapter_embed_strategy_get (component);
 	if (adapter->details->embed_strategy == NULL) {
-		gtk_object_unref (GTK_OBJECT (adapter));
-		
+		g_object_unref (adapter);
 		return NULL;
 	}
 
@@ -191,77 +166,67 @@ nautilus_adapter_new (Bonobo_Unknown component)
 	if (zoomable != NULL)
 		bonobo_object_add_interface (BONOBO_OBJECT (control), zoomable);
 
-	gtk_signal_connect (GTK_OBJECT (control), "activate",
-			    GTK_SIGNAL_FUNC (nautilus_adapter_activate_callback),
-			    adapter);
+	g_signal_connect (control, "activate",
+			  G_CALLBACK (nautilus_adapter_activate_callback),
+			  adapter);
 
-	gtk_signal_connect (GTK_OBJECT (adapter->details->embed_strategy), "open_location", 
-			    nautilus_adapter_open_location_callback, adapter);
+	g_signal_connect (adapter->details->embed_strategy, "open_location", 
+			  G_CALLBACK (nautilus_adapter_open_location_callback),
+			  adapter);
 
 
 	/* Get the class to handle loading this kind of component. */
-
-	adapter->details->load_strategy = nautilus_adapter_load_strategy_get
-		(component);
-
+	adapter->details->load_strategy = nautilus_adapter_load_strategy_get (component);
 	if (adapter->details->load_strategy == NULL) {
-		gtk_object_unref (GTK_OBJECT (adapter));
-		
+		g_object_unref (adapter);
 		return NULL;
 	}
 
 	/* hook up load strategy signals */
 	adapter->details->report_load_underway_id =
-		gtk_signal_connect_object (GTK_OBJECT (adapter->details->load_strategy),
-					   "report_load_underway",
-					   nautilus_adapter_load_underway_callback,
-					   GTK_OBJECT (adapter));
+		g_signal_connect_swapped (GTK_OBJECT (adapter->details->load_strategy),
+					  "report_load_underway",
+					  G_CALLBACK (nautilus_adapter_load_underway_callback),
+					  GTK_OBJECT (adapter));
 	adapter->details->report_load_progress_id =
-		gtk_signal_connect_object (GTK_OBJECT (adapter->details->load_strategy),
-					   "report_load_progress",
-					   nautilus_adapter_load_progress_callback,
-					   GTK_OBJECT (adapter));
+		g_signal_connect_swapped (GTK_OBJECT (adapter->details->load_strategy),
+					  "report_load_progress",
+					  G_CALLBACK (nautilus_adapter_load_progress_callback),
+					  GTK_OBJECT (adapter));
 	adapter->details->report_load_complete_id =
-		gtk_signal_connect_object (GTK_OBJECT (adapter->details->load_strategy),
-					   "report_load_complete",
-					   nautilus_adapter_load_complete_callback,
-					   GTK_OBJECT (adapter));
+		g_signal_connect_swapped (GTK_OBJECT (adapter->details->load_strategy),
+					  "report_load_complete",
+					  G_CALLBACK (nautilus_adapter_load_complete_callback),
+					  GTK_OBJECT (adapter));
 	adapter->details->report_load_failed_id =
-		gtk_signal_connect_object (GTK_OBJECT (adapter->details->load_strategy),
-					   "report_load_failed",
-					   nautilus_adapter_load_failed_callback,
-					   GTK_OBJECT (adapter));
+		g_signal_connect_swapped (GTK_OBJECT (adapter->details->load_strategy),
+					  "report_load_failed",
+					  G_CALLBACK (nautilus_adapter_load_failed_callback),
+					  GTK_OBJECT (adapter));
 
 	/* complete the embedding */
-
 	gtk_container_add (GTK_CONTAINER (bin), 
 			   nautilus_adapter_embed_strategy_get_widget (adapter->details->embed_strategy));
-
 			   
 	/* hook up view signals. */
-
-	gtk_signal_connect (GTK_OBJECT (adapter->details->nautilus_view),
-			    "load_location",
-			    nautilus_adapter_load_location_callback,
-			    adapter);
-
-	gtk_signal_connect (GTK_OBJECT (adapter->details->nautilus_view),
-			    "stop_loading",
-			    nautilus_adapter_stop_loading_callback,
-			    adapter);
+	g_signal_connect (adapter->details->nautilus_view,
+			  "load_location",
+			  G_CALLBACK (nautilus_adapter_load_location_callback),
+			  adapter);
+	g_signal_connect (adapter->details->nautilus_view,
+			  "stop_loading",
+			  G_CALLBACK (nautilus_adapter_stop_loading_callback),
+			  adapter);
 
 	return adapter;
 }
 
-
 NautilusView *
 nautilus_adapter_get_nautilus_view (NautilusAdapter *adapter) 
 {
 	return adapter->details->nautilus_view;
 }
 
-
-
 static void 
 nautilus_adapter_load_location_callback (NautilusView    *view,
 					 const char      *location,
@@ -303,7 +268,7 @@ nautilus_adapter_activate_callback (BonoboControl   *control,
 	if (state) {
 		Bonobo_UIContainer corba_container;
 
-		corba_container = bonobo_control_get_remote_ui_container (control);
+		corba_container = bonobo_control_get_remote_ui_container (control, NULL);
 		nautilus_adapter_embed_strategy_activate (adapter->details->embed_strategy,
 							  corba_container);
 	} else
@@ -336,4 +301,3 @@ nautilus_adapter_load_failed_callback   (NautilusAdapter             *adapter)
 {
 	nautilus_view_report_load_failed (adapter->details->nautilus_view);
 }
-
