@@ -1,3 +1,5 @@
+/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
+
 /*
  * Generic image loading embeddable using gdk-pixbuf.
  *
@@ -25,10 +27,11 @@
 #include <errno.h>
 
 #include <gnome.h>
-#include <liboaf/liboaf.h>
+#include <bonobo-activation/bonobo-activation.h>
 
 #include <bonobo.h>
 
+#include <eel/eel-debug.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk-pixbuf/gdk-pixbuf-loader.h>
 #include <libart_lgpl/art_misc.h>
@@ -39,6 +42,8 @@
 
 #include "io-png.h"
 
+#define LOAD_BUFFER_SIZE 65536
+
 /*
  * Number of running objects
  */ 
@@ -57,8 +62,8 @@ typedef struct {
         GtkWidget        *scrolled_window;
 	GdkPixbuf        *scaled;
         gboolean          size_allocated;
-	gboolean	  initial_flag;
-	gboolean	  resize_flag;
+	gboolean	  got_initial_size;
+	gboolean	  got_penultimate_allocation;
 	
 	GdkPixbuf        *zoomed;
 	float             zoom_level;
@@ -76,17 +81,17 @@ release_pixbuf (bonobo_object_data_t *bod)
 	g_return_if_fail (bod != NULL);
 
 	if (bod->pixbuf != NULL) {
-		gdk_pixbuf_unref (bod->pixbuf);
+		g_object_unref (bod->pixbuf);
 	}
 	bod->pixbuf = NULL;
 
 	if (bod->zoomed != NULL) {
-		gdk_pixbuf_unref (bod->zoomed);
+		g_object_unref (bod->zoomed);
 	}
 	bod->zoomed = NULL;
 
 	if (bod->scaled != NULL) {
-		gdk_pixbuf_unref (bod->scaled);
+		g_object_unref (bod->scaled);
 	}
 	bod->scaled = NULL;
 }
@@ -94,10 +99,6 @@ release_pixbuf (bonobo_object_data_t *bod)
 static void
 control_destroy_callback (BonoboControl *control, bonobo_object_data_t *bod)
 {
-	/* FIXME bugzilla.eazel.com 5966:
-	 * This fn never gets called. This means we are leaking.
-	 */
-
         if (bod == NULL) {
 		return;
 	}
@@ -214,8 +215,8 @@ redraw_control (bonobo_object_data_t *bod, GdkRectangle *rect)
 	 * so we don't screw up the size allocation process by drawing
 	 * an unscaled image too early.
 	 */
-	if (bod->size_allocated) {
-	        render_pixbuf (buf, bod->drawing_area, rect);
+	if (bod->got_initial_size) {
+		render_pixbuf (buf, bod->drawing_area, rect);
 	}
 }
 
@@ -253,14 +254,14 @@ configure_size (bonobo_object_data_t *bod, GdkRectangle *rect)
 }
 
 static float preferred_zoom_levels[] = {
-	1.0 / 10.0, 1.0 / 9.0, 1.0 / 8.0, 1.0 / 7.0, 1.0 / 6.0,
-	1.0 / 5.0, 1.0 / 4.0, 1.0 / 3.0, 1.0 / 2.0, 1.0, 2.0,
-	3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0
+	1.0 / 10.0,  1.0 / 8.0, 1.0 / 6.0, 1.0 / 5.0, 
+	1.0 / 4.0, 1.0 / 3.0, 1.0 / 2.0, 2.0 / 3.0, 1.0, 1.5, 2.0,
+	3.0, 4.0, 5.0, 6.0, 8.0, 10.0
 };
 static const gchar *preferred_zoom_level_names[] = {
-	"1:10", "1:9", "1:8", "1:7", "1:6", "1:5", "1:4", "1:3",
-	"1:2", "1:1", "2:1", "3:1", "4:1", "5:1", "6:1", "7:1",
-	"8:1", "9:1", "10:1"
+	"1:10", "1:8", "1:6", "1:5", "1:4", "1:3",
+	"1:2", "2:3",  "1:1", "3:2", "2:1", "3:1", "4:1", "5:1", "6:1",
+	"8:1", "10:1"
 };
 
 static const gint max_preferred_zoom_levels = (sizeof (preferred_zoom_levels) /
@@ -318,7 +319,7 @@ zoomable_zoom_in_callback (BonoboZoomable *zoomable, bonobo_object_data_t *bod)
 		new_zoom_level = zoom_level_from_index (index);
 	}
 	
-	gtk_signal_emit_by_name (GTK_OBJECT (zoomable), "set_zoom_level",
+	g_signal_emit_by_name (zoomable, "set_zoom_level",
 				 new_zoom_level);
 }
 
@@ -337,7 +338,7 @@ zoomable_zoom_out_callback (BonoboZoomable *zoomable, bonobo_object_data_t *bod)
 	index--;
 	new_zoom_level = zoom_level_from_index (index);
 
-	gtk_signal_emit_by_name (GTK_OBJECT (zoomable), "set_zoom_level",
+	g_signal_emit_by_name (zoomable, "set_zoom_level",
 				 new_zoom_level);
 }
 
@@ -359,15 +360,8 @@ zoomable_zoom_to_fit_callback (BonoboZoomable *zoomable, bonobo_object_data_t *b
 	y_level = vadj->page_size / height;
 
 	new_zoom_level = (x_level < y_level) ? x_level : y_level;
-
-#if 0
-	g_message ("zoom_to_fit: (%g,%g) - (%g,%g) - (%g,%g) - %g",
-		   width, height, hadj->page_size, vadj->page_size,
-		   x_level, y_level, new_zoom_level);
-#endif
-
 	if (new_zoom_level > 0) {
-		gtk_signal_emit_by_name (GTK_OBJECT (zoomable), "set_zoom_level",
+		g_signal_emit_by_name (zoomable, "set_zoom_level",
 				 new_zoom_level);
 	}
 }
@@ -375,7 +369,7 @@ zoomable_zoom_to_fit_callback (BonoboZoomable *zoomable, bonobo_object_data_t *b
 static void
 zoomable_zoom_to_default_callback (BonoboZoomable *zoomable, bonobo_object_data_t *bod)
 {
-	gtk_signal_emit_by_name (GTK_OBJECT (zoomable), "set_zoom_level",
+	g_signal_emit_by_name (zoomable, "set_zoom_level",
 				 1.0);
 }
 
@@ -415,11 +409,11 @@ rezoom_control (bonobo_object_data_t *bod, float new_zoom_level)
 	new_height = old_height * new_zoom_level;
 
 	if (bod->zoomed)
-		gdk_pixbuf_unref (bod->zoomed);
+		g_object_unref (bod->zoomed);
 
 	if (new_width >= 1 && new_height >= 1) {
 		bod->zoomed = gdk_pixbuf_scale_simple (pixbuf, new_width, 
-						       new_height, ART_FILTER_NEAREST);
+						       new_height, GDK_INTERP_BILINEAR);
 	}
 
 	resize_control (bod);
@@ -436,8 +430,8 @@ zoomable_set_zoom_level_callback (BonoboZoomable *zoomable, float new_zoom_level
 
 	control_update (bod);
 
-	bonobo_zoomable_report_zoom_level_changed (bod->zoomable,
-						   new_zoom_level);
+	bonobo_zoomable_report_zoom_level_changed (
+		bod->zoomable, new_zoom_level, NULL);
 }
 
 static void
@@ -487,22 +481,22 @@ load_image_from_stream (BonoboPersistStream *ps, Bonobo_Stream stream,
 
 	/* Load new data from stream */
 	do {
-		Bonobo_Stream_read (stream, 4096, &buffer, ev);
+		Bonobo_Stream_read (stream, LOAD_BUFFER_SIZE, &buffer, ev);
 		if (ev->_major != CORBA_NO_EXCEPTION) {
-			gdk_pixbuf_loader_close (loader);
-			gtk_object_unref (GTK_OBJECT (loader));
+			gdk_pixbuf_loader_close (loader, NULL);
+			g_object_unref (loader);
 			return;
 		}
 		
 		if (buffer->_buffer != NULL && 
-		    !gdk_pixbuf_loader_write (loader, buffer->_buffer, buffer->_length)) {
+		    !gdk_pixbuf_loader_write (loader, buffer->_buffer, buffer->_length, NULL)) {
 			CORBA_free (buffer);
 				if (ev->_major != CORBA_NO_EXCEPTION) {
 					CORBA_exception_set (ev, CORBA_USER_EXCEPTION,
 										 ex_Bonobo_Persist_WrongDataType, NULL);
 				}				
-				gdk_pixbuf_loader_close (loader);
-				gtk_object_unref (GTK_OBJECT (loader));
+				gdk_pixbuf_loader_close (loader, NULL);
+				g_object_unref (loader);
 				return;
 		}
 		
@@ -510,14 +504,20 @@ load_image_from_stream (BonoboPersistStream *ps, Bonobo_Stream stream,
 		CORBA_free (buffer);
 	} while (len > 0);
 
-	gdk_pixbuf_loader_close (loader);
+	gdk_pixbuf_loader_close (loader, NULL);
 	bod->pixbuf = gdk_pixbuf_loader_get_pixbuf (loader);
 
 	if (bod->pixbuf == NULL) {
 		CORBA_exception_set (ev, CORBA_USER_EXCEPTION, ex_Bonobo_Persist_WrongDataType, NULL);
-		gtk_object_unref (GTK_OBJECT (loader));
+		g_object_unref (loader);
 	} else {
-		gdk_pixbuf_ref (bod->pixbuf);
+		g_object_ref (bod->pixbuf);
+		
+		/* Restore current zoomed pixbuf cache. */
+		if (bod->zoom_level != 1.0) {
+			rezoom_control (bod, bod->zoom_level);
+		}
+		
 		resize_control (bod);
 	}
 }
@@ -544,8 +544,7 @@ control_size_allocate_callback (GtkWidget *drawing_area, GtkAllocation *allocati
 {
 	const GdkPixbuf *buf;
 	GdkPixbuf       *control_buf;
-	GdkInterpType    type;
-
+	
 	g_return_if_fail (bod != NULL);
 	g_return_if_fail (allocation != NULL);
 
@@ -560,7 +559,7 @@ control_size_allocate_callback (GtkWidget *drawing_area, GtkAllocation *allocati
 	if (allocation->width  == gdk_pixbuf_get_width (buf) &&
 	    allocation->height == gdk_pixbuf_get_height (buf)) {
 		if (bod->scaled != NULL) {
-			gdk_pixbuf_unref (bod->scaled);
+			g_object_unref (bod->scaled);
 			bod->scaled = NULL;
 		}
 		return;
@@ -573,27 +572,19 @@ control_size_allocate_callback (GtkWidget *drawing_area, GtkAllocation *allocati
 			return;
 		} else {
 			bod->scaled = NULL;
-			gdk_pixbuf_unref (control_buf);
+			g_object_unref (control_buf);
 			control_buf = NULL;
 		}
 	}
-
-	/* Too slow below this */
-	if (allocation->width < gdk_pixbuf_get_width (buf) / 4 ||
-	    allocation->width < gdk_pixbuf_get_width (buf) / 4)
-		type = ART_FILTER_NEAREST;
-	else
-		type = ART_FILTER_TILES;
-
+	
 	if (allocation->width >= 1 && allocation->height >= 1) {
 		bod->scaled = gdk_pixbuf_scale_simple (buf, allocation->width,
-					       	       allocation->height, type);
+					       	       allocation->height, GDK_INTERP_BILINEAR);
 	}
 	
 	control_update (bod);
 }
 
-
 /*
  * This callback will be invoked when the container assigns us a size.
  */
@@ -605,51 +596,51 @@ scrolled_control_size_allocate_callback (GtkWidget *drawing_area,
 	control_update (bod);
 }
 
-/* utility routine to determine if the image is bigger than the current viewer */
+/*
+ * determine if the image is larger than the display area *
+ */
 static gboolean
-image_bigger_than_viewer (bonobo_object_data_t *bod)
+image_fits_in_container (bonobo_object_data_t *bod)
 {
-	int width, height;
 	GtkAdjustment *hadj, *vadj;
-	
-	if (bod->pixbuf == NULL) {
-		return FALSE;
-	}
-	
+	float width, height;
+
 	width = gdk_pixbuf_get_width (bod->pixbuf);
 	height = gdk_pixbuf_get_height (bod->pixbuf);
 
 	hadj = gtk_scrolled_window_get_hadjustment (GTK_SCROLLED_WINDOW (bod->scrolled_window));
 	vadj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (bod->scrolled_window));
 
-	if (hadj == NULL || vadj == NULL) {
-		return FALSE;
-	}
-	
-	return width > hadj->page_size || height > vadj->page_size;
+	return width <= hadj->page_size && height <= vadj->page_size;
 }
-
+ 
 /*
  * This callback will be invoked when the container assigns us a size.
  */
 static void
 scrolled_window_size_allocate_callback (GtkWidget *drawing_area,
-					 GtkAllocation *allocation,
-					 bonobo_object_data_t *bod)
+					GtkAllocation *allocation,
+					bonobo_object_data_t *bod)
 {	
-	/* implement initial shrink-to-fit if necessary.  It's hard to tell when resizing
-	 * is complete, inspiring this hackish solution determining when; it should
-	 * be replaced with a cleaner approach when the framework is improve.
+	/* Implement initial shrink-to-fit if necessary. It's hard to
+	 * tell when resizing is complete, inspiring this hackish
+	 * solution determining when; it should be replaced with a
+	 * cleaner approach when the framework is improved.
 	 */
 
-	if (bod->resize_flag && bod->initial_flag && allocation->width > 1 && allocation->height > 1) {
-		if (image_bigger_than_viewer (bod)) {
-			zoomable_zoom_to_fit_callback (bod->zoomable, bod);		
-			control_update (bod);
-		}
-		bod->initial_flag = FALSE;
-	} else if (!bod->resize_flag && allocation->width == 1 && allocation->height == 1) {
-		bod->resize_flag = TRUE;
+	if (bod->got_penultimate_allocation
+	    && !bod->got_initial_size
+	    && allocation->width > 1
+	    && allocation->height > 1) {
+		bod->got_initial_size = TRUE;
+	 	if (!image_fits_in_container (bod)) {
+			zoomable_zoom_to_fit_callback (bod->zoomable, bod);
+	 	}
+		gtk_widget_queue_draw (bod->drawing_area);
+	} else if (!bod->got_penultimate_allocation
+		   && allocation->width == 1
+		   && allocation->height == 1) {
+		bod->got_penultimate_allocation = TRUE;
 	}
 }
 
@@ -660,7 +651,7 @@ control_activate_callback (BonoboControl *control, gboolean activate, gpointer d
 	 * Notify the ControlFrame that we accept to be activated or
 	 * deactivated (we are an acquiescent BonoboControl, yes we are).
 	 */
-	bonobo_control_activate_notify (control, activate);
+	bonobo_control_activate_notify (control, activate, NULL);
 }
 
 static bonobo_object_data_t *
@@ -670,27 +661,22 @@ control_factory_common (GtkWidget *scrolled_window)
 	bonobo_object_data_t *bod;
 
 	bod = g_new0 (bonobo_object_data_t, 1);
-	bod->scaled = NULL;
-	bod->zoomed = NULL;
 	bod->zoom_level = 1.0;
 	bod->drawing_area = gtk_drawing_area_new ();
-	bod->size_allocated = FALSE;
 	bod->scrolled_window = scrolled_window;
 
-	/* set flags that control initial shrink-to-fit */
-	bod->initial_flag = TRUE;
-	bod->resize_flag = FALSE;
-	
-	gtk_signal_connect (GTK_OBJECT (bod->drawing_area),
+	g_signal_connect (bod->drawing_area,
 			    "expose_event",
-			    GTK_SIGNAL_FUNC (drawing_area_exposed), bod);
+			    G_CALLBACK (drawing_area_exposed), bod);
 
 	if (scrolled_window) {
 		bod->root = scrolled_window;
 		gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (bod->root), 
 						       bod->drawing_area);
-	} else
+	} else {
 		bod->root = bod->drawing_area;
+		bod->got_initial_size = TRUE;
+	}
 
 	gtk_widget_show_all (bod->root);
 	bod->control = bonobo_control_new (bod->root);
@@ -703,21 +689,21 @@ control_factory_common (GtkWidget *scrolled_window)
 	 */
 	gtk_widget_ref (bod->drawing_area);
 
-	gtk_signal_connect (GTK_OBJECT (bod->control), "destroy",
-			    GTK_SIGNAL_FUNC (control_destroy_callback), bod);
+	g_signal_connect (bod->control, "destroy",
+			    G_CALLBACK (control_destroy_callback), bod);
 
 	bod->zoomable = bonobo_zoomable_new ();
 
-	gtk_signal_connect (GTK_OBJECT (bod->zoomable), "set_zoom_level",
-			    GTK_SIGNAL_FUNC (zoomable_set_zoom_level_callback), bod);
-	gtk_signal_connect (GTK_OBJECT (bod->zoomable), "zoom_in",
-			    GTK_SIGNAL_FUNC (zoomable_zoom_in_callback), bod);
-	gtk_signal_connect (GTK_OBJECT (bod->zoomable), "zoom_out",
-			    GTK_SIGNAL_FUNC (zoomable_zoom_out_callback), bod);
-	gtk_signal_connect (GTK_OBJECT (bod->zoomable), "zoom_to_fit",
-			    GTK_SIGNAL_FUNC (zoomable_zoom_to_fit_callback), bod);
-	gtk_signal_connect (GTK_OBJECT (bod->zoomable), "zoom_to_default",
-			    GTK_SIGNAL_FUNC (zoomable_zoom_to_default_callback), bod);
+	g_signal_connect (bod->zoomable, "set_zoom_level",
+			    G_CALLBACK (zoomable_set_zoom_level_callback), bod);
+	g_signal_connect (bod->zoomable, "zoom_in",
+			    G_CALLBACK (zoomable_zoom_in_callback), bod);
+	g_signal_connect (bod->zoomable, "zoom_out",
+			    G_CALLBACK (zoomable_zoom_out_callback), bod);
+	g_signal_connect (bod->zoomable, "zoom_to_fit",
+			    G_CALLBACK (zoomable_zoom_to_fit_callback), bod);
+	g_signal_connect (bod->zoomable, "zoom_to_default",
+			    G_CALLBACK (zoomable_zoom_to_default_callback), bod);
 
 	bod->zoom_level = 1.0;
 	bonobo_zoomable_set_parameters_full (bod->zoomable,
@@ -733,8 +719,8 @@ control_factory_common (GtkWidget *scrolled_window)
 	bonobo_object_add_interface (BONOBO_OBJECT (bod->control),
 				     BONOBO_OBJECT (bod->zoomable));
 
-	gtk_signal_connect (GTK_OBJECT (bod->control), "activate",
-			    GTK_SIGNAL_FUNC (control_activate_callback), bod);
+	g_signal_connect (bod->control, "activate",
+			    G_CALLBACK (control_activate_callback), bod);
 
 	/*
 	 * Interface Bonobo::PersistStream 
@@ -757,8 +743,8 @@ scaled_control_factory (void)
 
 	bod = control_factory_common (NULL);
 
-	gtk_signal_connect (GTK_OBJECT (bod->drawing_area), "size_allocate",
-			    GTK_SIGNAL_FUNC (control_size_allocate_callback), bod);
+	g_signal_connect (bod->drawing_area, "size_allocate",
+			    G_CALLBACK (control_size_allocate_callback), bod);
 
         return bod;
 }
@@ -772,24 +758,24 @@ scrollable_control_factory (void)
 	scroll = gtk_scrolled_window_new (NULL, NULL);
 
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll),
-					GTK_POLICY_ALWAYS,
-					GTK_POLICY_ALWAYS);
+					GTK_POLICY_AUTOMATIC,
+					GTK_POLICY_AUTOMATIC);
 
 	bod = control_factory_common (scroll);
 
-	gtk_signal_connect (GTK_OBJECT (bod->drawing_area), "size_allocate",
-			    GTK_SIGNAL_FUNC (scrolled_control_size_allocate_callback),
+	g_signal_connect (bod->drawing_area, "size_allocate",
+			    G_CALLBACK (scrolled_control_size_allocate_callback),
 			    bod);
 	
-	gtk_signal_connect (GTK_OBJECT (bod->scrolled_window), "size_allocate",
-			    GTK_SIGNAL_FUNC (scrolled_window_size_allocate_callback),
+	g_signal_connect (bod->scrolled_window, "size_allocate",
+			    G_CALLBACK (scrolled_window_size_allocate_callback),
 			    bod);
 
         return bod;
 }
 
 static BonoboObject *
-bonobo_object_factory (BonoboGenericFactory *this, const char *oaf_iid,
+bonobo_object_factory (BonoboGenericFactory *this, const char *bonobo_activation_iid,
 		       void *data)
 {
 	bonobo_object_data_t *bod;
@@ -800,9 +786,9 @@ bonobo_object_factory (BonoboGenericFactory *this, const char *oaf_iid,
 	 * Creates the BonoboObject server
 	 */
 
-	if (strcmp (oaf_iid, "OAFIID:nautilus-image-generic:6ed7ef0d-9274-4132-9a27-9f048142782f") == 0) {
+	if (strcmp (bonobo_activation_iid, "OAFIID:nautilus-image-generic:6ed7ef0d-9274-4132-9a27-9f048142782f") == 0) {
 		bod = scaled_control_factory ();
-	} else if (strcmp (oaf_iid, "OAFIID:nautilus-image-viewer:30686633-23d5-422b-83c6-4f1b06f8abcd") == 0) {
+	} else if (strcmp (bonobo_activation_iid, "OAFIID:nautilus-image-viewer:30686633-23d5-422b-83c6-4f1b06f8abcd") == 0) {
 		bod = scrollable_control_factory ();
 	} else {
 		return NULL;
@@ -820,9 +806,10 @@ init_bonobo_image_generic_factory (void)
 {
         char *registration_id;
 
-	registration_id = oaf_make_registration_id ("OAFIID:nautilus_image_view_factory:61ea9ab1-e4b4-4da8-8f54-61cf6f33c4f6", g_getenv ("DISPLAY"));
+	registration_id = bonobo_activation_make_registration_id ("OAFIID:nautilus_image_view_factory:61ea9ab1-e4b4-4da8-8f54-61cf6f33c4f6",
+						    g_getenv ("DISPLAY"));
 
-	image_factory = bonobo_generic_factory_new_multi 
+	image_factory = bonobo_generic_factory_new
 		(registration_id,
 		 bonobo_object_factory, NULL);
 
@@ -834,16 +821,23 @@ init_server_factory (int argc, char **argv)
 {
 	CORBA_Environment ev;
 	CORBA_exception_init (&ev);
+	
+	/* Disable session manager connection */
+#ifdef GNOME2_CONVERSION_COMPLETE
+	gnome_client_disable_master_connection ();
 
-        gnome_init_with_popt_table("bonobo-image-generic", VERSION,
-				   argc, argv,
-				   oaf_popt_options, 0, NULL); 
+	gnomelib_register_popt_table (bonobo_activation_popt_options, bonobo_activation_get_popt_table_name ());
+	bonobo_activation_init (argc, argv);
+
+        gnome_init ("bonobo-image-generic", VERSION,
+		    argc, argv); 
 	gdk_rgb_init ();
 
-	oaf_init (argc, argv);
-
 	if (!bonobo_init (CORBA_OBJECT_NIL, CORBA_OBJECT_NIL, CORBA_OBJECT_NIL))
 		g_error (_("I could not initialize Bonobo"));
+#endif
+	if (!bonobo_ui_init ("bonobo-image-generic", VERSION, &argc, argv))
+		g_error (_("I could not initialize Bonobo"));
 
 	CORBA_exception_free (&ev);
 }
@@ -851,6 +845,17 @@ init_server_factory (int argc, char **argv)
 int
 main (int argc, char *argv [])
 {
+	/* Initialize gettext support */
+#ifdef ENABLE_NLS
+	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
+	bind_textdomain_codeset (PACKAGE, "UTF-8");
+	textdomain (PACKAGE);
+#endif
+
+	if (g_getenv ("NAUTILUS_DEBUG") != NULL) {
+		eel_make_warnings_and_criticals_stop_in_debugger ();
+	}
+
 	init_server_factory (argc, argv);
 
 	init_bonobo_image_generic_factory ();
