@@ -28,21 +28,25 @@
  */
 
 #include <config.h>
+#include <time.h>
 
 #include <gtk/gtkcheckbutton.h>
+#include <gtk/gtkclist.h>
 #include <gtk/gtkdrawingarea.h>
 #include <gtk/gtkframe.h>
 #include <gtk/gtkhbbox.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtkscrolledwindow.h>
+#include <gtk/gtkstock.h>
 #include <gtk/gtkvbox.h>
 
-#include <libgnome/gnome-defs.h>
+#include <bonobo/bonobo-property-bag.h>
+
 #include <libgnome/gnome-i18n.h>
 #include <libgnome/gnome-util.h>
 
-#include <gnome-xml/parser.h>
-#include <gnome-xml/xmlmemory.h>
+#include <libxml/parser.h>
+#include <libxml/xmlmemory.h>
 
 #include <libgnomevfs/gnome-vfs-utils.h>
 
@@ -52,9 +56,6 @@
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-graphic-effects.h>
 #include <eel/eel-gtk-extensions.h>
-#include <eel/eel-label.h>
-#include <eel/eel-scalable-font.h>
-#include <eel/eel-smooth-text-layout.h>
 #include <eel/eel-stock-dialogs.h>
 #include <eel/eel-string.h>
 #include <eel/eel-vfs-extensions.h>
@@ -64,7 +65,6 @@
 #include <libnautilus-private/nautilus-file-attributes.h>
 #include <libnautilus-private/nautilus-file.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
-#include <libnautilus-private/nautilus-font-factory.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus-private/nautilus-metadata.h>
 #include <libnautilus-private/nautilus-theme.h>
@@ -121,9 +121,6 @@ typedef struct {
 	uint update_interval;
 	int update_timeout;
 	
-	EelScalableFont *font;	
-	EelScalableFont *bold_font;	
-	
 	gboolean news_changed;
 	gboolean always_display_title;
 	gboolean configure_mode;
@@ -150,7 +147,7 @@ typedef struct {
 	char *link_uri;
 	News *owner;
 	
-	char *title;
+	PangoLayout *title;
 	GdkPixbuf *logo_image;	
 	
 	GList *items;
@@ -303,14 +300,6 @@ do_destroy (GtkObject *obj, News *news)
 {
 	g_free (news->uri);
 	
-	if (news->font) {
-		gtk_object_unref (GTK_OBJECT (news->font));
-	}
-	
-	if (news->bold_font) {
-		gtk_object_unref (GTK_OBJECT (news->bold_font));
-	}
-
 	if (news->timer_task != 0) {
 		gtk_timeout_remove (news->timer_task);
 		news->timer_task = 0;
@@ -322,31 +311,36 @@ do_destroy (GtkObject *obj, News *news)
 	}
 	
         if (news->closed_triangle != NULL) {
-		gdk_pixbuf_unref (news->closed_triangle);
+		g_object_unref (news->closed_triangle);
 	}
         
 	if (news->closed_triangle_changed != NULL) {
-		gdk_pixbuf_unref (news->closed_triangle_changed);
+		g_object_unref (news->closed_triangle_changed);
 	}
         
 	if (news->open_triangle != NULL) {
-		gdk_pixbuf_unref (news->open_triangle);
+		g_object_unref (news->open_triangle);
 	}
 	
 	if (news->open_triangle_changed != NULL) {
-		gdk_pixbuf_unref (news->open_triangle_changed);
+		g_object_unref (news->open_triangle_changed);
 	}
 	
 	if (news->bullet != NULL) {
-		gdk_pixbuf_unref (news->bullet);
+		g_object_unref (news->bullet);
 	}	
 	
 	if (news->changed_bullet != NULL) {
-		gdk_pixbuf_unref (news->changed_bullet);
+		g_object_unref (news->changed_bullet);
 	}	
 	
 	/* free all the channel data */
 	nautilus_news_free_channel_list (news);
+
+	/* free the property bag */
+	if (news->property_bag != NULL) {
+		bonobo_object_unref (BONOBO_OBJECT (news->property_bag));
+	}
 	
 	eel_preferences_remove_callback (NAUTILUS_PREFERENCES_NEWS_MAX_ITEMS,
                                          max_items_changed,
@@ -426,7 +420,7 @@ draw_triangle (GdkPixbuf *pixbuf, RSSChannelData *channel_data, int v_offset)
 	pixbuf_composite (mapped_image, pixbuf, 2, triangle_position, 255);
 
 	if (mapped_image != triangle) {
-		gdk_pixbuf_unref (mapped_image);
+		g_object_unref (mapped_image);
 	}
 }
 
@@ -437,12 +431,14 @@ draw_rss_logo_image (RSSChannelData *channel_data,
 		     int offset,
 		     gboolean measure_only)
 {
-	char time_str[16];
+	char *time_str;
 	int logo_width, logo_height;
 	int v_offset, pixbuf_width;
-	int time_x_pos, time_y_pos;
 	GdkPixbuf *mapped_image;
+#if GNOME2_CONVERSION_COMPLETE
+	int time_x_pos, time_y_pos;
 	EelDimensions time_dimensions;
+#endif
 	
 	v_offset = offset;
 	
@@ -459,18 +455,20 @@ draw_rss_logo_image (RSSChannelData *channel_data,
 			}
 			pixbuf_composite (mapped_image, pixbuf, LOGO_LEFT_OFFSET, v_offset, 255);
 			if (mapped_image != channel_data->logo_image) {
-				gdk_pixbuf_unref (mapped_image);
+				g_object_unref (mapped_image);
 			}
 		}
 		v_offset += logo_height + 2;
 
 		/* also, draw the update time in the upper right corner if it fits*/
 		if (channel_data->last_update != 0 && !measure_only) {
-			strftime (&time_str[0], 16, "%I:%M %p",	localtime (&channel_data->last_update));
+			time_str = eel_strdup_strftime (_("%I:%M %p"), localtime (&channel_data->last_update));
 
+			pixbuf_width = gdk_pixbuf_get_width (pixbuf);
+
+#if GNOME2_CONVERSION_COMPLETE
 			time_dimensions = eel_scalable_font_measure_text (channel_data->owner->font, 9, time_str, strlen (time_str));
 	
-			pixbuf_width = gdk_pixbuf_get_width (pixbuf);
 			time_x_pos = pixbuf_width - time_dimensions.width - TIME_MARGIN_OFFSET;
 			if (time_x_pos >= LOGO_LEFT_OFFSET + logo_width) {
 				time_y_pos = offset + ((gdk_pixbuf_get_height (channel_data->logo_image) - time_dimensions.height) / 2);
@@ -480,6 +478,8 @@ draw_rss_logo_image (RSSChannelData *channel_data,
 							     TIME_FONT_SIZE, time_str, strlen (time_str),
 							     EEL_RGB_COLOR_BLACK, EEL_OPACITY_FULLY_OPAQUE);
 			}
+			g_free (time_str);
+#endif
 		}
 	}
 	return v_offset;
@@ -492,19 +492,14 @@ draw_rss_title (RSSChannelData *channel_data,
 		int v_offset,
 		gboolean measure_only)
 {
-	EelDimensions title_dimensions;
 	int label_offset;
 	gboolean is_prelit;
+        int height;
 	
-	if (channel_data->title == NULL || channel_data->owner->font == NULL) {
+	if (channel_data->title == NULL) {
 		return v_offset;
 	}
 	
-	/* first, measure the text */
-	title_dimensions = eel_scalable_font_measure_text (channel_data->owner->font, 
-					     TITLE_FONT_SIZE,
-					     channel_data->title, strlen (channel_data->title));
-	
 	/* if there is no image, draw the disclosure triangle */
 	if (channel_data->logo_image == NULL && !measure_only) {
 		draw_triangle (pixbuf, channel_data, v_offset);			
@@ -518,16 +513,15 @@ draw_rss_title (RSSChannelData *channel_data,
 	
 	/* draw the name into the pixbuf using anti-aliased text */	
 	if (!measure_only) {
-		eel_scalable_font_draw_text (channel_data->owner->font, pixbuf, 
-					  label_offset, v_offset,
-					  eel_gdk_pixbuf_whole_pixbuf,
-					  18,
-					  channel_data->title, strlen (channel_data->title),
-					  is_prelit ? EEL_RGBA_COLOR_PACK (0, 0, 128, 255) : EEL_RGB_COLOR_BLACK,
-					  EEL_OPACITY_FULLY_OPAQUE);
+		eel_gdk_pixbuf_draw_layout (pixbuf, 
+                                            label_offset, v_offset,
+                                            is_prelit ? EEL_RGBA_COLOR_PACK (0, 0, 128, 255) : EEL_RGB_COLOR_BLACK,
+                                            channel_data->title);
 	}
 	
-	return v_offset + title_dimensions.height;
+        pango_layout_get_pixel_size (channel_data->title, NULL, &height);
+
+	return v_offset + height;
 }
 
 /* utility to determine if a uri matches the current one */
@@ -547,13 +541,14 @@ draw_rss_items (RSSChannelData *channel_data,
 	GList *current_item;
 	RSSItemData *item_data;
 	int bullet_width, bullet_height, font_size;
+        gboolean bold;
 	int item_index, bullet_alpha;
-	int bullet_x_pos, bullet_y_pos;
 	guint32 text_color;
+#if GNOME2_CONVERSION_COMPLETE
+	int bullet_x_pos, bullet_y_pos;
 	ArtIRect dest_bounds;
-	EelSmoothTextLayout *smooth_text_layout;
+#endif
 	EelDimensions text_dimensions;
-	EelScalableFont *font;
 	GdkPixbuf *bullet;
 	
 	if (channel_data->owner->bullet) {
@@ -587,12 +582,9 @@ draw_rss_items (RSSChannelData *channel_data,
 		
 		font_size = ITEM_FONT_SIZE;	
 		item_data->item_start_y = v_offset;
-		if (is_current_uri (channel_data->owner, item_data->item_url)) {
-			font = channel_data->owner->bold_font;
-		} else {
-			font = channel_data->owner->font;
-		}
-		
+		bold = is_current_uri (channel_data->owner, item_data->item_url);
+
+#if GNOME2_CONVERSION_COMPLETE		
 		smooth_text_layout = eel_smooth_text_layout_new
                         (item_data->item_title,
                          eel_strlen (item_data->item_title),
@@ -626,7 +618,9 @@ draw_rss_items (RSSChannelData *channel_data,
 				}	
 			}
 		}
-		gtk_object_destroy (GTK_OBJECT (smooth_text_layout));
+
+		g_object_unref (smooth_text_layout);
+#endif
 		
 		item_data->item_end_y = item_data->item_start_y + text_dimensions.height;
 		v_offset += text_dimensions.height + 4;
@@ -719,7 +713,7 @@ static gint
 nautilus_news_configure_event (GtkWidget *widget, GdkEventConfigure *event, News *news_data )
 {
 	if (news_data->pixbuf != NULL) {
-		gdk_pixbuf_unref (news_data->pixbuf);
+		g_object_unref (news_data->pixbuf);
 	}
 		
 	news_data->pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8,
@@ -930,17 +924,20 @@ nautilus_news_leave_notify_event (GtkWidget *widget, GdkEventMotion *event, News
 static void
 nautilus_news_set_title (RSSChannelData *channel_data, const char *title)
 {
-	if (eel_strcmp (channel_data->title, title) == 0) {
-		return;
-	}
-	
-	if (channel_data->title) {
-		g_free (channel_data->title);
-	}
 	if (title != NULL) {
-		channel_data->title = g_strdup (title);
+                if (channel_data->title == NULL) {
+                        channel_data->title = pango_layout_new (eel_gtk_widget_get_pango_ft2_context (channel_data->owner->news_display));
+                } else {
+                        if (strcmp (pango_layout_get_text (channel_data->title), title) == 0) {
+                                return;
+                        }
+                }
+                pango_layout_set_text (channel_data->title, title, -1);
 	} else {
-		channel_data->title = NULL;	
+                if (channel_data->title != NULL) {
+                        g_object_unref (channel_data->title);
+                }
+		channel_data->title = NULL;
 	}
 }
 
@@ -966,10 +963,13 @@ free_channel (RSSChannelData *channel_data)
 	g_free (channel_data->name);
 	g_free (channel_data->uri);
 	g_free (channel_data->link_uri);
-	g_free (channel_data->title);
+
+        if (channel_data->title != NULL) {
+                g_object_unref (channel_data->title);
+        }
 	
 	if (channel_data->logo_image != NULL) {
-		gdk_pixbuf_unref (channel_data->logo_image);
+		g_object_unref (channel_data->logo_image);
 	}
 
 	if (channel_data->load_file_handle != NULL) {
@@ -1015,10 +1015,10 @@ nautilus_news_set_news_changed (News *news_data, gboolean changed_flag)
 		
 		tab_image_arg = bonobo_arg_new (BONOBO_ARG_STRING);
 		BONOBO_ARG_SET_STRING (tab_image_arg, tab_image);			
-                
+#ifdef GNOME2_CONVERSION_COMPLETE  
 		bonobo_property_bag_notify_listeners (news_data->property_bag,
                                                       "tab_image", tab_image_arg, NULL);
-                
+#endif 
 		bonobo_arg_release (tab_image_arg);
 		g_free (tab_image);
 	}
@@ -1121,12 +1121,12 @@ rss_logo_callback (GnomeVFSResult  error, GdkPixbuf *pixbuf, gpointer callback_d
 	channel_data->load_image_handle = NULL;
 	
 	if (channel_data->logo_image) {
-		gdk_pixbuf_unref (channel_data->logo_image);
+		g_object_unref (channel_data->logo_image);
 		channel_data->logo_image = NULL;
 	}
 	
 	if (pixbuf != NULL) {
-		gdk_pixbuf_ref (pixbuf);
+		g_object_ref (pixbuf);
 		pixbuf = eel_gdk_pixbuf_scale_down_to_fit (pixbuf, 192, 40);		
 		channel_data->logo_image = pixbuf;
 		queue_update_size_and_redraw (channel_data->owner);
@@ -1171,7 +1171,7 @@ extract_items (RSSChannelData *channel_data, xmlNodePtr container_node)
 	char *title, *temp_str;
 	gboolean scripting_news_format;
 	
-	current_node = container_node->childs;
+	current_node = container_node->children;
 	item_count = 0;
 	while (current_node != NULL) {
 		if (eel_strcmp (current_node->name, "item") == 0) {
@@ -1422,7 +1422,8 @@ extract_rss_image (RSSChannelData *channel_data, xmlDoc *rss_document)
 		if (uri_node != NULL) {
 			image_uri = xmlNodeGetContent (uri_node);
 			if (image_uri != NULL) {
-				channel_data->load_image_handle = eel_gdk_pixbuf_load_async (image_uri, rss_logo_callback, channel_data);
+				channel_data->load_image_handle = eel_gdk_pixbuf_load_async (image_uri, 
+					     GNOME_VFS_PRIORITY_DEFAULT, rss_logo_callback, channel_data);
 				got_image = TRUE;
 				xmlFree (image_uri);
 			}
@@ -1448,7 +1449,8 @@ extract_scripting_news_image (RSSChannelData *channel_data, xmlDoc *rss_document
 		if (image_node != NULL) {
 			image_uri = xmlNodeGetContent (image_node);
 			if (image_uri != NULL) {
-				channel_data->load_image_handle = eel_gdk_pixbuf_load_async (image_uri, rss_logo_callback, channel_data);
+				channel_data->load_image_handle = eel_gdk_pixbuf_load_async (image_uri, 
+						GNOME_VFS_PRIORITY_DEFAULT, rss_logo_callback, channel_data);
 				got_image = TRUE;
 				xmlFree (image_uri);
 			}
@@ -1488,7 +1490,7 @@ rss_read_done_callback (GnomeVFSResult result,
 	/* flag the update time */
 	time (&channel_data->last_update);
 
-	/* Parse the rss file with gnome-xml. The gnome-xml parser requires a zero-terminated array. */
+	/* Parse the rss file with libxml. The libxml parser requires a zero-terminated array. */
 	buffer = g_realloc (file_contents, file_size + 1);
 	buffer[file_size] = '\0';
 	rss_document = xmlParseMemory (buffer, file_size);
@@ -1519,7 +1521,8 @@ rss_read_done_callback (GnomeVFSResult result,
 	old_items = channel_data->items;
 	channel_data->items = NULL;
 		
-	current_node = rss_document->root;
+	current_node = xmlDocGetRootElement (rss_document);
+
 	item_count = extract_items (channel_data, current_node);
 	
 	/* if we couldn't find any items at the main level, look inside the channel node */
@@ -1556,7 +1559,8 @@ nautilus_news_load_channel (News *news_data, RSSChannelData *channel_data)
 	
 	/* load the uri asynchronously, calling a completion routine when completed */
 	channel_data->update_in_progress = TRUE;
-	channel_data->load_file_handle = eel_read_entire_file_async (channel_data->uri, rss_read_done_callback, channel_data);
+	channel_data->load_file_handle = eel_read_entire_file_async (channel_data->uri, 
+			GNOME_VFS_PRIORITY_DEFAULT, rss_read_done_callback, channel_data);
 	
 	/* put up a title that's displayed while we wait */
 	title = g_strdup_printf (_("Loading %s"), channel_data->name);
@@ -1611,7 +1615,7 @@ nautilus_news_add_channels (News *news_data, xmlDocPtr channels)
 	/* walk through the children of the root object, generating new channel
 	 * objects and adding them to the channel list 
 	 */
-	current_channel = xmlDocGetRootElement (channels)->childs;
+	current_channel = xmlDocGetRootElement (channels)->children;
 	while (current_channel != NULL) {
 		if (eel_strcmp (current_channel->name, "rss_channel") == 0) { 				
 			name = xmlGetProp (current_channel, "name");
@@ -1674,6 +1678,7 @@ read_channel_list (News *news_data)
 {
 	char *path;
 	xmlDocPtr channel_doc;
+
 	/* free the old channel data, if any  */
 	nautilus_news_free_channel_list (news_data);
 	
@@ -1686,7 +1691,7 @@ read_channel_list (News *news_data)
 			nautilus_news_add_channels (news_data, channel_doc);
 			xmlFreeDoc (channel_doc);
 		}
-	g_free (path);
+                g_free (path);
 	}
 }
 
@@ -1732,7 +1737,7 @@ static void
 load_xpm_image (GdkPixbuf** image_result, const char** image_name)
 {
 	if (*image_result != NULL) {
-		gdk_pixbuf_unref (*image_result);
+		g_object_unref (*image_result);
 	}
 	*image_result = gdk_pixbuf_new_from_xpm_data (image_name);
 }
@@ -1749,22 +1754,22 @@ nautilus_news_load_images (News *news_data)
 	load_xpm_image (&news_data->open_triangle_changed, (const char**) open_triangle_changed_xpm);
 	
 	if (news_data->bullet != NULL) {
-		gdk_pixbuf_unref (news_data->bullet);
+		g_object_unref (news_data->bullet);
 	}
 	
 	news_bullet_path = nautilus_theme_get_image_path ("news_bullet.png");	
 	if (news_bullet_path != NULL) {
-		news_data->bullet = gdk_pixbuf_new_from_file (news_bullet_path);
+		news_data->bullet = gdk_pixbuf_new_from_file (news_bullet_path, NULL);
 		g_free (news_bullet_path);
 	}
 
 	if (news_data->changed_bullet != NULL) {
-		gdk_pixbuf_unref (news_data->changed_bullet);
+		g_object_unref (news_data->changed_bullet);
 	}
 	
 	news_bullet_path = nautilus_theme_get_image_path ("changed_bullet.png");	
 	if (news_bullet_path != NULL) {
-		news_data->changed_bullet = gdk_pixbuf_new_from_file (news_bullet_path);
+		news_data->changed_bullet = gdk_pixbuf_new_from_file (news_bullet_path, NULL);
 		g_free (news_bullet_path);
 	}
 
@@ -1891,8 +1896,8 @@ add_site_from_fields (GtkWidget *widget, News *news)
 	int channel_count, byte_count;
 	gboolean got_xml_file;
 	
-	site_name = gtk_entry_get_text (GTK_ENTRY (news->item_name_field));
-	site_location = gtk_entry_get_text (GTK_ENTRY (news->item_location_field));
+	site_name = (char *) gtk_entry_get_text (GTK_ENTRY (news->item_name_field));
+	site_location = (char *)gtk_entry_get_text (GTK_ENTRY (news->item_location_field));
 
 	/* make sure there's something in the fields */
 	if (site_name == NULL || strlen (site_name) == 0) {
@@ -2002,14 +2007,14 @@ add_command_buttons (News *news_data, const char* label, gboolean from_configure
 		button = gtk_button_new_with_label (_("Edit"));
 		gtk_container_add (GTK_CONTAINER (button_box), button);
 
-		gtk_signal_connect (GTK_OBJECT (button), "clicked",
+		g_signal_connect (button, "clicked",
 		      (GtkSignalFunc) add_site_button_clicked, news_data);
 	}
 	
-	button = gtk_button_new_with_label (label);
+	button = gtk_button_new_from_stock (label);
 	gtk_container_add (GTK_CONTAINER (button_box), button);
 
-	gtk_signal_connect (GTK_OBJECT (button), "clicked",
+	g_signal_connect (button, "clicked",
 		      (GtkSignalFunc) configure_button_clicked, news_data);
 		      	
 	return frame;
@@ -2042,7 +2047,7 @@ check_button_toggled_callback (GtkToggleButton *toggle_button, gpointer user_dat
 	RSSChannelData *channel_data;
 	
 	news_data = (News*) user_data;
-	channel_name = gtk_object_get_data (GTK_OBJECT (toggle_button), "channel_name");
+	channel_name = g_object_get_data (G_OBJECT (toggle_button), "channel_name");
 	
 	channel_data = get_channel_from_name (news_data, channel_name);
 	if (channel_data != NULL) { 
@@ -2078,7 +2083,7 @@ determine_sort_position (GtkWidget *container, const char *name)
 	index = 0;
 	current_item = checkboxes;
 	while (current_item != NULL) {
-		current_name = gtk_object_get_data (GTK_OBJECT (current_item->data), "channel_name");
+		current_name = g_object_get_data (G_OBJECT (current_item->data), "channel_name");
 		
 		if (eel_strcasecmp (current_name, name) > 0) {
 			g_list_free (checkboxes);
@@ -2104,8 +2109,8 @@ add_channel_entry (News *news_data, const char *channel_name, int index, gboolea
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_button), is_showing);
 	gtk_box_pack_start (GTK_BOX (news_data->checkbox_list), check_button, FALSE, FALSE, 0);
 
-	gtk_signal_connect (GTK_OBJECT (check_button), "toggled",
-      	              	    			GTK_SIGNAL_FUNC (check_button_toggled_callback),
+	g_signal_connect (check_button, "toggled",
+      	              	    			G_CALLBACK (check_button_toggled_callback),
                             			news_data);
 
 	/* reorder newly added button so it's sorted by it's name */
@@ -2120,10 +2125,10 @@ add_channel_entry (News *news_data, const char *channel_name, int index, gboolea
 	
 	/* set up user data to use in toggle handler */
         gtk_object_set_user_data (GTK_OBJECT (check_button), news_data);
-	gtk_object_set_data_full (GTK_OBJECT (check_button),
+	g_object_set_data_full (G_OBJECT(check_button),
 				  "channel_name",
 				  g_strdup (channel_name),
-				  (GtkDestroyNotify) g_free);
+				  g_free);
 }
 
 /* here's the routine that loads and parses the xml file, then iterates through it
@@ -2154,7 +2159,7 @@ add_channels_to_lists (News* news_data)
 	/* loop through the channel entries, adding an entry to the configure
 	 * list for each entry in the file
 	 */
-	current_channel = xmlDocGetRootElement (channel_doc)->childs;
+	current_channel = xmlDocGetRootElement (channel_doc)->children;
 	channel_index = 0;
 	while (current_channel != NULL) {
 		if (eel_strcmp (current_channel->name, "rss_channel") == 0) { 				
@@ -2187,7 +2192,9 @@ empty_message_size_allocate (GtkWidget *widget, GtkAllocation *allocation, News
 	
 	wrap_width = allocation->width - 2*EMPTY_MESSAGE_MARGIN;
 	if (wrap_width > 0) {
+#if GNOME2_CONVERSION_COMPLETE
 		eel_label_set_smooth_line_wrap_width (EEL_LABEL (widget), allocation->width - 2*EMPTY_MESSAGE_MARGIN);
+#endif
 	}
 }
 
@@ -2246,8 +2253,8 @@ make_remove_widgets (News *news, GtkWidget *container)
 	gtk_clist_set_selection_mode (GTK_CLIST (news->remove_site_list), GTK_SELECTION_BROWSE);		
 	gtk_clist_set_auto_sort (GTK_CLIST (news->remove_site_list), TRUE);
 	
-	gtk_signal_connect (GTK_OBJECT (news->remove_site_list), "select_row",
-			    GTK_SIGNAL_FUNC (select_row_in_remove_list), news);
+	g_signal_connect (news->remove_site_list, "select_row",
+			    G_CALLBACK (select_row_in_remove_list), news);
 			    
 	scrolled_window = GTK_SCROLLED_WINDOW (gtk_scrolled_window_new (NULL, NULL));
 	gtk_scrolled_window_set_policy (scrolled_window, GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);   
@@ -2264,8 +2271,8 @@ make_remove_widgets (News *news, GtkWidget *container)
 	
 	news->remove_button = gtk_button_new_with_label (_("Remove Site"));
 	gtk_container_add (GTK_CONTAINER (button_box), news->remove_button);
-	gtk_signal_connect (GTK_OBJECT (news->remove_button), "clicked",
-		(GtkSignalFunc) remove_selected_site, news);
+	g_signal_connect (news->remove_button, "clicked",
+                            (GtkSignalFunc) remove_selected_site, news);
 }
 
 /* generate the add new site widgets */
@@ -2309,7 +2316,7 @@ make_add_widgets (News *news, GtkWidget *container)
 	
 	button = gtk_button_new_with_label (_("Add New Site"));
 	gtk_container_add (GTK_CONTAINER (button_box), button);
-	gtk_signal_connect (GTK_OBJECT (button), "clicked",
+	g_signal_connect (button, "clicked",
 		(GtkSignalFunc) add_site_from_fields, news);
 }
 
@@ -2347,7 +2354,7 @@ set_up_edit_widgets (News *news, GtkWidget *container)
 	gtk_box_pack_start (GTK_BOX (expand_box), temp_vbox, TRUE, TRUE, 0);
 	
 	/* add the button box at the bottom with a cancel button */
-	button_box = add_command_buttons (news, _("Cancel"), FALSE);
+	button_box = add_command_buttons (news, GTK_STOCK_CANCEL, FALSE);
 	gtk_box_pack_start (GTK_BOX (news->edit_site_box), button_box, FALSE, FALSE, 0);	
 }
 
@@ -2407,26 +2414,25 @@ set_up_main_widgets (News *news, GtkWidget *container)
  	news->news_display_scrolled_window = scrolled_window;
 	
 	/* add the empty message */
-	news->empty_message = eel_label_new (_("The News panel displays current headlines from your favorite websites.  Click the \'Select Sites\' button to select the sites to display."));
-	eel_label_set_smooth_font_size (EEL_LABEL (news->empty_message), 14);
-	eel_label_set_justify (EEL_LABEL (news->empty_message), GTK_JUSTIFY_LEFT);
-	eel_label_set_wrap (EEL_LABEL (news->empty_message), TRUE);	
+	news->empty_message = gtk_label_new (_("The News panel displays current headlines from your favorite websites.  Click the \'Select Sites\' button to select the sites to display."));
+	eel_gtk_label_set_scale (GTK_LABEL (news->empty_message), PANGO_SCALE_LARGE);
+	gtk_label_set_line_wrap (GTK_LABEL (news->empty_message), TRUE);	
 
 	gtk_box_pack_start (GTK_BOX (news->main_box), news->empty_message, TRUE,
-		TRUE, 0);
+                            TRUE, 0);
 	
  	/* connect the appropriate signals for drawing and event handling */
- 	gtk_signal_connect (GTK_OBJECT (news->news_display), "expose_event",
-		      (GtkSignalFunc) nautilus_news_expose_event, news);
-  	gtk_signal_connect (GTK_OBJECT(news->news_display),"configure_event",
-		      (GtkSignalFunc) nautilus_news_configure_event, news);
-
-  	gtk_signal_connect (GTK_OBJECT (news->news_display), "motion_notify_event",
-		      (GtkSignalFunc) nautilus_news_motion_notify_event, news);
-  	gtk_signal_connect (GTK_OBJECT (news->news_display), "leave_notify_event",
-		      (GtkSignalFunc) nautilus_news_leave_notify_event, news);
-  	gtk_signal_connect (GTK_OBJECT (news->news_display), "button_release_event",
-		      (GtkSignalFunc) nautilus_news_button_release_event, news);
+ 	g_signal_connect (news->news_display, "expose_event",
+                          G_CALLBACK (nautilus_news_expose_event), news);
+  	g_signal_connect (news->news_display,"configure_event",
+                          G_CALLBACK (nautilus_news_configure_event), news);
+        
+  	g_signal_connect (news->news_display, "motion_notify_event",
+                          G_CALLBACK (nautilus_news_motion_notify_event), news);
+  	g_signal_connect (news->news_display, "leave_notify_event",
+                          G_CALLBACK (nautilus_news_leave_notify_event), news);
+  	g_signal_connect (news->news_display, "button_release_event",
+                          G_CALLBACK (nautilus_news_button_release_event), news);
 
   	gtk_widget_set_events (news->news_display, GDK_EXPOSURE_MASK
 			 | GDK_LEAVE_NOTIFY_MASK
@@ -2456,10 +2462,6 @@ make_news_view (const char *iid, gpointer callback_data)
 	set_up_configure_widgets (news, main_container);
 	set_up_edit_widgets (news, main_container);
 		
-	/* set up the fonts */
- 	news->font = eel_scalable_font_get_default_font ();
- 	news->bold_font = eel_scalable_font_get_default_bold_font ();
-       	
 	/* get preferences and sanity check them */
 	news->max_item_count = eel_preferences_get_integer (NAUTILUS_PREFERENCES_NEWS_MAX_ITEMS);
 	news->update_interval = 60 * eel_preferences_get_integer (NAUTILUS_PREFERENCES_NEWS_UPDATE_INTERVAL);	
@@ -2481,21 +2483,24 @@ make_news_view (const char *iid, gpointer callback_data)
 	news->timer_task = gtk_timeout_add (10000, check_for_updates, news);
 
 	/* arrange for notification when we're resized */
-	gtk_signal_connect (GTK_OBJECT (news->news_display), "size_allocate", news_display_size_allocate, news);
-	gtk_signal_connect (GTK_OBJECT (news->empty_message), "size_allocate", empty_message_size_allocate, news);
+	g_signal_connect (news->news_display, "size_allocate", G_CALLBACK (news_display_size_allocate), news);
+	g_signal_connect (news->empty_message, "size_allocate", G_CALLBACK (empty_message_size_allocate), news);
 		
 	/* Create the nautilus view CORBA object. */
         news->view = nautilus_view_new (main_container);
-        gtk_signal_connect (GTK_OBJECT (news->view), "destroy", do_destroy, news);
+        g_signal_connect (news->view, "destroy", G_CALLBACK (do_destroy), news);
 
-	gtk_signal_connect (GTK_OBJECT (news->view), "load_location",
-                            nautilus_news_load_location, news);
+	g_signal_connect (news->view, "load_location",
+                            G_CALLBACK (nautilus_news_load_location), news);
 
 	/* allocate a property bag to reflect the TAB_IMAGE property */
 	news->property_bag = bonobo_property_bag_new (get_bonobo_properties,  set_bonobo_properties, news);
+
+#ifdef GNOME2_CONVERSION_COMPLETE
 	bonobo_control_set_properties (nautilus_view_get_bonobo_control (news->view), news->property_bag);
+#endif
 	bonobo_property_bag_add (news->property_bag, "tab_image", TAB_IMAGE, BONOBO_ARG_STRING, NULL,
-				 "image indicating that the news has changed", 0);
+				 _("image indicating that the news has changed"), 0);
 	bonobo_property_bag_add (news->property_bag, "close", CLOSE_NOTIFY,
 				 BONOBO_ARG_BOOLEAN, NULL, "close notification", 0);
  	
@@ -2519,12 +2524,8 @@ make_news_view (const char *iid, gpointer callback_data)
 int
 main(int argc, char *argv[])
 {
-	/* Make criticals and warnings stop in the debugger if NAUTILUS_DEBUG is set.
-	 * Unfortunately, this has to be done explicitly for each domain.
-	 */
-	if (g_getenv("NAUTILUS_DEBUG") != NULL) {
-		eel_make_warnings_and_criticals_stop_in_debugger
-			(G_LOG_DOMAIN, g_log_domain_glib, "Gdk", "Gtk", "GnomeVFS", "GnomeUI", "Bonobo", NULL);
+	if (g_getenv ("NAUTILUS_DEBUG") != NULL) {
+		eel_make_warnings_and_criticals_stop_in_debugger ();
 	}
 	
         return nautilus_view_standard_main ("nautilus-news",
@@ -2536,6 +2537,6 @@ main(int argc, char *argv[])
                                             "OAFIID:nautilus_news_view_factory:041601",
                                             "OAFIID:nautilus_news_view:041601",
                                             make_news_view,
-                                            nautilus_global_preferences_initialize,
+                                            nautilus_global_preferences_init,
                                             NULL);
 }
