@@ -25,21 +25,18 @@
 
 #include <config.h>
 #include "nautilus-desktop-file-loader.h"
-#include "nautilus-program-choosing.h"
 
-#include <libgnome/libgnome.h>
-#include <libgnomevfs/gnome-vfs-ops.h>
+#include "nautilus-program-choosing.h"
 #include <eel/eel-gnome-extensions.h>
 #include <eel/eel-vfs-extensions.h>
-
-#include <string.h>
-#include <stdlib.h>
-#include <stdio.h>
 #include <errno.h>
-#include <ctype.h>
-#include <locale.h>
-#include <iconv.h>
 #include <langinfo.h>
+#include <libgnome/gnome-url.h>
+#include <libgnomevfs/gnome-vfs-ops.h>
+#include <locale.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 
 typedef struct NautilusDesktopFileSection NautilusDesktopFileSection;
 typedef struct NautilusDesktopFileAddition NautilusDesktopFileAddition;
@@ -294,50 +291,10 @@ nautilus_desktop_file_free (NautilusDesktopFile *df)
 }
 
 
-/* This is cut and pasted from glib 1.3.x
- * It should be removed when porting to glib 2
- */
-/**
- * g_strdupv:
- * @str_array: %NULL-terminated array of strings
- * 
- * Copies %NULL-terminated array of strings. The copy is a deep copy;
- * the new array should be freed by first freeing each string, then
- * the array itself. g_strfreev() does this for you. If called
- * on a %NULL value, g_strdupv() simply returns %NULL.
- * 
- * Return value: a new %NULL-terminated array of strings
- **/
-static gchar**
-cnp_g_strdupv (gchar **str_array)
-{
-        if (str_array) {
-                gint i;
-                gchar **retval;
-
-                i = 0;
-                while (str_array[i])
-                        ++i;
-          
-                retval = g_new (gchar*, i + 1);
-
-                i = 0;
-                while (str_array[i]) {
-                        retval[i] = g_strdup (str_array[i]);
-                        ++i;
-                }
-                retval[i] = NULL;
-
-                return retval;
-        } else {
-                return NULL;
-        }
-}
-
 char**
 nautilus_desktop_file_get_lines (NautilusDesktopFile *df)
 {
-        return cnp_g_strdupv (df->lines);
+        return g_strdupv (df->lines);
 }
 
 /* Custom hash functions allow us to avoid strdups */
@@ -352,17 +309,17 @@ key_equal (gconstpointer v1,
          * and don't count leading/trailing spaces
          */
 
-        while (isspace ((guchar)*p1)) {
+        while (g_ascii_isspace (*p1)) {
                 ++p1;
 	}
 
-        while (isspace ((guchar)*p2)) {
+        while (g_ascii_isspace (*p2)) {
                 ++p2;
 	}
   
         while (*p1 && *p2 &&
                *p1 != '=' && *p2 != '=' &&
-               !isspace ((guchar)*p1) && !isspace ((guchar)*p2)) {
+               !g_ascii_isspace (*p1) && !g_ascii_isspace (*p2)) {
                 if (*p1 != *p2) {
                         return FALSE;
 		}
@@ -371,11 +328,11 @@ key_equal (gconstpointer v1,
                 ++p2;
         }
 
-        if (*p1 && *p1 != '=' && !isspace ((guchar)*p1)) {
+        if (*p1 && *p1 != '=' && !g_ascii_isspace (*p1)) {
                 return FALSE;
 	}
 
-        if (*p2 && *p2 != '=' && !isspace ((guchar)*p2)) {
+        if (*p2 && *p2 != '=' && !g_ascii_isspace (*p2)) {
                 return FALSE;
 	}
   
@@ -392,12 +349,12 @@ key_hash (gconstpointer key)
          * and don't count leading/trailing spaces
          */
   
-        while (isspace ((guchar)*p)) {
+        while (g_ascii_isspace (*p)) {
                 ++p;
 	}
 
         if (h) {
-                for (p += 1; *p != '\0' && *p != '=' && !isspace ((guchar)*p); p++) {
+                for (p += 1; *p != '\0' && *p != '=' && !g_ascii_isspace (*p); p++) {
                         h = (h << 5) - h + *p;
 		}
 	}
@@ -470,7 +427,7 @@ hash_lines (NautilusDesktopFile *df)
         while (iter != NULL && *iter != NULL) {
                 p = *iter;
 
-                while (isspace ((guchar)*p)) {
+                while (g_ascii_isspace (*p)) {
                         ++p;
 		}
 
@@ -507,7 +464,7 @@ hash_lines (NautilusDesktopFile *df)
 			} else {
                                 if (current_sect) {
                                         ++eq;
-                                        while (isspace ((guchar)*eq)) {
+                                        while (g_ascii_isspace (*eq)) {
                                                 ++eq;
 					}
                                         /* could overwrite an earlier copy of
@@ -644,7 +601,7 @@ key_foreach (gpointer key, gpointer value, gpointer data)
         
         key_end = (char*) key;
         while (*key_end &&
-               !isspace ((guchar)*key_end) &&
+               !g_ascii_isspace (*key_end) &&
                *key_end != '=') {
                 ++key_end;
         }
@@ -1034,7 +991,7 @@ validated_strdup (const char *str)
         static gboolean initialized = FALSE;
         gchar *pout, *pin, *buf;
         gint len, ulen = 0, ib, ob;
-        iconv_t fd;
+        GIConv fd;
 
         G_LOCK (init_validate);
         if (!initialized) {
@@ -1049,7 +1006,7 @@ validated_strdup (const char *str)
         
         len = strlen (str);
         if (looks_utf8 (str, len, NULL, &ulen)) {
-                if ((fd = iconv_open (locale, "UTF-8")) != (iconv_t)-1) {
+                if ((fd = g_iconv_open (locale, "UTF-8")) != (GIConv)-1) {
                         ib = len;
                         ob = ib * 3;
                         pout = buf = g_new0 (gchar, ob);
@@ -1057,12 +1014,12 @@ validated_strdup (const char *str)
 
                         /* not portable either */
                         
-                        if (iconv (fd, &pin, &ib, &pout, &ob) == (size_t)-1) {
+                        if (g_iconv (fd, &pin, &ib, &pout, &ob) == (size_t)-1) {
                                 g_free (buf);
                                 buf = NULL;
                         }
 
-                        iconv_close (fd);
+                        g_iconv_close (fd);
                 }
         } else {
                 buf = g_strdup (str);
@@ -1071,24 +1028,6 @@ validated_strdup (const char *str)
         return buf;
 }
 
-/* This is cut and pasted from glib 1.3.x
- * It should be removed when porting to glib 2
- */
-static void
-cnp_g_string_append_len (GString *str,
-			 const char *s,
-			 int len)
-{
-	if (len < 0) {
-		g_string_append (str, s);
-	} else {
-		char *tmp;
-		tmp = g_strndup (s, len);
-		g_string_append (str, tmp);
-		g_free (tmp);
-	}
-}
-
 static char*
 nautilus_desktop_file_sub_formats (NautilusDesktopFile *df,
 				   const char *src)
@@ -1107,7 +1046,7 @@ nautilus_desktop_file_sub_formats (NautilusDesktopFile *df,
 	while (p) {
 		if (p != end) {
 			/* Append what we just scanned over */
-		        cnp_g_string_append_len (new, end, p - end);
+		        g_string_append_len (new, end, p - end);
 		}
 
 		end = p;
@@ -1172,7 +1111,7 @@ nautilus_desktop_file_launch (NautilusDesktopFile *df)
 		nautilus_desktop_file_get_string (df, NULL, "URL", &url);
 
 		if (url != NULL) {
-			gnome_url_show (url);
+			gnome_url_show (url, NULL);
 		}
 
 		g_free (url);
