@@ -19,7 +19,7 @@
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
   
-   Authors: Darin Adler <darin@eazel.com>,
+   Authors: Darin Adler <darin@bentspoon.com>,
             Mike Engber <engber@eazel.com>
 */
 
@@ -31,7 +31,7 @@
 #include "nautilus-directory-metafile-monitor.h"
 #include "nautilus-metafile-server.h"
 #include <eel/eel-string.h>
-#include <liboaf/liboaf.h>
+#include <bonobo-activation/bonobo-activation.h>
 #include <stdio.h>
 
 static Nautilus_MetafileFactory factory = CORBA_OBJECT_NIL;
@@ -51,14 +51,61 @@ free_factory (void)
 	bonobo_object_release_unref (factory, NULL);
 }
 
+
+static void
+die_on_failed_activation (const char *server_name,
+			  CORBA_Environment *ev)
+{
+	/* This isn't supposed to happen. So do some core-dumping
+	 * action, and don't bother translating the error message.
+	 */
+
+	const char *details;
+	Bonobo_GeneralError *general_error;
+
+	switch (ev->_major) {
+	case CORBA_NO_EXCEPTION:
+		details = "got NIL but no exception";
+		break;
+
+	case CORBA_SYSTEM_EXCEPTION:
+	case CORBA_USER_EXCEPTION:
+		details = CORBA_exception_id (ev);
+		if (strcmp (details, "IDL:Bonobo/GeneralError:1.0") == 0) {
+			general_error = CORBA_exception_value (ev);
+			details = general_error->description;
+		}
+		break;
+
+	default:
+		details = "got bad exception";
+		break;
+	}
+
+	g_error ("Failed to activate the server %s; this may indicate a broken\n"
+		 "Nautilus or Bonobo installation, or may reflect a bug in something,\n"
+		 "or may mean that your PATH or LD_LIBRARY_PATH or the like is\n"
+		 "incorrect. Nautilus will dump core and exit.\n"
+		 "Details: '%s'", server_name, details);
+}
+
 static Nautilus_MetafileFactory
 get_factory (void)
 {
 	NautilusMetafileFactory *instance;
-
+	CORBA_Environment ev;
+	
 	if (factory == CORBA_OBJECT_NIL) {
 		if (get_factory_from_oaf) {
-			factory = oaf_activate_from_id (METAFILE_FACTORY_IID, 0, NULL, NULL);
+			CORBA_exception_init (&ev);
+
+			factory = bonobo_activation_activate_from_id (METAFILE_FACTORY_IID, 0,
+							NULL, &ev);
+			if (ev._major != CORBA_NO_EXCEPTION || factory == CORBA_OBJECT_NIL) {
+				die_on_failed_activation ("Nautilus_MetafileFactory", &ev);
+			}
+
+			CORBA_exception_free (&ev);
 		} else {
 			instance = nautilus_metafile_factory_get_instance ();
 			factory = bonobo_object_dup_ref (bonobo_object_corba_objref (BONOBO_OBJECT (instance)), NULL);
@@ -70,25 +117,50 @@ get_factory (void)
 	return factory;
 }
 
+static Nautilus_Metafile
+open_metafile (const char *uri, gboolean make_errors_fatal)
+{
+	Nautilus_Metafile metafile;
+	CORBA_Environment ev;
+
+	CORBA_exception_init (&ev);
+	
+	metafile = Nautilus_MetafileFactory_open (get_factory (), (char *) uri, &ev);
+	
+	if (ev._major != CORBA_NO_EXCEPTION) {
+		metafile = CORBA_OBJECT_NIL;
+		if (make_errors_fatal) {
+			g_error ("%s: CORBA error opening MetafileFactory: %s",
+				 g_get_prgname (),
+				 CORBA_exception_id (&ev));
+		}
+	}
+	
+	CORBA_exception_free (&ev);
+
+	return metafile;
+}
+
 static Nautilus_Metafile
 get_metafile (NautilusDirectory *directory)
 {
 	char *uri;
-	CORBA_Environment ev;
 
 	if (directory->details->metafile_corba_object == CORBA_OBJECT_NIL) {
 		uri = nautilus_directory_get_uri (directory);
-	
-		CORBA_exception_init (&ev);
 
-		directory->details->metafile_corba_object = Nautilus_MetafileFactory_open (get_factory (), uri, &ev);
+		directory->details->metafile_corba_object = open_metafile (uri, !get_factory_from_oaf);
+		if (directory->details->metafile_corba_object == NULL) {
+			g_assert (get_factory_from_oaf);
+			factory = CORBA_OBJECT_NIL;
+			directory->details->metafile_corba_object = open_metafile (uri, TRUE);
+		}
 
-		/* FIXME bugzilla.eazel.com 6664: examine ev for errors */
-		CORBA_exception_free (&ev);
-	
 		g_free (uri);
 	}
 
+	g_assert (directory->details->metafile_corba_object != CORBA_OBJECT_NIL);
+	
 	return bonobo_object_dup_ref (directory->details->metafile_corba_object, NULL);	
 }
 
@@ -107,7 +179,7 @@ nautilus_directory_is_metadata_read (NautilusDirectory *directory)
 
 	result = Nautilus_Metafile_is_read (metafile, &ev);
 
-	/* FIXME bugzilla.eazel.com 6664: examine ev for errors */
+	/* FIXME bugzilla.gnome.org 46664: examine ev for errors */
 	CORBA_exception_free (&ev);
 	bonobo_object_release_unref (metafile, NULL);
 
@@ -139,7 +211,7 @@ nautilus_directory_get_file_metadata (NautilusDirectory *directory,
 
 	corba_value = Nautilus_Metafile_get (metafile, file_name, key, non_null_default, &ev);
 
-	/* FIXME bugzilla.eazel.com 6664: examine ev for errors */
+	/* FIXME bugzilla.gnome.org 46664: examine ev for errors */
 	CORBA_exception_free (&ev);
 	bonobo_object_release_unref (metafile, NULL);
 
@@ -180,7 +252,7 @@ nautilus_directory_get_file_metadata_list (NautilusDirectory *directory,
 
 	corba_value = Nautilus_Metafile_get_list (metafile, file_name, list_key, list_subkey, &ev);
 
-	/* FIXME bugzilla.eazel.com 6664: examine ev for errors */
+	/* FIXME bugzilla.gnome.org 46664: examine ev for errors */
 	CORBA_exception_free (&ev);
 	bonobo_object_release_unref (metafile, NULL);
 
@@ -222,7 +294,7 @@ nautilus_directory_set_file_metadata (NautilusDirectory *directory,
 
 	Nautilus_Metafile_set (metafile, file_name, key, default_metadata, metadata, &ev);
 
-	/* FIXME bugzilla.eazel.com 6664: examine ev for errors */
+	/* FIXME bugzilla.gnome.org 46664: examine ev for errors */
 	CORBA_exception_free (&ev);
 	bonobo_object_release_unref (metafile, NULL);
 }
@@ -272,7 +344,7 @@ nautilus_directory_set_file_metadata_list (NautilusDirectory *directory,
 
 	Nautilus_Metafile_set_list (metafile, file_name, list_key, list_subkey, corba_list, &ev);
 
-	/* FIXME bugzilla.eazel.com 6664: examine ev for errors */
+	/* FIXME bugzilla.gnome.org 46664: examine ev for errors */
 	CORBA_exception_free (&ev);
 	bonobo_object_release_unref (metafile, NULL);
 
@@ -330,6 +402,7 @@ nautilus_directory_get_integer_file_metadata (NautilusDirectory *directory,
 	char *result_as_string;
 	char *default_as_string;
 	int result;
+	char c;
 
 	default_as_string = g_strdup_printf ("%d", default_metadata);
 	result_as_string = nautilus_directory_get_file_metadata
@@ -341,7 +414,7 @@ nautilus_directory_get_integer_file_metadata (NautilusDirectory *directory,
 	if (result_as_string == NULL) {
 		result = default_metadata;
 	} else {
-		if (sscanf (result_as_string, " %d %*s", &result) != 1) {
+		if (sscanf (result_as_string, " %d %c", &result, &c) != 1) {
 			result = default_metadata;
 		}
 		g_free (result_as_string);
@@ -394,7 +467,7 @@ nautilus_directory_copy_file_metadata (NautilusDirectory *source_directory,
 
 	Nautilus_Metafile_copy (source_metafile, source_file_name, destination_uri, destination_file_name, &ev);
 
-	/* FIXME bugzilla.eazel.com 6664: examine ev for errors */
+	/* FIXME bugzilla.gnome.org 46664: examine ev for errors */
 	CORBA_exception_free (&ev);
 	bonobo_object_release_unref (source_metafile, NULL);
 
@@ -416,7 +489,7 @@ nautilus_directory_remove_file_metadata (NautilusDirectory *directory,
 
 	Nautilus_Metafile_remove (metafile, file_name, &ev);
 
-	/* FIXME bugzilla.eazel.com 6664: examine ev for errors */
+	/* FIXME bugzilla.gnome.org 46664: examine ev for errors */
 	CORBA_exception_free (&ev);
 	bonobo_object_release_unref (metafile, NULL);
 }
@@ -438,7 +511,7 @@ nautilus_directory_rename_file_metadata (NautilusDirectory *directory,
 
 	Nautilus_Metafile_rename (metafile, old_file_name, new_file_name, &ev);
 
-	/* FIXME bugzilla.eazel.com 6664: examine ev for errors */
+	/* FIXME bugzilla.gnome.org 46664: examine ev for errors */
 	CORBA_exception_free (&ev);
 	bonobo_object_release_unref (metafile, &ev);
 }
@@ -458,7 +531,7 @@ nautilus_directory_rename_directory_metadata (NautilusDirectory *directory,
 
 	Nautilus_Metafile_rename_directory (metafile, new_directory_uri, &ev);
 
-	/* FIXME bugzilla.eazel.com 6664: examine ev for errors */
+	/* FIXME bugzilla.gnome.org 46664: examine ev for errors */
 	CORBA_exception_free (&ev);
 	bonobo_object_release_unref (metafile, &ev);
 }
@@ -486,7 +559,7 @@ nautilus_directory_register_metadata_monitor (NautilusDirectory *directory)
 		 bonobo_object_corba_objref (BONOBO_OBJECT (directory->details->metafile_monitor)),
 		 &ev);
 
-	/* FIXME bugzilla.eazel.com 6664: examine ev for errors */
+	/* FIXME bugzilla.gnome.org 46664: examine ev for errors */
 	CORBA_exception_free (&ev);
 	bonobo_object_release_unref (metafile, NULL);
 }
@@ -509,7 +582,7 @@ nautilus_directory_unregister_metadata_monitor (NautilusDirectory *directory)
 		 bonobo_object_corba_objref (BONOBO_OBJECT (directory->details->metafile_monitor)),
 		 &ev);
 
-	/* FIXME bugzilla.eazel.com 6664: examine ev for errors */
+	/* FIXME bugzilla.gnome.org 46664: examine ev for errors */
 	CORBA_exception_free (&ev);
 	bonobo_object_release_unref (metafile, NULL);
 
