@@ -36,7 +36,6 @@
 #include "nautilus-metafile.h"
 #include "nautilus-trash-directory.h"
 #include "nautilus-vfs-directory.h"
-#include <ctype.h>
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-gtk-macros.h>
 #include <eel/eel-string.h>
@@ -63,64 +62,68 @@ static guint signals[LAST_SIGNAL];
 
 static GHashTable *directories;
 
-static void               nautilus_directory_destroy          (GtkObject              *object);
-static void               nautilus_directory_initialize       (gpointer                object,
+static void               nautilus_directory_finalize         (GObject                *object);
+static void               nautilus_directory_dispose          (GObject                *object);
+static void               nautilus_directory_init             (gpointer                object,
 							       gpointer                klass);
-static void               nautilus_directory_initialize_class (NautilusDirectoryClass *klass);
+static void               nautilus_directory_class_init (NautilusDirectoryClass *klass);
 static NautilusDirectory *nautilus_directory_new              (const char             *uri);
 static char *             real_get_name_for_self_as_new_file  (NautilusDirectory      *directory);
 static void               set_directory_uri                   (NautilusDirectory      *directory,
 							       const char             *new_uri);
 
-EEL_DEFINE_CLASS_BOILERPLATE (NautilusDirectory,
-				   nautilus_directory,
-				   GTK_TYPE_OBJECT)
+EEL_CLASS_BOILERPLATE (NautilusDirectory,
+		       nautilus_directory,
+		       GTK_TYPE_OBJECT)
 
 static void
-nautilus_directory_initialize_class (NautilusDirectoryClass *klass)
+nautilus_directory_class_init (NautilusDirectoryClass *klass)
 {
-	GtkObjectClass *object_class;
+	GObjectClass *object_class;
 
-	object_class = GTK_OBJECT_CLASS (klass);
+	object_class = G_OBJECT_CLASS (klass);
 	
-	object_class->destroy = nautilus_directory_destroy;
+	object_class->finalize = nautilus_directory_finalize;
+	object_class->dispose  = nautilus_directory_dispose;
 
 	signals[FILES_ADDED] =
-		gtk_signal_new ("files_added",
-				GTK_RUN_LAST,
-				object_class->type,
-				GTK_SIGNAL_OFFSET (NautilusDirectoryClass, files_added),
-				gtk_marshal_NONE__POINTER,
-				GTK_TYPE_NONE, 1, GTK_TYPE_POINTER);
+		g_signal_new ("files_added",
+		              G_TYPE_FROM_CLASS (object_class),
+		              G_SIGNAL_RUN_LAST,
+		              G_STRUCT_OFFSET (NautilusDirectoryClass, files_added),
+		              NULL, NULL,
+		              gtk_marshal_VOID__POINTER,
+		              G_TYPE_NONE, 1, G_TYPE_POINTER);
 	signals[FILES_CHANGED] =
-		gtk_signal_new ("files_changed",
-				GTK_RUN_LAST,
-				object_class->type,
-				GTK_SIGNAL_OFFSET (NautilusDirectoryClass, files_changed),
-				gtk_marshal_NONE__POINTER,
-				GTK_TYPE_NONE, 1, GTK_TYPE_POINTER);
+		g_signal_new ("files_changed",
+		              G_TYPE_FROM_CLASS (object_class),
+		              G_SIGNAL_RUN_LAST,
+		              G_STRUCT_OFFSET (NautilusDirectoryClass, files_changed),
+		              NULL, NULL,
+		              gtk_marshal_VOID__POINTER,
+		              G_TYPE_NONE, 1, G_TYPE_POINTER);
 	signals[DONE_LOADING] =
-		gtk_signal_new ("done_loading",
-				GTK_RUN_LAST,
-				object_class->type,
-				GTK_SIGNAL_OFFSET (NautilusDirectoryClass, done_loading),
-				gtk_marshal_NONE__NONE,
-				GTK_TYPE_NONE, 0);
+		g_signal_new ("done_loading",
+		              G_TYPE_FROM_CLASS (object_class),
+		              G_SIGNAL_RUN_LAST,
+		              G_STRUCT_OFFSET (NautilusDirectoryClass, done_loading),
+		              NULL, NULL,
+		              gtk_marshal_VOID__VOID,
+		              G_TYPE_NONE, 0);
 	signals[LOAD_ERROR] =
-		gtk_signal_new ("load_error",
-				GTK_RUN_LAST,
-				object_class->type,
-				GTK_SIGNAL_OFFSET (NautilusDirectoryClass, load_error),
-				gtk_marshal_NONE__INT,
-				GTK_TYPE_NONE, 1, GTK_TYPE_INT);
-	
-	gtk_object_class_add_signals (object_class, signals, LAST_SIGNAL);
+		g_signal_new ("load_error",
+		              G_TYPE_FROM_CLASS (object_class),
+		              G_SIGNAL_RUN_LAST,
+		              G_STRUCT_OFFSET (NautilusDirectoryClass, load_error),
+		              NULL, NULL,
+		              gtk_marshal_VOID__INT,
+		              G_TYPE_NONE, 1, G_TYPE_INT);
 
 	klass->get_name_for_self_as_new_file = real_get_name_for_self_as_new_file;
 }
 
 static void
-nautilus_directory_initialize (gpointer object, gpointer klass)
+nautilus_directory_init (gpointer object, gpointer klass)
 {
 	NautilusDirectory *directory;
 
@@ -142,7 +145,7 @@ nautilus_directory_ref (NautilusDirectory *directory)
 
 	g_return_if_fail (NAUTILUS_IS_DIRECTORY (directory));
 
-	gtk_object_ref (GTK_OBJECT (directory));
+	g_object_ref (directory);
 }
 
 void
@@ -154,16 +157,18 @@ nautilus_directory_unref (NautilusDirectory *directory)
 
 	g_return_if_fail (NAUTILUS_IS_DIRECTORY (directory));
 
-	gtk_object_unref (GTK_OBJECT (directory));
+	g_object_unref (directory);
 }
 
 static void
-nautilus_directory_destroy (GtkObject *object)
+nautilus_directory_dispose (GObject *object)
 {
 	NautilusDirectory *directory;
 
 	directory = NAUTILUS_DIRECTORY (object);
 
+	g_hash_table_remove (directories, directory->details->uri);
+
 	nautilus_directory_cancel (directory);
 	g_assert (directory->details->count_in_progress == NULL);
 	g_assert (directory->details->top_left_read_state == NULL);
@@ -171,32 +176,49 @@ nautilus_directory_destroy (GtkObject *object)
 	if (directory->details->monitor_list != NULL) {
 		g_warning ("destroying a NautilusDirectory while it's being monitored");
 		eel_g_list_free_deep (directory->details->monitor_list);
+		directory->details->monitor_list = NULL;
 	}
 
 	if (directory->details->monitor != NULL) {
 		nautilus_monitor_cancel (directory->details->monitor);
+		directory->details->monitor = NULL;
 	}
 
 	if (directory->details->metafile_monitor != NULL) {
 		nautilus_directory_unregister_metadata_monitor (directory);
+		directory->details->metafile_monitor = NULL;
 	}
 
-	if (directory->details->metafile_corba_object != CORBA_OBJECT_NIL) {
-		bonobo_object_release_unref (directory->details->metafile_corba_object, NULL);
-	}
-
-	g_hash_table_remove (directories, directory->details->uri);
+	directory->details->metafile_corba_object =
+		bonobo_object_release_unref (
+			directory->details->metafile_corba_object, NULL);
 
 	if (directory->details->dequeue_pending_idle_id != 0) {
 		gtk_idle_remove (directory->details->dequeue_pending_idle_id);
+		directory->details->dequeue_pending_idle_id = 0;
 	}
  
 	g_free (directory->details->uri);
+	directory->details->uri = NULL;
+
 	if (directory->details->vfs_uri != NULL) {
 		gnome_vfs_uri_unref (directory->details->vfs_uri);
+		directory->details->vfs_uri = NULL;
 	}
+
+	EEL_CALL_PARENT (G_OBJECT_CLASS, dispose, (object));
+}
+
+static void
+nautilus_directory_finalize (GObject *object)
+{
+	NautilusDirectory *directory;
+
+	directory = NAUTILUS_DIRECTORY (object);
+
 	g_assert (directory->details->file_list == NULL);
 	g_hash_table_destroy (directory->details->file_hash);
+
 	nautilus_file_queue_destroy (directory->details->high_priority_queue);
 	nautilus_file_queue_destroy (directory->details->low_priority_queue);
 	nautilus_idle_queue_destroy (directory->details->idle_queue);
@@ -207,7 +229,7 @@ nautilus_directory_destroy (GtkObject *object)
 
 	g_free (directory->details);
 
-	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
 static void
@@ -484,11 +506,11 @@ nautilus_directory_new (const char *uri)
 	g_assert (uri != NULL);
 
 	if (eel_uri_is_trash (uri)) {
-		directory = NAUTILUS_DIRECTORY (gtk_object_new (NAUTILUS_TYPE_TRASH_DIRECTORY, NULL));
+		directory = NAUTILUS_DIRECTORY (g_object_new (NAUTILUS_TYPE_TRASH_DIRECTORY, NULL));
 	} else {
-		directory = NAUTILUS_DIRECTORY (gtk_object_new (NAUTILUS_TYPE_VFS_DIRECTORY, NULL));
+		directory = NAUTILUS_DIRECTORY (g_object_new (NAUTILUS_TYPE_VFS_DIRECTORY, NULL));
 	}
-	gtk_object_ref (GTK_OBJECT (directory));
+	g_object_ref (directory);
 	gtk_object_sink (GTK_OBJECT (directory));
 
 	set_directory_uri (directory, uri);
@@ -667,7 +689,6 @@ nautilus_directory_find_file_by_internal_uri (NautilusDirectory *directory,
 		result = nautilus_directory_get_existing_corresponding_file (directory);
 		if (result != NULL) {
 			nautilus_file_unref (result);
-			g_return_val_if_fail (!GTK_OBJECT_DESTROYED (result), NULL);
 		}
 	} else {
 		result = nautilus_directory_find_file_by_relative_uri (directory, relative_uri);
@@ -681,8 +702,8 @@ nautilus_directory_emit_files_added (NautilusDirectory *directory,
 				     GList *added_files)
 {
 	if (added_files != NULL) {
-		gtk_signal_emit (GTK_OBJECT (directory),
-				 signals[FILES_ADDED],
+		g_signal_emit (directory,
+				 signals[FILES_ADDED], 0,
 				 added_files);
 	}
 }
@@ -692,8 +713,8 @@ nautilus_directory_emit_files_changed (NautilusDirectory *directory,
 				       GList *changed_files)
 {
 	if (changed_files != NULL) {
-		gtk_signal_emit (GTK_OBJECT (directory),
-				 signals[FILES_CHANGED],
+		g_signal_emit (directory,
+				 signals[FILES_CHANGED], 0,
 				 changed_files);
 	}
 }
@@ -713,16 +734,16 @@ nautilus_directory_emit_change_signals (NautilusDirectory *directory,
 void
 nautilus_directory_emit_done_loading (NautilusDirectory *directory)
 {
-	gtk_signal_emit (GTK_OBJECT (directory),
-			 signals[DONE_LOADING]);
+	g_signal_emit (directory,
+			 signals[DONE_LOADING], 0);
 }
 
 void
 nautilus_directory_emit_load_error (NautilusDirectory *directory,
 				    GnomeVFSResult error_result)
 {
-	gtk_signal_emit (GTK_OBJECT (directory),
-			 signals[LOAD_ERROR],
+	g_signal_emit (directory,
+			 signals[LOAD_ERROR], 0,
 			 error_result);
 }
 
@@ -800,8 +821,8 @@ call_files_added_free_list (gpointer key, gpointer value, gpointer user_data)
 	g_assert (value != NULL);
 	g_assert (user_data == NULL);
 
-	gtk_signal_emit (GTK_OBJECT (key),
-			 signals[FILES_ADDED],
+	g_signal_emit (key,
+			 signals[FILES_ADDED], 0,
 			 value);
 	g_list_free (value);
 }
@@ -1562,7 +1583,7 @@ nautilus_directory_list_ref (GList *list)
 void
 nautilus_directory_list_unref (GList *list)
 {
-	eel_g_list_safe_for_each (list, (GFunc) nautilus_directory_unref, NULL);
+	g_list_foreach (list, (GFunc) nautilus_directory_unref, NULL);
 }
 
 /**
