@@ -30,7 +30,6 @@
 #include "nautilus-file-operations-progress.h"
 #include "nautilus-lib-self-check-functions.h"
 
-#include <eel/eel-gdk-font-extensions.h>
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-stock-dialogs.h>
@@ -102,8 +101,7 @@ transfer_info_destroy (TransferInfo *transfer_info)
 	}
 	
 	if (transfer_info->debuting_uris != NULL) {
-		eel_g_hash_table_destroy_deep_custom
-			(transfer_info->debuting_uris, (GFunc) g_free, NULL, NULL, NULL);
+		g_hash_table_destroy (transfer_info->debuting_uris);
 	}
 	
 	g_free (transfer_info);
@@ -196,14 +194,8 @@ icon_position_iterator_get_next (IconPositionIterator *position_iterator,
 	return TRUE;
 }
 
-/* Hack to get the GdkFont used by a GtkLabel in an error dialog.
- * We need to do this because the string truncation needs to be
- * done before a dialog is instantiated.
- * 
- * This is probably not super fast but it is not a problem in the
- * context we are using it, truncating a string while displaying an
- * error dialog.
- */
+#if GNOME2_CONVERSION_COMPLETE
+
 static GdkFont *
 get_label_font (void)
 {
@@ -225,12 +217,15 @@ get_label_font (void)
 	return font;
 }
 
+#endif
+
 static char *
 ellipsize_string_for_dialog (const char *str)
 {
+	char *result;
+#ifdef GNOME2_CONVERSION_COMPLETE
 	GdkFont *font;
 	int maximum_width;
-	char *result;
 
 	/* get a nice length to ellipsize to, based on the font */
 	font = get_label_font ();
@@ -238,6 +233,9 @@ ellipsize_string_for_dialog (const char *str)
 
 	result = eel_string_ellipsize (str, font, maximum_width, EEL_ELLIPSIZE_MIDDLE);
 	gdk_font_unref (font);
+#else
+	result = g_strdup (str);
+#endif
 
 	return result;
 }
@@ -333,11 +331,16 @@ center_dialog_over_window (GtkWindow *window, GtkWindow *over)
 	center_dialog_over_rect (window, rect);
 }
 
-static gboolean
-handle_close_callback (GnomeDialog *dialog, TransferInfo *tranfer_info)
+static void
+handle_response_callback (GtkDialog *dialog, int response, TransferInfo *transfer_info)
 {
-	tranfer_info->cancelled = TRUE;
-	return FALSE;
+	transfer_info->cancelled = TRUE;
+}
+
+static void
+handle_close_callback (GtkDialog *dialog, TransferInfo *transfer_info)
+{
+	transfer_info->cancelled = TRUE;
 }
 
 static void
@@ -356,14 +359,14 @@ create_transfer_dialog (const GnomeVFSXferProgressInfo *progress_info,
 	/* Treat clicking on the close box or use of the escape key
 	 * the same as clicking cancel.
 	 */
-	gtk_signal_connect (GTK_OBJECT (transfer_info->progress_dialog),
-			    "clicked",
-			    GTK_SIGNAL_FUNC (gnome_dialog_close),
-			    NULL);
-	gtk_signal_connect (GTK_OBJECT (transfer_info->progress_dialog),
-			    "close",
-			    GTK_SIGNAL_FUNC (handle_close_callback),
-			    transfer_info);
+	g_signal_connect (transfer_info->progress_dialog,
+			  "response",
+			  G_CALLBACK (handle_response_callback),
+			  NULL);
+	g_signal_connect (transfer_info->progress_dialog,
+			  "close",
+			  G_CALLBACK (handle_close_callback),
+			  transfer_info);
 
 	/* Make the progress dialog show up over the window we are copying into */
 	if (transfer_info->parent_view != NULL) {
@@ -452,7 +455,8 @@ handle_transfer_ok (const GnomeVFSXferProgressInfo *progress_info,
 		/* If cancelled, delete any partially copied files that are laying
 		 * around and return.
 		 */
-		if (progress_info->bytes_total != progress_info->bytes_copied) {
+		if (progress_info->target_name != NULL
+		    && progress_info->bytes_total != progress_info->bytes_copied) {
 			GList *delete_me;
 
 			delete_me = g_list_prepend (NULL, progress_info->target_name);
@@ -771,8 +775,8 @@ build_error_string (const char *source_name, const char *target_name,
 		/* None of the specific error messages apply, use a catch-all
 		 * generic error
 		 */
-		g_message ("Please tell pavel@eazel.com that you hit case %s while doing "
-			"a file operation.", gnome_vfs_result_to_string (error));
+		g_message ("Hit unexpected error \"%s\" while doing a file operation.",
+			   gnome_vfs_result_to_string (error));
 
 		/* FIXMEs: we need to consider a single item
 		 * move/copy and not offer to continue in that case
@@ -1084,7 +1088,7 @@ handle_transfer_overwrite (const GnomeVFSXferProgressInfo *progress_info,
 		}
 		
 		eel_run_simple_dialog (parent_for_error_dialog (transfer_info), TRUE, text,
-					_("Unable to replace file."), _("OK"), NULL, NULL);
+				       _("Unable to replace file."), GTK_STOCK_OK, NULL, NULL);
 
 		g_free (text);
 		g_free (formatted_name);
@@ -1224,17 +1228,30 @@ get_link_name (char *name, int count)
 static const char untranslated_copy_duplicate_tag[] = N_(" (copy)");
 /* localizers: tag used to detect the second copy of a file */
 static const char untranslated_another_copy_duplicate_tag[] = N_(" (another copy)");
+
+/* localizers: tag used to detect the x11th copy of a file */
+static const char untranslated_x11th_copy_duplicate_tag[] = N_("th copy)");
+/* localizers: tag used to detect the x12th copy of a file */
+static const char untranslated_x12th_copy_duplicate_tag[] = N_("th copy)");
+/* localizers: tag used to detect the x13th copy of a file */
+static const char untranslated_x13th_copy_duplicate_tag[] = N_("th copy)");
+
 /* localizers: tag used to detect the x1st copy of a file */
 static const char untranslated_st_copy_duplicate_tag[] = N_("st copy)");
 /* localizers: tag used to detect the x2nd copy of a file */
 static const char untranslated_nd_copy_duplicate_tag[] = N_("nd copy)");
 /* localizers: tag used to detect the x3rd copy of a file */
 static const char untranslated_rd_copy_duplicate_tag[] = N_("rd copy)");
+
 /* localizers: tag used to detect the xxth copy of a file */
 static const char untranslated_th_copy_duplicate_tag[] = N_("th copy)");
 
 #define COPY_DUPLICATE_TAG _(untranslated_copy_duplicate_tag)
 #define ANOTHER_COPY_DUPLICATE_TAG _(untranslated_another_copy_duplicate_tag)
+#define X11TH_COPY_DUPLICATE_TAG _(untranslated_x11th_copy_duplicate_tag)
+#define X12TH_COPY_DUPLICATE_TAG _(untranslated_x12th_copy_duplicate_tag)
+#define X13TH_COPY_DUPLICATE_TAG _(untranslated_x13th_copy_duplicate_tag)
+
 #define ST_COPY_DUPLICATE_TAG _(untranslated_st_copy_duplicate_tag)
 #define ND_COPY_DUPLICATE_TAG _(untranslated_nd_copy_duplicate_tag)
 #define RD_COPY_DUPLICATE_TAG _(untranslated_rd_copy_duplicate_tag)
@@ -1244,6 +1261,14 @@ static const char untranslated_th_copy_duplicate_tag[] = N_("th copy)");
 static const char untranslated_first_copy_duplicate_format[] = N_("%s (copy)%s");
 /* localizers: appended to second file copy */
 static const char untranslated_second_copy_duplicate_format[] = N_("%s (another copy)%s");
+
+/* localizers: appended to x11th file copy */
+static const char untranslated_x11th_copy_duplicate_format[] = N_("%s (%dth copy)%s");
+/* localizers: appended to x12th file copy */
+static const char untranslated_x12th_copy_duplicate_format[] = N_("%s (%dth copy)%s");
+/* localizers: appended to x13th file copy */
+static const char untranslated_x13th_copy_duplicate_format[] = N_("%s (%dth copy)%s");
+
 /* localizers: appended to x1st file copy */
 static const char untranslated_st_copy_duplicate_format[] = N_("%s (%dst copy)%s");
 /* localizers: appended to x2nd file copy */
@@ -1255,6 +1280,10 @@ static const char untranslated_th_copy_duplicate_format[] = N_("%s (%dth copy)%s
 
 #define FIRST_COPY_DUPLICATE_FORMAT _(untranslated_first_copy_duplicate_format)
 #define SECOND_COPY_DUPLICATE_FORMAT _(untranslated_second_copy_duplicate_format)
+#define X11TH_COPY_DUPLICATE_FORMAT _(untranslated_x11th_copy_duplicate_format)
+#define X12TH_COPY_DUPLICATE_FORMAT _(untranslated_x12th_copy_duplicate_format)
+#define X13TH_COPY_DUPLICATE_FORMAT _(untranslated_x13th_copy_duplicate_format)
+
 #define ST_COPY_DUPLICATE_FORMAT _(untranslated_st_copy_duplicate_format)
 #define ND_COPY_DUPLICATE_FORMAT _(untranslated_nd_copy_duplicate_format)
 #define RD_COPY_DUPLICATE_FORMAT _(untranslated_rd_copy_duplicate_format)
@@ -1320,8 +1349,18 @@ parse_previous_duplicate_name (const char *name,
 
 
 	/* Check to see if we got one of st, nd, rd, th. */
+	tag = strstr (name, X11TH_COPY_DUPLICATE_TAG);
 
-	tag = strstr (name, ST_COPY_DUPLICATE_TAG);
+	if (tag == NULL) {
+		tag = strstr (name, X12TH_COPY_DUPLICATE_TAG);
+	}
+	if (tag == NULL) {
+		tag = strstr (name, X13TH_COPY_DUPLICATE_TAG);
+	}
+
+	if (tag == NULL) {
+		tag = strstr (name, ST_COPY_DUPLICATE_TAG);
+	}
 	if (tag == NULL) {
 		tag = strstr (name, ND_COPY_DUPLICATE_TAG);
 	}
@@ -1377,6 +1416,7 @@ make_next_duplicate_name (const char *base, const char *suffix, int count)
 	}
 
 	if (count <= 2) {
+
 		/* Handle special cases for low numbers.
 		 * Perhaps for some locales we will need to add more.
 		 */
@@ -1399,22 +1439,42 @@ make_next_duplicate_name (const char *base, const char *suffix, int count)
 		 * For locales where getting this exactly right is difficult,
 		 * these can just be made all the same as the general case below.
 		 */
-		switch (count % 10) {
-		case 1:
-			format = ST_COPY_DUPLICATE_FORMAT;
+
+		/* Handle special cases for x11th - x20th.
+		 */
+		switch (count % 100) {
+		case 11:
+			format = X11TH_COPY_DUPLICATE_FORMAT;
 			break;
-		case 2:
-			format = ND_COPY_DUPLICATE_FORMAT;
+		case 12:
+			format = X12TH_COPY_DUPLICATE_FORMAT;
 			break;
-		case 3:
-			format = RD_COPY_DUPLICATE_FORMAT;
+		case 13:
+			format = X13TH_COPY_DUPLICATE_FORMAT;
 			break;
 		default:
-			/* The general case. */
-			format = TH_COPY_DUPLICATE_FORMAT;
+			format = NULL;
 			break;
 		}
 
+		if (format == NULL) {
+			switch (count % 10) {
+			case 1:
+				format = ST_COPY_DUPLICATE_FORMAT;
+				break;
+			case 2:
+				format = ND_COPY_DUPLICATE_FORMAT;
+				break;
+			case 3:
+				format = RD_COPY_DUPLICATE_FORMAT;
+				break;
+			default:
+				/* The general case. */
+				format = TH_COPY_DUPLICATE_FORMAT;
+				break;
+			}
+		}
+
 		result = g_strdup_printf (format, base, count, suffix);
 	}
 
@@ -1563,9 +1623,9 @@ sync_transfer_callback (GnomeVFSXferProgressInfo *progress_info, gpointer data)
 							    progress_info->target_name);
 				}
 				if (debuting_uris != NULL) {
-					g_hash_table_insert (debuting_uris,
-							     g_strdup (progress_info->target_name),
-							     GINT_TO_POINTER (TRUE));
+					g_hash_table_replace (debuting_uris,
+							      g_strdup (progress_info->target_name),
+							      GINT_TO_POINTER (TRUE));
 				}
 			}
 			nautilus_file_changes_queue_file_added (progress_info->target_name);
@@ -1596,9 +1656,9 @@ sync_transfer_callback (GnomeVFSXferProgressInfo *progress_info, gpointer data)
 				}
 				
 				if (debuting_uris != NULL) {
-					g_hash_table_insert (debuting_uris,
-							     g_strdup (progress_info->target_name),
-							     GINT_TO_POINTER (really_moved));
+					g_hash_table_replace (debuting_uris,
+							      g_strdup (progress_info->target_name),
+							      GINT_TO_POINTER (really_moved));
 				}
 			}
 			if (really_moved) {
@@ -1723,7 +1783,7 @@ nautilus_file_operations_copy_move (const GList *item_uris,
 	duplicate = copy_action != GDK_ACTION_MOVE;
 	for (p = item_uris; p != NULL; p = p->next) {
 		/* Filter out special Nautilus link files */
-		/* FIXME bugzilla.eazel.com 5295: 
+		/* FIXME bugzilla.gnome.org 45295: 
 		 * This is surprising behavior -- the user drags the Trash icon (say)
 		 * to a folder, releases it, and nothing whatsoever happens. Don't we want
 		 * a dialog in this case?
@@ -1980,7 +2040,7 @@ nautilus_file_operations_copy_move (const GList *item_uris,
 	transfer_info->overwrite_mode = GNOME_VFS_XFER_OVERWRITE_MODE_QUERY;
 	transfer_info->done_callback = done_callback;
 	transfer_info->done_callback_data = done_callback_data;
-	transfer_info->debuting_uris = g_hash_table_new (g_str_hash, g_str_equal);
+	transfer_info->debuting_uris = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
 
 	sync_transfer_info = g_new (SyncTransferInfo, 1);
 	sync_transfer_info->iterator = icon_position_iterator;
@@ -1990,6 +2050,7 @@ nautilus_file_operations_copy_move (const GList *item_uris,
 		gnome_vfs_async_xfer (&transfer_info->handle, source_uri_list, target_uri_list,
 		      		      move_options, GNOME_VFS_XFER_ERROR_MODE_QUERY, 
 		      		      GNOME_VFS_XFER_OVERWRITE_MODE_QUERY,
+				      GNOME_VFS_PRIORITY_DEFAULT,
 		      		      update_transfer_callback, transfer_info,
 		      		      sync_transfer_callback, sync_transfer_info);
 	}
@@ -2122,6 +2183,7 @@ nautilus_file_operations_new_folder (GtkWidget *parent_view,
 	      		      GNOME_VFS_XFER_NEW_UNIQUE_DIRECTORY,
 	      		      GNOME_VFS_XFER_ERROR_MODE_QUERY, 
 	      		      GNOME_VFS_XFER_OVERWRITE_MODE_QUERY,
+			      GNOME_VFS_PRIORITY_DEFAULT,
 	      		      new_folder_transfer_callback, state,
 	      		      sync_transfer_callback, NULL);
 
@@ -2164,6 +2226,7 @@ nautilus_file_operations_delete (const GList *item_uris,
 	      		      GNOME_VFS_XFER_DELETE_ITEMS | GNOME_VFS_XFER_RECURSIVE,
 	      		      GNOME_VFS_XFER_ERROR_MODE_QUERY, 
 	      		      GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE,
+			      GNOME_VFS_PRIORITY_DEFAULT,
 	      		      update_transfer_callback, transfer_info,
 	      		      sync_transfer_callback, NULL);
 
@@ -2198,6 +2261,7 @@ do_empty_trash (GtkWidget *parent_view)
 		      		      GNOME_VFS_XFER_EMPTY_DIRECTORIES,
 		      		      GNOME_VFS_XFER_ERROR_MODE_QUERY, 
 		      		      GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE,
+				      GNOME_VFS_PRIORITY_DEFAULT,
 		      		      update_transfer_callback, transfer_info,
 		      		      sync_transfer_callback, NULL);
 	}
@@ -2208,8 +2272,9 @@ do_empty_trash (GtkWidget *parent_view)
 static gboolean
 confirm_empty_trash (GtkWidget *parent_view)
 {
-	GnomeDialog *dialog;
+	GtkDialog *dialog;
 	GtkWindow *parent_window;
+	int response;
 
 	/* Just Say Yes if the preference says not to confirm. */
 	if (!eel_preferences_get_boolean (NAUTILUS_PREFERENCES_CONFIRM_TRASH)) {
@@ -2226,9 +2291,13 @@ confirm_empty_trash (GtkWidget *parent_view)
 		GNOME_STOCK_BUTTON_CANCEL,
 		parent_window);
 
-	gnome_dialog_set_default (dialog, GNOME_CANCEL);
+	gtk_dialog_set_default_response (dialog, GTK_RESPONSE_CANCEL);
 
-	return gnome_dialog_run (dialog) == GNOME_OK;
+	response = gtk_dialog_run (dialog);
+
+	gtk_object_destroy (GTK_OBJECT (dialog));
+
+	return response == GTK_RESPONSE_YES;
 }
 
 void 
@@ -2288,14 +2357,18 @@ nautilus_self_check_file_operations (void)
 	EEL_CHECK_STRING_RESULT (get_duplicate_name (_("foo foo (24th copy)"), 1), _("foo foo (25th copy)"));
 	EEL_CHECK_STRING_RESULT (get_duplicate_name (_("foo foo (24th copy).txt"), 1), _("foo foo (25th copy).txt"));
 	EEL_CHECK_STRING_RESULT (get_duplicate_name (_("foo foo (100000000000000th copy).txt"), 1), _("foo foo (copy).txt"));
-
-	/* FIXME bugzilla.eazel.com 7701: These are wrong. */
-	EEL_CHECK_STRING_RESULT (get_duplicate_name (_("foo (10th copy)"), 1), _("foo (11st copy)"));
-	EEL_CHECK_STRING_RESULT (get_duplicate_name (_("foo (10th copy).txt"), 1), _("foo (11st copy).txt"));
-	EEL_CHECK_STRING_RESULT (get_duplicate_name (_("foo (11th copy)"), 1), _("foo (12nd copy)"));
-	EEL_CHECK_STRING_RESULT (get_duplicate_name (_("foo (11th copy).txt"), 1), _("foo (12nd copy).txt"));
-	EEL_CHECK_STRING_RESULT (get_duplicate_name (_("foo (12th copy)"), 1), _("foo (13rd copy)"));
-	EEL_CHECK_STRING_RESULT (get_duplicate_name (_("foo (12th copy).txt"), 1), _("foo (13rd copy).txt"));
+	EEL_CHECK_STRING_RESULT (get_duplicate_name (_("foo (10th copy)"), 1), _("foo (11th copy)"));
+	EEL_CHECK_STRING_RESULT (get_duplicate_name (_("foo (10th copy).txt"), 1), _("foo (11th copy).txt"));
+	EEL_CHECK_STRING_RESULT (get_duplicate_name (_("foo (11th copy)"), 1), _("foo (12th copy)"));
+	EEL_CHECK_STRING_RESULT (get_duplicate_name (_("foo (11th copy).txt"), 1), _("foo (12th copy).txt"));
+	EEL_CHECK_STRING_RESULT (get_duplicate_name (_("foo (12th copy)"), 1), _("foo (13th copy)"));
+	EEL_CHECK_STRING_RESULT (get_duplicate_name (_("foo (12th copy).txt"), 1), _("foo (13th copy).txt"));
+	EEL_CHECK_STRING_RESULT (get_duplicate_name (_("foo (110th copy)"), 1), _("foo (111th copy)"));
+	EEL_CHECK_STRING_RESULT (get_duplicate_name (_("foo (110th copy).txt"), 1), _("foo (111th copy).txt"));
+	EEL_CHECK_STRING_RESULT (get_duplicate_name (_("foo (122nd copy)"), 1), _("foo (123rd copy)"));
+	EEL_CHECK_STRING_RESULT (get_duplicate_name (_("foo (122nd copy).txt"), 1), _("foo (123rd copy).txt"));
+	EEL_CHECK_STRING_RESULT (get_duplicate_name (_("foo (123rd copy)"), 1), _("foo (124th copy)"));
+	EEL_CHECK_STRING_RESULT (get_duplicate_name (_("foo (123rd copy).txt"), 1), _("foo (124th copy).txt"));
 }
 
 #endif
