@@ -102,6 +102,7 @@ struct NautilusIconContainerDetails {
 	/* List of icons. */
 	GList *icons;
 	GList *new_icons;
+	GHashTable *icon_set;
 
 	/* Current icon for keyboard navigation. */
 	NautilusIcon *keyboard_focus;
@@ -160,12 +161,6 @@ struct NautilusIconContainerDetails {
 	/* Idle handler for stretch code */
 	guint stretch_idle_id;
 
-	/* Timeout for selection in browser mode. */
-	guint linger_selection_mode_timer_id;
-
-	/* Icon to be selected at timeout in browser mode. */
-	NautilusIcon *linger_selection_mode_icon;
-
 	/* DnD info. */
 	NautilusIconDndInfo *dnd_info;
 
@@ -174,10 +169,7 @@ struct NautilusIconContainerDetails {
 	
 	/* fonts used to draw labels in regular mode */
 	GdkFont *label_font[NAUTILUS_ZOOM_LEVEL_LARGEST + 1];
-
-	/* font used to draw labels in smooth mode */
-	EelScalableFont *smooth_label_font;
-	int font_size_table[NAUTILUS_ZOOM_LEVEL_LARGEST + 1];
+	int font_size_table[NAUTILUS_ZOOM_LEVEL_LARGEST + 1]; /* unused? */
 
 	/* pixbuf and color for label highlighting */
 	GdkPixbuf *highlight_frame;
