@@ -20,7 +20,7 @@
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
   
-   Author: Darin Adler <darin@eazel.com>
+   Author: Darin Adler <darin@bentspoon.com>
 */
 
 #include <config.h>
@@ -68,20 +68,20 @@ enum {
 
 static guint signals[LAST_SIGNAL];
 
-static void     nautilus_merged_directory_initialize       (gpointer                 object,
+static void     nautilus_merged_directory_init       (gpointer                 object,
 							    gpointer                 klass);
-static void     nautilus_merged_directory_initialize_class (gpointer                 klass);
+static void     nautilus_merged_directory_class_init (gpointer                 klass);
 static void     remove_all_real_directories                (NautilusMergedDirectory *merged);
 static guint    merged_callback_hash                       (gconstpointer            merged_callback);
 static gboolean merged_callback_equal                      (gconstpointer            merged_callback,
 							    gconstpointer            merged_callback_2);
 
-EEL_DEFINE_CLASS_BOILERPLATE (NautilusMergedDirectory,
+EEL_CLASS_BOILERPLATE (NautilusMergedDirectory,
 				   nautilus_merged_directory,
 				   NAUTILUS_TYPE_DIRECTORY)
 
 static void
-nautilus_merged_directory_initialize (gpointer object, gpointer klass)
+nautilus_merged_directory_init (gpointer object, gpointer klass)
 {
 	NautilusMergedDirectory *merged;
 
@@ -286,17 +286,32 @@ merged_cancel_callback (NautilusDirectory *directory,
 	merged_callback_destroy (merged_callback);
 }
 
+static void
+build_merged_callback_list (NautilusDirectory *directory,
+			    GList *file_list,
+			    gpointer callback_data)
+{
+	GList **merged_list;
+
+	merged_list = callback_data;
+	*merged_list = g_list_concat (*merged_list,
+				      nautilus_file_list_copy (file_list));
+}
+
 /* Create a monitor on each of the directories in the list. */
 static void
 merged_file_monitor_add (NautilusDirectory *directory,
 			 gconstpointer client,
 			 gboolean monitor_hidden_files,
 			 gboolean monitor_backup_files,
-			 GList *file_attributes)
+			 GList *file_attributes,
+			 NautilusDirectoryCallback callback,
+			 gpointer callback_data)
 {
 	NautilusMergedDirectory *merged;
 	MergedMonitor *monitor;
 	GList *node;
+	GList *merged_callback_list;
 
 	merged = NAUTILUS_MERGED_DIRECTORY (directory);
 
@@ -318,12 +333,18 @@ merged_file_monitor_add (NautilusDirectory *directory,
 	monitor->monitor_attributes = eel_g_str_list_copy (file_attributes);
 	
 	/* Call through to the real directory add calls. */
+	merged_callback_list = NULL;
 	for (node = merged->details->directories; node != NULL; node = node->next) {
 		nautilus_directory_file_monitor_add
 			(node->data, monitor,
 			 monitor_hidden_files, monitor_backup_files,
-			 file_attributes);
+			 file_attributes,
+			 build_merged_callback_list, &merged_callback_list);
 	}
+	if (callback != NULL) {
+		(* callback) (directory, merged_callback_list, callback_data);
+	}
+	nautilus_file_list_free (merged_callback_list);
 }
 
 /* Remove the monitor from each of the directories in the list. */
@@ -423,17 +444,17 @@ merged_is_not_empty (NautilusDirectory *directory)
 static void
 forward_files_added_cover (NautilusDirectory *real_directory,
 			   GList *files,
-			   NautilusMergedDirectory *merged)
+			   gpointer callback_data)
 {
-	nautilus_directory_emit_files_added (NAUTILUS_DIRECTORY (merged), files);
+	nautilus_directory_emit_files_added (NAUTILUS_DIRECTORY (callback_data), files);
 }
 
 static void
 forward_files_changed_cover (NautilusDirectory *real_directory,
 			     GList *files,
-			     NautilusMergedDirectory *merged)
+			     gpointer callback_data)
 {
-	nautilus_directory_emit_files_changed (NAUTILUS_DIRECTORY (merged), files);
+	nautilus_directory_emit_files_changed (NAUTILUS_DIRECTORY (callback_data), files);
 }
 
 static void
@@ -459,7 +480,8 @@ monitor_add_directory (gpointer key,
 		(NAUTILUS_DIRECTORY (callback_data), monitor,
 		 monitor->monitor_hidden_files,
 		 monitor->monitor_backup_files,
-		 monitor->monitor_attributes);
+		 monitor->monitor_attributes,
+		 forward_files_added_cover, monitor->merged);
 }
 
 static void
@@ -478,21 +500,12 @@ merged_add_real_directory (NautilusMergedDirectory *merged,
 	merged->details->directories_not_done_loading = g_list_prepend
 		(merged->details->directories_not_done_loading, real_directory);
 
-	/* Connect signals. */
-	gtk_signal_connect (GTK_OBJECT (real_directory),
-			    "files_added",
-			    forward_files_added_cover,
-			    merged);
-	gtk_signal_connect (GTK_OBJECT (real_directory),
-			    "files_changed",
-			    forward_files_changed_cover,
-			    merged);
-	gtk_signal_connect (GTK_OBJECT (real_directory),
+	g_signal_connect (real_directory,
 			    "done_loading",
-			    done_loading_callback,
+			    G_CALLBACK (done_loading_callback),
 			    merged);
 
-	/* FIXME bugzilla.eazel.com 5084: The done_loading part won't work for the case where
+	/* FIXME bugzilla.gnome.org 45084: The done_loading part won't work for the case where
          * we have no directories in our list.
 	 */
 
@@ -500,7 +513,16 @@ merged_add_real_directory (NautilusMergedDirectory *merged,
 	g_hash_table_foreach (merged->details->monitors,
 			      monitor_add_directory,
 			      real_directory);
-	/* FIXME bugzilla.eazel.com 2541: Do we need to add the directory to callbacks too? */
+	/* FIXME bugzilla.gnome.org 42541: Do we need to add the directory to callbacks too? */
+
+	g_signal_connect (real_directory,
+			    "files_added",
+			    G_CALLBACK (forward_files_added_cover),
+			    merged);
+	g_signal_connect (real_directory,
+			    "files_changed",
+			    G_CALLBACK (forward_files_changed_cover),
+			    merged);
 }
 
 void
@@ -516,8 +538,8 @@ nautilus_merged_directory_add_real_directory (NautilusMergedDirectory *merged,
 		return;
 	}
 
-	gtk_signal_emit (GTK_OBJECT (merged),
-			 signals[ADD_REAL_DIRECTORY],
+	g_signal_emit (merged,
+			 signals[ADD_REAL_DIRECTORY], 0,
 			 real_directory);
 }
 
@@ -585,8 +607,8 @@ nautilus_merged_directory_remove_real_directory (NautilusMergedDirectory *merged
 		return;
 	}
 
-	gtk_signal_emit (GTK_OBJECT (merged),
-			 signals[REMOVE_REAL_DIRECTORY],
+	g_signal_emit (merged,
+			 signals[REMOVE_REAL_DIRECTORY], 0,
 			 real_directory);
 }
 
@@ -600,7 +622,7 @@ remove_all_real_directories (NautilusMergedDirectory *merged)
 }
 
 static void
-nautilus_merged_directory_initialize_class (gpointer klass)
+nautilus_merged_directory_class_init (gpointer klass)
 {
 	GtkObjectClass *object_class;
 	NautilusDirectoryClass *directory_class;
@@ -625,21 +647,21 @@ nautilus_merged_directory_initialize_class (gpointer klass)
 	merged_directory_class->remove_real_directory = merged_remove_real_directory;
 
 	signals[ADD_REAL_DIRECTORY] 
-		= gtk_signal_new ("add_real_directory",
-				  GTK_RUN_LAST,
-				  object_class->type,
-				  GTK_SIGNAL_OFFSET (NautilusMergedDirectoryClass, 
+		= g_signal_new ("add_real_directory",
+		                G_TYPE_FROM_CLASS (object_class),
+		                G_SIGNAL_RUN_LAST,
+		                G_STRUCT_OFFSET (NautilusMergedDirectoryClass, 
 						     add_real_directory),
-				  gtk_marshal_NONE__POINTER,
-				  GTK_TYPE_NONE, 1, GTK_TYPE_POINTER);
+		                NULL, NULL,
+		                gtk_marshal_VOID__POINTER,
+		                G_TYPE_NONE, 1, G_TYPE_POINTER);
 	signals[REMOVE_REAL_DIRECTORY] 
-		= gtk_signal_new ("remove_real_directory",
-				  GTK_RUN_LAST,
-				  object_class->type,
-				  GTK_SIGNAL_OFFSET (NautilusMergedDirectoryClass, 
+		= g_signal_new ("remove_real_directory",
+		                G_TYPE_FROM_CLASS (object_class),
+		                G_SIGNAL_RUN_LAST,
+		                G_STRUCT_OFFSET (NautilusMergedDirectoryClass, 
 						     remove_real_directory),
-				  gtk_marshal_NONE__POINTER,
-				  GTK_TYPE_NONE, 1, GTK_TYPE_POINTER);
-
-	gtk_object_class_add_signals (object_class, signals, LAST_SIGNAL);				  
+		                NULL, NULL,
+		                gtk_marshal_VOID__POINTER,
+		                G_TYPE_NONE, 1, G_TYPE_POINTER);
 }
