@@ -20,7 +20,7 @@
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
   
-   Author: Darin Adler <darin@eazel.com>
+   Author: Darin Adler <darin@bentspoon.com>
 */
 
 #include <config.h>
@@ -35,7 +35,6 @@
 #include <eel/eel-gtk-macros.h>
 #include "nautilus-trash-directory.h"
 #include <gtk/gtksignal.h>
-#include <libgnome/gnome-defs.h>
 #include <libgnome/gnome-i18n.h>
 #include <string.h>
 
@@ -77,11 +76,11 @@ static const char * const delegated_attributes[] = {
 	NAUTILUS_FILE_ATTRIBUTE_DIRECTORY_ITEM_MIME_TYPES
 };
 
-static void nautilus_trash_file_initialize       (gpointer   object,
+static void nautilus_trash_file_init       (gpointer   object,
 						  gpointer   klass);
-static void nautilus_trash_file_initialize_class (gpointer   klass);
+static void nautilus_trash_file_class_init (gpointer   klass);
 
-EEL_DEFINE_CLASS_BOILERPLATE (NautilusTrashFile,
+EEL_CLASS_BOILERPLATE (NautilusTrashFile,
 				   nautilus_trash_file,
 				   NAUTILUS_TYPE_FILE)
 
@@ -92,7 +91,7 @@ is_delegated_attribute (const char *attribute)
 
 	g_return_val_if_fail (attribute != NULL, FALSE);
 
-	for (i = 0; i < EEL_N_ELEMENTS (delegated_attributes); i++) {
+	for (i = 0; i < G_N_ELEMENTS (delegated_attributes); i++) {
 		if (strcmp (attribute, delegated_attributes[i]) == 0) {
 			return TRUE;
 		}
@@ -126,7 +125,7 @@ real_monitor_add (NautilusFile *file,
 {
 	nautilus_directory_monitor_add_internal
 		(file->details->directory, file,
-		 client, TRUE, TRUE, attributes);
+		 client, TRUE, TRUE, attributes, NULL, NULL);
 }   
 			   
 static void
@@ -285,9 +284,9 @@ add_real_file (NautilusTrashFile *trash,
 	trash->details->files = g_list_prepend
 		(trash->details->files, real_file);
 	
-	gtk_signal_connect (GTK_OBJECT (real_file),
+	g_signal_connect (real_file,
 			    "changed",
-			    real_file_changed_callback,
+			    G_CALLBACK (real_file_changed_callback),
 			    trash);
 
 	/* Add the file to any extant monitors. */
@@ -332,7 +331,7 @@ remove_real_file (NautilusTrashFile *trash,
 		 real_file);
 
 	gtk_signal_disconnect_by_func (GTK_OBJECT (real_file),
-				       real_file_changed_callback,
+				       G_CALLBACK (real_file_changed_callback),
 				       trash);
 
 	trash->details->files = g_list_remove
@@ -735,7 +734,7 @@ remove_all_real_files (NautilusTrashFile *trash)
 }
 
 static void
-nautilus_trash_file_initialize (gpointer object, gpointer klass)
+nautilus_trash_file_init (gpointer object, gpointer klass)
 {
 	NautilusTrashFile *trash_file;
 	NautilusTrashDirectory *trash_directory;
@@ -755,12 +754,12 @@ nautilus_trash_file_initialize (gpointer object, gpointer klass)
 	trash_file->details->add_directory_connection_id = gtk_signal_connect
 		(GTK_OBJECT (trash_directory),
 		 "add_real_directory",
-		 add_directory_callback,
+		 G_CALLBACK (add_directory_callback),
 		 trash_file);
 	trash_file->details->remove_directory_connection_id = gtk_signal_connect
 		(GTK_OBJECT (trash_directory),
 		 "remove_real_directory",
-		 remove_directory_callback,
+		 G_CALLBACK (remove_directory_callback),
 		 trash_file);
 
 	real_directories = nautilus_merged_directory_get_real_directories
@@ -805,7 +804,7 @@ trash_destroy (GtkObject *object)
 }
 
 static void
-nautilus_trash_file_initialize_class (gpointer klass)
+nautilus_trash_file_class_init (gpointer klass)
 {
 	GtkObjectClass *object_class;
 	NautilusFileClass *file_class;
