@@ -51,6 +51,8 @@
 #include <eel/eel-stock-dialogs.h>
 #include <eel/eel-string.h>
 
+#if GNOME2_CONVERSION_COMPLETE
+
 /* FIXME bugzilla.gnome.org 42815: This code uses part of the
  * NautilusSearchBarCriterion class, which is really for complex
  * search bar user interface. We only need to do some non-UI
@@ -70,9 +72,9 @@ struct FMSearchListViewDetails {
 	BonoboUIComponent *ui;
 };
 
-static void 	fm_search_list_view_initialize       	 (gpointer          object,
+static void 	fm_search_list_view_init       	 (gpointer          object,
 						      	  gpointer          klass);
-static void 	fm_search_list_view_initialize_class 	 (gpointer          klass);
+static void 	fm_search_list_view_class_init 	 (gpointer          klass);
 static void     real_destroy                             (GtkObject        *object);
 static void 	real_add_file				 (FMDirectoryView  *view,
 							  NautilusFile 	   *file);
@@ -107,7 +109,7 @@ static void	reveal_selected_items_callback 		 (BonoboUIComponent *component,
 							  const char 	   *verb);
 
 
-EEL_DEFINE_CLASS_BOILERPLATE (FMSearchListView,
+EEL_CLASS_BOILERPLATE (FMSearchListView,
 				   fm_search_list_view,
 				   FM_TYPE_LIST_VIEW)
 
@@ -177,7 +179,7 @@ static void
 real_load_error (FMDirectoryView *nautilus_view, 
 		 GnomeVFSResult result)
 {
-	GnomeDialog *load_error_dialog;
+	GtkDialog *load_error_dialog;
 	char *error_string;
 
 	/* Do not call parent's function; we handle all search errors
@@ -315,7 +317,7 @@ display_indexed_search_problems_dialog (gboolean backup_search_is_available)
 static void     
 display_system_services_are_disabled_dialog (gboolean unindexed_search_is_available)
 {
-	GnomeDialog *dialog_shown;
+	GtkDialog *dialog_shown;
 	char *details_string;
 
 	details_string = nautilus_medusa_get_explanation_of_enabling ();
@@ -333,7 +335,7 @@ display_system_services_are_disabled_dialog (gboolean unindexed_search_is_availa
 #endif	
 
 static void
-fm_search_list_view_initialize_class (gpointer klass)
+fm_search_list_view_class_init (gpointer klass)
 {
 	GtkObjectClass *object_class;
 	FMDirectoryViewClass *fm_directory_view_class;
@@ -369,7 +371,7 @@ fm_search_list_view_initialize_class (gpointer klass)
 }
 
 static void
-fm_search_list_view_initialize (gpointer object,
+fm_search_list_view_init (gpointer object,
 				gpointer klass)
 {
 	FMSearchListView *search_view;
@@ -385,9 +387,9 @@ fm_search_list_view_initialize (gpointer object,
 
 	nautilus_view = fm_directory_view_get_nautilus_view (directory_view);
 
-	gtk_signal_connect (GTK_OBJECT (nautilus_view),
+	g_signal_connect (nautilus_view,
 			    "load_location",
-			    GTK_SIGNAL_FUNC (load_location_callback),
+			    G_CALLBACK (load_location_callback),
 			    NULL);
 }
 
@@ -399,7 +401,7 @@ real_destroy (GtkObject *object)
 	search_view = FM_SEARCH_LIST_VIEW (object);
 
 	if (search_view->details->ui != NULL) {
-		bonobo_ui_component_unset_container (search_view->details->ui);
+		bonobo_ui_component_unset_container (search_view->details->ui, NULL);
 		bonobo_object_unref (BONOBO_OBJECT (search_view->details->ui));
 	}
 	g_free (search_view->details);
@@ -627,8 +629,9 @@ real_adding_file (FMListView *view, NautilusFile *file)
 
 	gtk_signal_connect_object (GTK_OBJECT (file),
 				   "changed",
-				   fm_directory_view_queue_file_change,
+				   G_CALLBACK (fm_directory_view_queue_file_change),
 				   GTK_OBJECT (view));
+
 	/* Monitor the things needed to get the right
 	 * icon. Also monitor a directory's item count because
 	 * the "size" attribute is based on that, and the file's metadata, and
@@ -655,7 +658,7 @@ real_removing_file (FMListView *view, NautilusFile *file)
 
 	nautilus_file_monitor_remove (file, view);
 	gtk_signal_disconnect_by_func 
-		(GTK_OBJECT (file), fm_directory_view_queue_file_change, view);
+		(GTK_OBJECT (file), G_CALLBACK (fm_directory_view_queue_file_change), view);
 	EEL_CALL_PARENT (FM_LIST_VIEW_CLASS, removing_file, (view, file));
 }
 
@@ -710,6 +713,7 @@ static void
 real_merge_menus (FMDirectoryView *view)
 {
 	FMSearchListView *search_view;
+	Bonobo_UIContainer ui_container;
 	BonoboUIVerb verbs [] = {
 		BONOBO_UI_VERB ("Indexing Info", indexing_info_callback),
 		BONOBO_UI_VERB ("Reveal", reveal_selected_items_callback),
@@ -721,12 +725,14 @@ real_merge_menus (FMDirectoryView *view)
 	search_view = FM_SEARCH_LIST_VIEW (view);
 
 	search_view->details->ui = bonobo_ui_component_new ("Search List View");
+	ui_container = fm_directory_view_get_bonobo_ui_container (view);
 	bonobo_ui_component_set_container (search_view->details->ui,
-					   fm_directory_view_get_bonobo_ui_container (view));
+					   ui_container, NULL);
+	bonobo_object_release_unref (ui_container, NULL);
 	bonobo_ui_util_set_ui (search_view->details->ui,
 			       DATADIR,
 			       "nautilus-search-list-view-ui.xml",
-			       "nautilus");
+			       "nautilus", NULL);
 	bonobo_ui_component_add_verb_list_with_data (search_view->details->ui, verbs, view);
 }
 
@@ -802,3 +808,5 @@ reveal_selected_items_callback (BonoboUIComponent *component, gpointer user_data
 
 	nautilus_file_list_free (selection);
 }
+
+#endif
