@@ -21,7 +21,7 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *  Authors: Elliot Lee <sopwith@redhat.com>,
- *           Darin Adler <darin@eazel.com>
+ *           Darin Adler <darin@bentspoon.com>
  *
  */
 
@@ -48,11 +48,10 @@
 #include <gtk/gtksignal.h>
 #include <libgnome/gnome-config.h>
 #include <libgnome/gnome-i18n.h>
-#include <libgnome/gnome-metadata.h>
 #include <libgnome/gnome-util.h>
 #include <libgnomeui/gnome-client.h>
 #include <libgnomeui/gnome-messagebox.h>
-#include <libgnomeui/gnome-stock.h>
+#include <libgnomeui/gnome-stock-icons.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
@@ -63,7 +62,12 @@
 #include <libnautilus-private/nautilus-sound.h>
 #include <libnautilus-private/nautilus-undo-manager.h>
 #include <libnautilus-private/nautilus-volume-monitor.h>
-#include <liboaf/liboaf.h>
+#include <libnautilus-private/nautilus-authn-manager.h>
+#include <bonobo-activation/bonobo-activation.h>
+
+/* Needed for the is_kdesktop_present check */
+#include <gdk/gdkx.h>
+#include <X11/Xlib.h>
 
 #define FACTORY_IID	     "OAFIID:nautilus_factory:bd1e1862-92d7-4391-963e-37583f0daef3"
 #define SEARCH_LIST_VIEW_IID "OAFIID:nautilus_file_manager_search_list_view:b186e381-198e-43cf-9c46-60b6bb35db0b"
@@ -75,59 +79,28 @@ static NautilusDesktopWindow *nautilus_application_desktop_window;
 /* Keeps track of all the nautilus windows. */
 static GList *nautilus_application_window_list;
 
-static CORBA_boolean manufactures                          (PortableServer_Servant    servant,
-							    const CORBA_char         *iid,
-							    CORBA_Environment        *ev);
-static CORBA_Object  create_object                         (PortableServer_Servant    servant,
-							    const CORBA_char         *iid,
-							    const GNOME_stringlist   *params,
-							    CORBA_Environment        *ev);
-static void          nautilus_application_initialize       (NautilusApplication      *application);
-static void          nautilus_application_initialize_class (NautilusApplicationClass *klass);
-static void          nautilus_application_destroy          (GtkObject                *object);
-static gboolean      confirm_ok_to_run_as_root             (void);
-static gboolean      need_to_show_first_time_druid         (void);
-static void          desktop_changed_callback              (gpointer                  user_data);
-static void          desktop_location_changed_callback     (gpointer                  user_data);
-static void          volume_mounted_callback               (NautilusVolumeMonitor    *monitor,
-							    NautilusVolume           *volume,
-							    NautilusApplication      *application);
-static void          volume_unmounted_callback             (NautilusVolumeMonitor    *monitor,
-							    NautilusVolume           *volume,
-							    NautilusApplication      *application);
-static void	     update_session			    (gpointer		      callback_data);
-static void	     init_session 			    (void);
+static void     nautilus_application_init         (NautilusApplication      *application);
+static void     nautilus_application_class_init   (NautilusApplicationClass *klass);
+static gboolean need_to_show_first_time_druid     (void);
+static void     desktop_changed_callback          (gpointer                  user_data);
+static void     desktop_location_changed_callback (gpointer                  user_data);
+static void     volume_mounted_callback           (NautilusVolumeMonitor    *monitor,
+						   NautilusVolume           *volume,
+						   NautilusApplication      *application);
+static void     volume_unmounted_callback         (NautilusVolumeMonitor    *monitor,
+						   NautilusVolume           *volume,
+						   NautilusApplication      *application);
+static void     update_session                    (gpointer                  callback_data);
+static void     init_session                      (void);
+static gboolean is_kdesktop_present               (void);
 
-EEL_DEFINE_CLASS_BOILERPLATE (NautilusApplication, nautilus_application, BONOBO_OBJECT_TYPE)
-
-static POA_GNOME_ObjectFactory__epv factory_epv = {
-	NULL,
-	&manufactures,
-	&create_object
-};
-static PortableServer_ServantBase__epv base_epv;
-static POA_GNOME_ObjectFactory__vepv vepv = {
-	&base_epv,
-	&factory_epv
-};
-
-static CORBA_boolean
-manufactures (PortableServer_Servant servant,
-	      const CORBA_char *iid,
-	      CORBA_Environment *ev)
-{
-	return strcmp (iid, NAUTILUS_ICON_VIEW_IID) == 0
-		|| strcmp (iid, NAUTILUS_DESKTOP_ICON_VIEW_IID) == 0
-		|| strcmp (iid, NAUTILUS_LIST_VIEW_IID) == 0
-		|| strcmp (iid, SEARCH_LIST_VIEW_IID) == 0
-		|| strcmp (iid, SHELL_IID) == 0
-		|| strcmp (iid, METAFILE_FACTORY_IID) == 0;
-}
+EEL_BONOBO_BOILERPLATE (NautilusApplication,
+			nautilus_application,
+			BONOBO_GENERIC_FACTORY_TYPE)
 
 static CORBA_Object
 create_object (PortableServer_Servant servant,
 	       const CORBA_char *iid,
-	       const GNOME_stringlist *params,
 	       CORBA_Environment *ev)
 {
 	BonoboObject *object;
@@ -135,19 +108,21 @@ create_object (PortableServer_Servant servant,
 	NautilusApplication *application;
 
 	if (strcmp (iid, NAUTILUS_ICON_VIEW_IID) == 0) {
-		directory_view = FM_DIRECTORY_VIEW (gtk_object_new (fm_icon_view_get_type (), NULL));
+		directory_view = FM_DIRECTORY_VIEW (g_object_new (fm_icon_view_get_type (), NULL));
 		object = BONOBO_OBJECT (fm_directory_view_get_nautilus_view (directory_view));
 	} else if (strcmp (iid, NAUTILUS_DESKTOP_ICON_VIEW_IID) == 0) {
-		directory_view = FM_DIRECTORY_VIEW (gtk_object_new (fm_desktop_icon_view_get_type (), NULL));
+		directory_view = FM_DIRECTORY_VIEW (g_object_new (fm_desktop_icon_view_get_type (), NULL));
 		object = BONOBO_OBJECT (fm_directory_view_get_nautilus_view (directory_view));
 	} else if (strcmp (iid, NAUTILUS_LIST_VIEW_IID) == 0) {
-		directory_view = FM_DIRECTORY_VIEW (gtk_object_new (fm_list_view_get_type (), NULL));
+		directory_view = FM_DIRECTORY_VIEW (g_object_new (fm_list_view_get_type (), NULL));
 		object = BONOBO_OBJECT (fm_directory_view_get_nautilus_view (directory_view));
+#if GNOME2_CONVERSION_COMPLETE
 	} else if (strcmp (iid, SEARCH_LIST_VIEW_IID) == 0) {
-		directory_view = FM_DIRECTORY_VIEW (gtk_object_new (fm_search_list_view_get_type (), NULL));
+		directory_view = FM_DIRECTORY_VIEW (g_object_new (fm_search_list_view_get_type (), NULL));
 		object = BONOBO_OBJECT (fm_directory_view_get_nautilus_view (directory_view));
+#endif
 	} else if (strcmp (iid, SHELL_IID) == 0) {
-		application = NAUTILUS_APPLICATION (((BonoboObjectServant *) servant)->bonobo_object);
+		application = NAUTILUS_APPLICATION (bonobo_object_from_servant (servant));
 		object = BONOBO_OBJECT (nautilus_shell_new (application));
 	} else if (strcmp (iid, METAFILE_FACTORY_IID) == 0) {
 		object = BONOBO_OBJECT (nautilus_metafile_factory_get_instance ());
@@ -158,19 +133,6 @@ create_object (PortableServer_Servant servant,
 	return CORBA_Object_duplicate (bonobo_object_corba_objref (object), ev);
 }
 
-static CORBA_Object
-create_factory (PortableServer_POA poa,
-		NautilusApplication *bonobo_object,
-		CORBA_Environment *ev)
-{
-	BonoboObjectServant *servant;
-
-	servant = g_new0 (BonoboObjectServant, 1);
-	((POA_GNOME_ObjectFactory *) servant)->vepv = &vepv;
-	POA_GNOME_ObjectFactory__init ((PortableServer_Servant) servant, ev);
-	return bonobo_object_activate_servant (BONOBO_OBJECT (bonobo_object), servant);
-}
-
 GList *
 nautilus_application_get_window_list (void)
 {
@@ -178,50 +140,40 @@ nautilus_application_get_window_list (void)
 }
 
 static void
-nautilus_application_initialize_class (NautilusApplicationClass *klass)
+nautilus_application_init (NautilusApplication *application)
 {
-	GTK_OBJECT_CLASS (klass)->destroy = nautilus_application_destroy;
-}
-
-static void
-nautilus_application_initialize (NautilusApplication *application)
-{
-	CORBA_Environment ev;
-	CORBA_Object corba_object;
-
-	CORBA_exception_init (&ev);
-	corba_object = create_factory (bonobo_poa (), application, &ev);
-	if (ev._major != CORBA_NO_EXCEPTION) {
-		g_error ("could not create factory");
-	}
-	CORBA_exception_free (&ev);
-	
-	bonobo_object_construct (BONOBO_OBJECT (application), corba_object);
-	
 	/* Create an undo manager */
 	application->undo_manager = nautilus_undo_manager_new ();
 
 	/* Watch for volume mounts so we can restore open windows */
-	gtk_signal_connect (GTK_OBJECT (nautilus_volume_monitor_get ()),
+	g_signal_connect (nautilus_volume_monitor_get (),
 			    "volume_mounted",
-			    volume_mounted_callback,
+			    G_CALLBACK (volume_mounted_callback),
 			    application);
 
 	/* Watch for volume unmounts so we can close open windows */
-	gtk_signal_connect (GTK_OBJECT (nautilus_volume_monitor_get ()),
+	g_signal_connect (nautilus_volume_monitor_get (),
 			    "volume_unmounted",
-			    volume_unmounted_callback,
+			    G_CALLBACK (volume_unmounted_callback),
 			    application);
 }
 
 NautilusApplication *
 nautilus_application_new (void)
 {
-	return NAUTILUS_APPLICATION (gtk_object_new (nautilus_application_get_type (), NULL));
+	NautilusApplication *application;
+
+	application = g_object_new (NAUTILUS_TYPE_APPLICATION, NULL);
+	
+	bonobo_generic_factory_construct_noreg (BONOBO_GENERIC_FACTORY (application),
+						FACTORY_IID,
+						NULL);
+	
+	return application;
 }
 
 static void
-nautilus_application_destroy (GtkObject *object)
+nautilus_application_destroy (BonoboObject *object)
 {
 	NautilusApplication *application;
 
@@ -231,41 +183,34 @@ nautilus_application_destroy (GtkObject *object)
 	
 	bonobo_object_unref (BONOBO_OBJECT (application->undo_manager));
 
-	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	EEL_CALL_PARENT (BONOBO_OBJECT_CLASS, destroy, (object));
 }
 
 static gboolean
 check_required_directories (NautilusApplication *application)
 {
 	char *user_directory;
-	char *user_main_directory;
 	char *desktop_directory;
 	EelStringList *directories;
 	char *directories_as_string;
 	char *error_string;
 	char *dialog_title;
-	GnomeDialog *dialog;
+	GtkDialog *dialog;
 	int failed_count;
 	
 	g_assert (NAUTILUS_IS_APPLICATION (application));
 
 	user_directory = nautilus_get_user_directory ();
-	user_main_directory = nautilus_get_user_main_directory ();
 	desktop_directory = nautilus_get_desktop_directory ();
 
 	directories = eel_string_list_new (TRUE);
 	
-	if (!g_file_test (user_directory, G_FILE_TEST_ISDIR)) {
+	if (!g_file_test (user_directory, G_FILE_TEST_IS_DIR)) {
 		eel_string_list_insert (directories, user_directory);
 	}
-	g_free (user_directory);
+	g_free (user_directory);	    
 	    
-	if (!g_file_test (user_main_directory, G_FILE_TEST_ISDIR)) {
-		eel_string_list_insert (directories, user_main_directory);
-	}
-	g_free (user_main_directory);
-	    
-	if (!g_file_test (desktop_directory, G_FILE_TEST_ISDIR)) {
+	if (!g_file_test (desktop_directory, G_FILE_TEST_IS_DIR)) {
 		eel_string_list_insert (directories, desktop_directory);
 	}
 	g_free (desktop_directory);
@@ -352,7 +297,9 @@ migrate_gmc_trash (void)
 	
 	if (stat (trash_dir, &buf) == 0 && S_ISDIR (buf.st_mode)) {
 		rename (trash_dir, dest);
+#if GNOME2_CONVERSION_COMPLETE
 		gnome_metadata_rename (trash_dir, dest);
+#endif
 	}
 	
 	g_free (dp);
@@ -415,11 +362,43 @@ migrate_old_nautilus_files (void)
 	g_free (old_desktop_dir);
 }
 
+static gint
+create_starthere_link_callback (gpointer data)
+{
+	char *desktop_path;
+	char *desktop_link_file;
+	char *cmd;
+	
+	/* Create default services icon on the desktop */
+	desktop_path = nautilus_get_desktop_directory ();
+	desktop_link_file = nautilus_make_path (desktop_path,
+						"starthere.desktop");
+
+	cmd = g_strconcat ("/bin/cp ",
+			   NAUTILUS_DATADIR,
+			   "/starthere-link.desktop ",
+			   desktop_link_file,
+			   NULL);
+
+	if (system (cmd) != 0) {
+		g_warning ("Failed to execute command '%s'\n", cmd);
+	}
+	
+	g_free (desktop_path);
+	g_free (desktop_link_file);
+	g_free (cmd);
+	
+	return FALSE;
+}
+
 static void
 finish_startup (NautilusApplication *application)
 {
 	/* initialize the sound machinery */
-	nautilus_sound_initialize ();
+	nautilus_sound_init ();
+
+	/* initialize URI authentication manager */
+	nautilus_authentication_manager_init ();
 
 	/* Make the desktop work with gmc and old Nautilus. */
 	migrate_gmc_trash ();
@@ -438,22 +417,15 @@ nautilus_application_startup (NautilusApplication *application,
 {
 	CORBA_Environment ev;
 	Nautilus_Shell shell;
-	OAF_RegistrationResult result;
+	Bonobo_RegistrationResult result;
 	const char *message, *detailed_message;
-	GnomeDialog *dialog;
+	GtkDialog *dialog;
 	Nautilus_URIList *url_list;
 	const CORBA_char *corba_geometry;
 	int num_failures;
 
 	num_failures = 0;
 
-	/* Perform check for nautilus being run as super user */
-	if (!(kill_shell || restart_shell)) {
-		if (!confirm_ok_to_run_as_root ()) {
-			return;
-		}
-	}
-
 	/* Check the user's ~/.nautilus directories and post warnings
 	 * if there are problems.
 	 */
@@ -463,84 +435,87 @@ nautilus_application_startup (NautilusApplication *application,
 
 	/* Run the first time startup druid if needed. */
 	if (do_first_time_druid_check && need_to_show_first_time_druid ()) {
-		nautilus_first_time_druid_show (application, urls);
-		return;
+		/* Do this at idle time, once nautilus has initialized
+		 * itself. Otherwise we may spawn a second nautilus
+		 * process when looking for a metadata factory..
+		 */
+		g_idle_add (create_starthere_link_callback, NULL);
+		nautilus_set_first_time_file_flag ();
 	}
 
 	CORBA_exception_init (&ev);
 
 	/* Start up the factory. */
 	while (TRUE) {
-		/* Try to register the file manager view factory with OAF. */
-		result = oaf_active_server_register
+		/* Try to register the file manager view factory. */
+		result = bonobo_activation_active_server_register
 			(FACTORY_IID,
 			 bonobo_object_corba_objref (BONOBO_OBJECT (application)));
 		switch (result) {
-		case OAF_REG_SUCCESS:
-			/* We are registered with OAF and all is right with the world. */
+		case Bonobo_ACTIVATION_REG_SUCCESS:
+			/* We are registered and all is right with the world. */
 			finish_startup (application);
-		case OAF_REG_ALREADY_ACTIVE:
+		case Bonobo_ACTIVATION_REG_ALREADY_ACTIVE:
 			/* Another copy of nautilus already is running and registered. */
 			message = NULL;
 			detailed_message = NULL;
 			break;
-		case OAF_REG_NOT_LISTED:
+		case Bonobo_ACTIVATION_REG_NOT_LISTED:
 			/* Can't register myself due to trouble locating the
-			 * Nautilus_Shell.oaf file. This has happened when you
+			 * Nautilus_Shell.server file. This has happened when you
 			 * launch Nautilus with an LD_LIBRARY_PATH that
-			 * doesn't include the directory containg the oaf
+			 * doesn't include the directory containing the oaf
 			 * library. It could also happen if the
-			 * Nautilus_Shell.oaf file was not present for some
+			 * Nautilus_Shell.server file was not present for some
 			 * reason. Sometimes killing oafd and gconfd fixes
 			 * this problem but we don't exactly understand why,
 			 * since neither of the above causes explain it.
 			 */
 			message = _("Nautilus can't be used now. "
-				    "Running the command \"nautilus-clean.sh -x\""
+				    "Running the command \"bonobo-slay\""
 				    " from the console may fix the problem. If not,"
 				    " you can try rebooting the computer or"
 				    " installing Nautilus again.");
-			/* FIXME bugzilla.eazel.com 2536: The guesses and stuff here are lame. */
+			/* FIXME bugzilla.gnome.org 42536: The guesses and stuff here are lame. */
 			detailed_message = _("Nautilus can't be used now. "
-					     "Running the command \"nautilus-clean.sh -x\""
-					     " from the console may fix the problem. If not,"
-					     " you can try rebooting the computer or"
-					     " installing Nautilus again.\n\n"
-					     "OAF couldn't locate the Nautilus_shell.oaf file. "
+					     "Running the command \"bonobo-slay\" "
+					     "from the console may fix the problem. If not, "
+					     "you can try rebooting the computer or "
+					     "installing Nautilus again.\n\n"
+					     "Bonobo couldn't locate the Nautilus_shell.server file. "
 					     "One cause of this seems to be an LD_LIBRARY_PATH "
-					     "that does not include the oaf library's directory. "
+					     "that does not include the bonobo-activation library's directory. "
 					     "Another possible cause would be bad install "
-					     "with a missing Nautilus_Shell.oaf file.\n\n"
-					     "Running \"nautilus-clean.sh -x\" will kill all "
-					     "OAF and GConf processes, which may be needed by "
+					     "with a missing Nautilus_Shell.server file.\n\n"
+					     "Running \"bonobo-slay\" will kill all "
+					     "Bonobo Activation and GConf processes, which may be needed by "
 					     "other applications.\n\n"
-					     "Sometimes killing oafd and gconfd fixes "
+					     "Sometimes killing bonobo-activation-server and gconfd fixes "
 					     "the problem, but we don't know why.\n\n"
 					     "We have also seen this error when a faulty "
-					     "version of oaf was installed.");
+					     "version of bonobo-activation was installed.");
 			break;
 		default:
 			/* This should never happen. */
-			g_warning ("bad error code from oaf_active_server_register");
-		case OAF_REG_ERROR:
+			g_warning ("bad error code from bonobo_activation_active_server_register");
+		case Bonobo_ACTIVATION_REG_ERROR:
 			/* Some misc. error (can never happen with current
-			 * version of OAF). Show dialog and terminate the
+			 * version of bonobo-activation). Show dialog and terminate the
 			 * program.
 			 */
-			/* FIXME bugzilla.eazel.com 2537: Looks like this does happen with the
-			 * current OAF. I guess I read the code
-			 * wrong. Need to figure out when and make a
+			/* FIXME bugzilla.gnome.org 42537: Looks like this does happen with the
+			 * current OAF. I guess I read the code wrong. Need to figure out when and make a
 			 * good message.
 			 */
 			message = _("Nautilus can't be used now, due to an unexpected error.");
 			detailed_message = _("Nautilus can't be used now, due to an unexpected error "
-					     "from OAF when attempting to register the file manager view server.");
+					     "from Bonobo when attempting to register the file manager view server.");
 			break;
 		}
 
 		/* Get the shell object. */
 		if (message == NULL) {
-			shell = oaf_activate_from_id (SHELL_IID, 0, NULL, NULL);
+			shell = bonobo_activation_activate_from_id (SHELL_IID, 0, NULL, NULL);
 			if (!CORBA_Object_is_nil (shell, &ev)) {
 				break;
 			}
@@ -548,19 +523,19 @@ nautilus_application_startup (NautilusApplication *application,
 			/* If we couldn't find ourselves it's a bad problem so
 			 * we better stop looping.
 			 */
-			if (result == OAF_REG_SUCCESS) {
-				/* FIXME bugzilla.eazel.com 2538: When can this happen? */
+			if (result == Bonobo_ACTIVATION_REG_SUCCESS) {
+				/* FIXME bugzilla.gnome.org 42538: When can this happen? */
 				message = _("Nautilus can't be used now, due to an unexpected error.");
 				detailed_message = _("Nautilus can't be used now, due to an unexpected error "
-						     "from OAF when attempting to locate the factory."
-						     "Killing oafd and restarting Nautilus may help fix the problem.");
+						     "from Bonobo when attempting to locate the factory."
+						     "Killing bonobo-activation-server and restarting Nautilus may help fix the problem.");
 			} else {
 				num_failures++;
 				if (num_failures > 20) {
 					message = _("Nautilus can't be used now, due to an unexpected error.");
 					detailed_message = _("Nautilus can't be used now, due to an unexpected error "
-							     "from OAF when attempting to locate the shell object. "
-							     "Killing oafd and restarting Nautilus may help fix the problem.");
+							     "from Bonobo when attempting to locate the shell object. "
+							     "Killing bonobo-activation-server and restarting Nautilus may help fix the problem.");
 					
 				}
 			}
@@ -579,22 +554,27 @@ nautilus_application_startup (NautilusApplication *application,
 	} else if (restart_shell) {
 		Nautilus_Shell_restart (shell, &ev);
 	} else {
+		/* If KDE desktop is running, then force no_desktop */
+		if (is_kdesktop_present ()) {
+			no_desktop = TRUE;
+		}
+		
 		if (!no_desktop && eel_preferences_get_boolean (NAUTILUS_PREFERENCES_SHOW_DESKTOP)) {
 			Nautilus_Shell_start_desktop (shell, &ev);
 		}
 		
 		/* Monitor the preference to show or hide the desktop */
 		eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_SHOW_DESKTOP,
-							       desktop_changed_callback,
-							       application,
-							       GTK_OBJECT (application));
+							  desktop_changed_callback,
+							  application,
+							  G_OBJECT (application));
 
 		/* Monitor the preference to have the desktop */
 		/* point to the Unix home folder */
 		eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR,
-							       desktop_location_changed_callback,
-							       NULL,
-							       GTK_OBJECT (application));
+							  desktop_location_changed_callback,
+							  NULL,
+							  G_OBJECT (application));
 
 		/* CORBA C mapping doesn't allow NULL to be passed
 		   for string parameters */
@@ -689,15 +669,15 @@ nautilus_application_create_window (NautilusApplication *application)
 	g_return_val_if_fail (NAUTILUS_IS_APPLICATION (application), NULL);
 	
 	window = NAUTILUS_WINDOW (gtk_widget_new (nautilus_window_get_type (),
-						  "app", GTK_OBJECT (application),
+						  "app", G_OBJECT (application),
 						  "app_id", "nautilus", NULL));
 	
-	gtk_signal_connect (GTK_OBJECT (window), 
-			    "delete_event", GTK_SIGNAL_FUNC (nautilus_window_delete_event_callback),
+	g_signal_connect (window, 
+			    "delete_event", G_CALLBACK (nautilus_window_delete_event_callback),
                     	    NULL);
 
-	gtk_signal_connect (GTK_OBJECT (window),
-			    "destroy", nautilus_application_destroyed_window,
+	g_signal_connect (window,
+			    "destroy", G_CALLBACK (nautilus_application_destroyed_window),
 			    application);
 
 	nautilus_application_window_list = g_list_prepend (nautilus_application_window_list, window);
@@ -710,36 +690,6 @@ nautilus_application_create_window (NautilusApplication *application)
 	return window;
 }
 
-/*
- * confirm_ok_to_run_as_root:
- *
- * Puts out a warning if the user is running nautilus as root.
- */
-static gboolean
-confirm_ok_to_run_as_root (void)
-{
-	GtkWidget *dialog;
-	int result;
-
-	if (geteuid () != 0) {
-		return TRUE;
-	}
-
-	if (g_getenv ("NAUTILUS_OK_TO_RUN_AS_ROOT") != NULL) {
-		return TRUE;
-	}
-
-	dialog = gnome_message_box_new
-		(_("You are about to run Nautilus as root.\n\n"
-		   "As root, you can damage your system if you are not careful, and\n"
-		   "Nautilus will not stop you from doing it."),
-		 GNOME_MESSAGE_BOX_WARNING,
-		 GNOME_STOCK_BUTTON_OK, _("Quit"), NULL);
-	result = gnome_dialog_run_and_close (GNOME_DIALOG (dialog));
-	
-	return result == 0;
-}
-
 /* callback for changing the directory the desktop points to */
 static void
 desktop_location_changed_callback (gpointer user_data)
@@ -826,10 +776,10 @@ volume_mounted_callback (NautilusVolumeMonitor *monitor, NautilusVolume *volume,
 	}
 	
 	/* Open a window to the CD if the user has set that preference. */
-	if (volume->device_type == NAUTILUS_DEVICE_CD_ROM_DRIVE
+	if (nautilus_volume_get_device_type (volume) == NAUTILUS_DEVICE_CDROM_DRIVE
 		&& gnome_config_get_bool ("/magicdev/Options/do_fileman_window=true")) {		
 		window = nautilus_application_create_window (application);
-		uri = gnome_vfs_get_uri_from_local_path (volume->mount_path);
+		uri = gnome_vfs_get_uri_from_local_path (nautilus_volume_get_mount_path (volume));
 		nautilus_window_go_to (window, uri);
 		g_free (uri);
 	}
@@ -886,7 +836,7 @@ volume_unmounted_callback (NautilusVolumeMonitor *monitor, NautilusVolume *volum
 		if (window != NULL && window_can_be_closed (window)) {
 			uri = nautilus_window_get_location (window);
 			path = gnome_vfs_get_local_path_from_uri (uri);
-			if (eel_str_has_prefix (path, volume->mount_path)) {
+			if (eel_str_has_prefix (path, nautilus_volume_get_mount_path (volume))) {
 				close_list = g_list_prepend (close_list, window);
 			}
 			g_free (path);
@@ -957,11 +907,11 @@ init_session (void)
 
 	client = gnome_master_client ();
 
-	gtk_signal_connect (GTK_OBJECT (client), "save_yourself",
+	g_signal_connect (client, "save_yourself",
 			    (GtkSignalFunc) save_session,
 			    NULL);
 	
-	gtk_signal_connect (GTK_OBJECT (client), "die",
+	g_signal_connect (client, "die",
 			    (GtkSignalFunc) removed_from_session,
 			    NULL);
 	
@@ -971,3 +921,136 @@ init_session (void)
 
 	update_session (client);
 }
+
+static gboolean
+get_self_typed_prop (Window      xwindow,
+                     Atom        atom,
+                     gulong     *val)
+{  
+	Atom type;
+	int format;
+	gulong nitems;
+	gulong bytes_after;
+	gulong *num;
+	int err;
+  
+	gdk_error_trap_push ();
+	type = None;
+	XGetWindowProperty (gdk_display,
+			    xwindow,
+			    atom,
+			    0, G_MAXLONG,
+			    False, atom, &type, &format, &nitems,
+			    &bytes_after, (guchar **)&num);  
+
+	err = gdk_error_trap_pop ();
+	if (err != Success) {
+		return FALSE;
+	}
+  
+	if (type != atom) {
+		return FALSE;
+	}
+
+	if (val)
+		*val = *num;
+  
+	XFree (num);
+
+	return TRUE;
+}
+
+static gboolean
+has_wm_state (Window xwindow)
+{
+	return get_self_typed_prop (xwindow,
+				    XInternAtom (gdk_display, "WM_STATE", False),
+				    NULL);
+}
+
+static gboolean
+look_for_kdesktop_recursive (Window xwindow)
+{
+  
+	Window ignored1, ignored2;
+	Window *children;
+	unsigned int n_children;
+	unsigned int i;
+	gboolean retval;
+  
+	/* If WM_STATE is set, this is a managed client, so look
+	 * for the class hint and end recursion. Otherwise,
+	 * this is probably just a WM frame, so keep recursing.
+	 */
+	if (has_wm_state (xwindow)) {      
+		XClassHint ch;
+      
+		gdk_error_trap_push ();
+		ch.res_name = NULL;
+		ch.res_class = NULL;
+      
+		XGetClassHint (gdk_display, xwindow, &ch);
+      
+		gdk_error_trap_pop ();
+      
+		if (ch.res_name)
+			XFree (ch.res_name);
+      
+		if (ch.res_class) {
+			if (strcmp (ch.res_class, "kdesktop") == 0) {
+				XFree (ch.res_class);
+				return TRUE;
+			}
+			else
+				XFree (ch.res_class);
+		}
+
+		return FALSE;
+	}
+  
+	retval = FALSE;
+  
+	gdk_error_trap_push ();
+  
+	XQueryTree (gdk_display,
+		    xwindow,
+		    &ignored1, &ignored2, &children, &n_children);
+
+	if (gdk_error_trap_pop ()) {
+		return FALSE;
+	}
+
+	i = 0;
+	while (i < n_children) {
+		if (look_for_kdesktop_recursive (children[i])) {
+			retval = TRUE;
+			break;
+		}
+      
+		++i;
+	}
+  
+	if (children)
+		XFree (children);
+
+	return retval;
+}
+
+static gboolean
+is_kdesktop_present (void)
+{
+	/* FIXME this is a pretty lame hack, should be replaced
+	 * eventually with e.g. a requirement that desktop managers
+	 * support a manager selection, ICCCM sec 2.8
+	 */
+
+	return look_for_kdesktop_recursive (GDK_ROOT_WINDOW ());
+}
+
+static void
+nautilus_application_class_init (NautilusApplicationClass *klass)
+{
+	BONOBO_OBJECT_CLASS (klass)->destroy = nautilus_application_destroy;
+	
+	BONOBO_GENERIC_FACTORY_CLASS (klass)->epv.createObject = create_object;
+}
