@@ -28,10 +28,10 @@
 #include <config.h>
 #include "nautilus-bookmarks-window.h"
 #include <libnautilus/nautilus-undo.h>
-#include <libnautilus-extensions/nautilus-global-preferences.h>
-#include <libnautilus-extensions/nautilus-gtk-extensions.h>
-#include <libnautilus-extensions/nautilus-icon-factory.h>
-#include <libnautilus-extensions/nautilus-undo-signal-handlers.h>
+#include <libnautilus-private/nautilus-global-preferences.h>
+#include <eel/eel-gtk-extensions.h>
+#include <libnautilus-private/nautilus-icon-factory.h>
+#include <libnautilus-private/nautilus-undo-signal-handlers.h>
 #include <gnome.h>
 
 
@@ -39,49 +39,54 @@
  * more than one bookmark-editing window, these would be struct or
  * class fields. 
  */
-static int		     bookmark_list_changed_signalID;
+static int		     bookmark_list_changed_signal_id;
 static NautilusBookmarkList *bookmarks = NULL;
-static GtkWidget	    *bookmark_list_widget = NULL; /* awkward name to distinguish from NautilusBookmarkList */
+static GtkTreeView	    *bookmark_list_widget = NULL; /* awkward name to distinguish from NautilusBookmarkList */
+static GtkListStore	    *bookmark_list_store = NULL;
+static GtkTreeSelection     *bookmark_selection = NULL;
+static int                   selection_changed_id = 0;
 static GtkWidget	    *name_field = NULL;
-static int		     name_field_changed_signalID;
+static int		     name_field_changed_signal_id;
 static GtkWidget	    *remove_button = NULL;
 static gboolean		     text_changed = FALSE;
 static GtkWidget	    *uri_field = NULL;
-static int		     uri_field_changed_signalID;
+static int		     uri_field_changed_signal_id;
+
 
 /* forward declarations */
-static NautilusBookmark *get_selected_bookmark (void);
-static guint	get_selected_row	      (void);
-static gboolean get_selection_exists 	      (void);
-static void     name_or_uri_field_activate    (NautilusEntry *entry);
-static void	nautilus_bookmarks_window_restore_geometry
-					      (GtkWidget *window);
-static void	on_bookmark_list_changed       (NautilusBookmarkList *, 
-					       gpointer user_data);
-static void	on_name_field_changed 	      (GtkEditable *, gpointer user_data);
-static void	on_remove_button_clicked      (GtkButton *, gpointer user_data);
-static void	on_row_move 		      (GtkCList *,
-	     				       int old_row,
-	     				       int new_row,
-	     				       gpointer user_data);
-static void	on_select_row 		      (GtkCList	*,
-	       				       int row,
-	       				       int column,
-	       				       GdkEventButton *,
-	       				       gpointer user_data);
-static gboolean	on_text_field_focus_out_event (GtkWidget *, 
-					       GdkEventFocus *, 
-					       gpointer user_data);
-static void	on_uri_field_changed 	      (GtkEditable *, gpointer user_data);
-static gboolean on_window_delete_event 	      (GtkWidget *, 
-					       GdkEvent *, 
-					       gpointer user_data);
-static void     on_window_hide_event 	      (GtkWidget *, 
-					       gpointer user_data);
-static void     on_window_destroy_event       (GtkWidget *, 
-					       gpointer user_data);
-static void	repopulate		      (void);
-static void	set_up_close_accelerator      (GtkWidget *window);
+static guint    get_selected_row                            (void);
+static gboolean get_selection_exists                        (void);
+static void     name_or_uri_field_activate                  (NautilusEntry        *entry);
+static void     nautilus_bookmarks_window_restore_geometry  (GtkWidget            *window);
+static void     on_bookmark_list_changed                    (NautilusBookmarkList *list,
+							     gpointer              user_data);
+static void     on_name_field_changed                       (GtkEditable          *editable,
+							     gpointer              user_data);
+static void     on_remove_button_clicked                    (GtkButton            *button,
+							     gpointer              user_data);
+#if GNOME2_CONVERSION_COMPLETE
+static void     on_row_move                                 (GtkCList             *clist,
+							     int                   old_row,
+							     int                   new_row,
+							     gpointer              user_data);
+#endif
+static void     on_selection_changed                        (GtkTreeSelection     *treeselection,
+							     gpointer              user_data);
+
+static gboolean on_text_field_focus_out_event               (GtkWidget            *widget,
+							     GdkEventFocus        *event,
+							     gpointer              user_data);
+static void     on_uri_field_changed                        (GtkEditable          *editable,
+							     gpointer              user_data);
+static gboolean on_window_delete_event                      (GtkWidget            *widget,
+							     GdkEvent             *event,
+							     gpointer              user_data);
+static void     on_window_hide_event                        (GtkWidget            *widget,
+							     gpointer              user_data);
+static void     on_window_destroy_event                     (GtkWidget            *widget,
+							     gpointer              user_data);
+static void     repopulate                                  (void);
+static void     set_up_close_accelerator                    (GtkWidget            *window);
 
 #define BOOKMARK_LIST_COLUMN_ICON		0
 #define BOOKMARK_LIST_COLUMN_NAME		1
@@ -97,6 +102,14 @@ static void	set_up_close_accelerator      (GtkWidget *window);
 #define BOOKMARKS_WINDOW_INITIAL_WIDTH	500
 #define BOOKMARKS_WINDOW_INITIAL_HEIGHT	200
 
+static void
+nautilus_bookmarks_window_response_callback (GtkDialog *dialog,
+					     int response_id,
+					     gpointer callback_data)
+{
+	gtk_widget_hide (GTK_WIDGET (dialog));
+}
+
 /**
  * create_bookmarks_window:
  * 
@@ -106,25 +119,28 @@ static void	set_up_close_accelerator      (GtkWidget *window);
  * Return value: A pointer to the new window.
  **/
 GtkWindow *
-create_bookmarks_window (NautilusBookmarkList *list, GtkObject *undo_manager_source)
+create_bookmarks_window (NautilusBookmarkList *list, GObject *undo_manager_source)
 {
-	GtkWidget *window;
-	GtkWidget *content_area;
-	GtkWidget *list_scroller;
-	GtkWidget *right_side;
-	GtkWidget *vbox3;
-	GtkWidget *name_label;
-	GtkWidget *vbox4;
-	GtkWidget *url_label;
-	GtkWidget *hbox2;
+	GtkWidget         *window;
+	GtkWidget         *content_area;
+	GtkWidget         *list_scroller;
+	GtkWidget         *right_side;
+	GtkWidget         *vbox3;
+	GtkWidget         *name_label;
+	GtkWidget         *vbox4;
+	GtkWidget         *url_label;
+	GtkWidget         *hbox2;
+	GtkTreeViewColumn *col;
+	GtkCellRenderer   *rend;
 
 	bookmarks = list;
 
-	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	window = gtk_dialog_new_with_buttons (_("Bookmarks"), NULL, 0,
+					      _("Done"), GTK_RESPONSE_OK,
+					      NULL);
+	
 	set_up_close_accelerator (window);
-	nautilus_undo_share_undo_manager (GTK_OBJECT (window), undo_manager_source);
-	gtk_container_set_border_width (GTK_CONTAINER (window), GNOME_PAD);
-	gtk_window_set_title (GTK_WINDOW (window), _("Bookmarks"));
+	nautilus_undo_share_undo_manager (G_OBJECT (window), undo_manager_source);
 	gtk_window_set_wmclass (GTK_WINDOW (window), "bookmarks", "Nautilus");
 	gtk_widget_set_usize (window, 
 			      BOOKMARKS_WINDOW_MIN_WIDTH, 
@@ -134,25 +150,54 @@ create_bookmarks_window (NautilusBookmarkList *list, GtkObject *undo_manager_sou
 	
 	content_area = gtk_hbox_new (TRUE, GNOME_PAD);
 	gtk_widget_show (content_area);
-	gtk_container_add (GTK_CONTAINER (window), content_area);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->vbox), content_area, FALSE, FALSE, 0);
 
 	list_scroller = gtk_scrolled_window_new (NULL, NULL);
 	gtk_widget_show (list_scroller);
 	gtk_box_pack_start (GTK_BOX (content_area), list_scroller, TRUE, TRUE, 0);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (list_scroller), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (list_scroller), GTK_SHADOW_IN);
+	gtk_container_set_border_width (GTK_CONTAINER (list_scroller), 7);
 
-	bookmark_list_widget = gtk_clist_new (BOOKMARK_LIST_COLUMN_COUNT);
-	gtk_widget_show (bookmark_list_widget);
-	gtk_container_add (GTK_CONTAINER (list_scroller), bookmark_list_widget);
-	gtk_clist_column_titles_hide (GTK_CLIST (bookmark_list_widget));
-	gtk_clist_set_column_width (GTK_CLIST (bookmark_list_widget),
-				    BOOKMARK_LIST_COLUMN_ICON,
-				    NAUTILUS_ICON_SIZE_SMALLER);
-	gtk_clist_set_row_height (GTK_CLIST (bookmark_list_widget),
-				  NAUTILUS_ICON_SIZE_SMALLER);
-	gtk_clist_set_reorderable(GTK_CLIST (bookmark_list_widget), TRUE);
-	gtk_clist_set_use_drag_icons(GTK_CLIST (bookmark_list_widget), FALSE);
-
+	bookmark_list_widget = GTK_TREE_VIEW (gtk_tree_view_new ());
+	gtk_widget_show (GTK_WIDGET (bookmark_list_widget));
+	gtk_container_add (GTK_CONTAINER (list_scroller), 
+			   GTK_WIDGET (bookmark_list_widget));
+	gtk_widget_set_size_request (GTK_WIDGET (bookmark_list_widget), -1, 120);
+	gtk_tree_view_set_headers_visible (bookmark_list_widget, FALSE);
+	gtk_tree_view_set_reorderable (bookmark_list_widget, TRUE);
+		
+	rend = gtk_cell_renderer_pixbuf_new ();
+	col = gtk_tree_view_column_new_with_attributes ("Icon", 
+							rend,
+							"pixbuf", 
+							BOOKMARK_LIST_COLUMN_ICON,
+							NULL);
+	gtk_tree_view_append_column (bookmark_list_widget,
+				     GTK_TREE_VIEW_COLUMN (col));
+	gtk_tree_view_column_set_fixed_width (GTK_TREE_VIEW_COLUMN (col),
+					      NAUTILUS_ICON_SIZE_SMALLER);
+	
+	rend = gtk_cell_renderer_text_new ();
+	col = gtk_tree_view_column_new ();
+	col = gtk_tree_view_column_new_with_attributes ("Icon", 
+							rend,
+							"text", 
+							BOOKMARK_LIST_COLUMN_NAME,
+							NULL);
+	gtk_tree_view_append_column (bookmark_list_widget,
+				     GTK_TREE_VIEW_COLUMN (col));
+	
+	bookmark_list_store = gtk_list_store_new (BOOKMARK_LIST_COLUMN_COUNT,
+						  GDK_TYPE_PIXBUF,
+						  G_TYPE_STRING,
+						  G_TYPE_INT);
+	gtk_tree_view_set_model (bookmark_list_widget,
+				 GTK_TREE_MODEL (bookmark_list_store));
+	
+	bookmark_selection =
+		GTK_TREE_SELECTION (gtk_tree_view_get_selection (bookmark_list_widget));
+	
 	right_side = gtk_vbox_new (FALSE, GNOME_PAD);
 	gtk_widget_show (right_side);
 	gtk_box_pack_start (GTK_BOX (content_area), right_side, TRUE, TRUE, 0);
@@ -187,77 +232,65 @@ create_bookmarks_window (NautilusBookmarkList *list, GtkObject *undo_manager_sou
 	gtk_widget_show (hbox2);
 	gtk_box_pack_start (GTK_BOX (right_side), hbox2, FALSE, FALSE, 0);
 
-	remove_button = gtk_button_new_with_label (_("Remove"));
-	nautilus_gtk_button_set_standard_padding (GTK_BUTTON (remove_button));
+	remove_button = gtk_button_new_with_mnemonic (_("_Remove"));
+
 	gtk_widget_show (remove_button);
 	gtk_box_pack_start (GTK_BOX (hbox2), remove_button, TRUE, FALSE, 0);
 
-	bookmark_list_changed_signalID =
-		gtk_signal_connect (GTK_OBJECT(bookmarks), "contents_changed",
-				    GTK_SIGNAL_FUNC(on_bookmark_list_changed),
-				    NULL);
-				    
-	gtk_signal_connect (GTK_OBJECT(bookmark_list_widget), "row_move",
-			    GTK_SIGNAL_FUNC(on_row_move),
-			    NULL);
-			    
-	gtk_signal_connect (GTK_OBJECT(bookmark_list_widget), "select_row",
-			    GTK_SIGNAL_FUNC(on_select_row),
-			    NULL);
+	bookmark_list_changed_signal_id =
+		g_signal_connect (bookmarks, "contents_changed",
+				  G_CALLBACK (on_bookmark_list_changed), NULL);
+#if GNOME2_CONVERSION_COMPLETE
+	g_signal_connect (bookmark_list_widget, "row_move",
+			  G_CALLBACK (on_row_move), NULL);
+#endif	
+	selection_changed_id =
+		g_signal_connect (bookmark_selection, "changed",
+				  G_CALLBACK (on_selection_changed), NULL);	
 
-	gtk_signal_connect (GTK_OBJECT (window), "delete_event",
-                    	    GTK_SIGNAL_FUNC (on_window_delete_event),
-                    	    NULL);
+	g_signal_connect (window, "delete_event",
+			  G_CALLBACK (on_window_delete_event), NULL);
                     	    
-	gtk_signal_connect (GTK_OBJECT (window), "hide",
-                    	    on_window_hide_event,
-                    	    NULL);
+	g_signal_connect (window, "hide",
+			  G_CALLBACK (on_window_hide_event), NULL);
                     	    
-	gtk_signal_connect (GTK_OBJECT (window), "destroy",
-                    	    on_window_destroy_event,
-                    	    NULL);
+	g_signal_connect (window, "destroy",
+			  G_CALLBACK (on_window_destroy_event), NULL);
                     	    
-	name_field_changed_signalID =
-		gtk_signal_connect (GTK_OBJECT (name_field), "changed",
-                	            GTK_SIGNAL_FUNC (on_name_field_changed),
-                      		    NULL);
+	g_signal_connect (window, "response",
+			  G_CALLBACK (nautilus_bookmarks_window_response_callback), NULL);
+
+	name_field_changed_signal_id =
+		g_signal_connect (name_field, "changed",
+				  G_CALLBACK (on_name_field_changed),
+				  NULL);
                       		    
-	gtk_signal_connect (GTK_OBJECT (name_field), "focus_out_event",
-      	              	    GTK_SIGNAL_FUNC (on_text_field_focus_out_event),
-                            NULL);
+	g_signal_connect (name_field, "focus_out_event",
+			  G_CALLBACK (on_text_field_focus_out_event), NULL);
                             
-	gtk_signal_connect (GTK_OBJECT (name_field), "activate",
-      	              	    GTK_SIGNAL_FUNC (name_or_uri_field_activate),
-                            NULL);
+	g_signal_connect (name_field, "activate",
+			  G_CALLBACK (name_or_uri_field_activate), NULL);
 
-	uri_field_changed_signalID = 
-		gtk_signal_connect (GTK_OBJECT (uri_field), "changed",
-                	    	    GTK_SIGNAL_FUNC (on_uri_field_changed),
-                      		    NULL);
+	uri_field_changed_signal_id = 
+		g_signal_connect (uri_field, "changed",
+				  G_CALLBACK (on_uri_field_changed), NULL);
                       		    
-	gtk_signal_connect (GTK_OBJECT (uri_field), "focus_out_event",
-        	            GTK_SIGNAL_FUNC (on_text_field_focus_out_event),
-              	    	    NULL);
+	g_signal_connect (uri_field, "focus_out_event",
+			  G_CALLBACK (on_text_field_focus_out_event), NULL);
               	    	    
-	gtk_signal_connect (GTK_OBJECT (uri_field), "activate",
-      	              	    GTK_SIGNAL_FUNC (name_or_uri_field_activate),
-                            NULL);
+	g_signal_connect (uri_field, "activate",
+			  G_CALLBACK (name_or_uri_field_activate), NULL);
 
-	gtk_signal_connect (GTK_OBJECT (remove_button), "clicked",
-        	            GTK_SIGNAL_FUNC (on_remove_button_clicked),
-                      	    NULL);
+	g_signal_connect (remove_button, "clicked",
+			  G_CALLBACK (on_remove_button_clicked), NULL);
 
 	/* Register to find out about icon theme changes */
-	gtk_signal_connect_object_while_alive (nautilus_icon_factory_get (),
-					       "icons_changed",
-					       repopulate,
-					       GTK_OBJECT (window));
+	gtk_signal_connect_object_while_alive (nautilus_icon_factory_get (), "icons_changed",
+					       repopulate, GTK_OBJECT (window));
                       	    
-
-	/* Set selection mode after connecting signal to notice initial selected row. */
-	gtk_clist_set_selection_mode(GTK_CLIST (bookmark_list_widget), 
+	gtk_tree_selection_set_mode (bookmark_selection,
 				     GTK_SELECTION_BROWSE);
-
+	
 	/* Fill in list widget with bookmarks, must be after signals are wired up. */
 	repopulate();
 
@@ -265,48 +298,35 @@ create_bookmarks_window (NautilusBookmarkList *list, GtkObject *undo_manager_sou
 }
 
 static NautilusBookmark *
-get_selected_bookmark ()
+get_selected_bookmark (void)
 {
 	g_return_val_if_fail(NAUTILUS_IS_BOOKMARK_LIST(bookmarks), NULL);
 
-	return nautilus_bookmark_list_item_at(bookmarks, get_selected_row());
+	return nautilus_bookmark_list_item_at(bookmarks, get_selected_row ());
 }
 
 static guint
-get_selected_row ()
+get_selected_row (void)
 {
-	g_assert(get_selection_exists());
-	return GPOINTER_TO_UINT(g_list_nth_data(
-		GTK_CLIST(bookmark_list_widget)->selection, 0));
+	GtkTreeIter       iter;
+	GtkTreePath      *path;
+	GtkTreeModel     *model;
+	
+	g_assert (get_selection_exists());
+	
+	model = GTK_TREE_MODEL (bookmark_list_store);
+	gtk_tree_selection_get_selected (bookmark_selection,
+					 &model,
+					 &iter);
+	
+	path = gtk_tree_model_get_path (model, &iter);
+	return atoi (gtk_tree_path_to_string (path));
 }
 
 static gboolean
-get_selection_exists ()
+get_selection_exists (void)
 {
-	g_assert (GTK_CLIST(bookmark_list_widget)->selection_mode 
-		== GTK_SELECTION_BROWSE);
-	return GTK_CLIST(bookmark_list_widget)->rows > 0;
-}
-
-static void
-install_bookmark_icon (NautilusBookmark *bookmark, int row)
-{
-	GdkPixmap *pixmap;
-	GdkBitmap *bitmap;
-
-	if (!nautilus_bookmark_get_pixmap_and_mask (bookmark,
-		  				    NAUTILUS_ICON_SIZE_SMALLER,
-						    &pixmap,
-						    &bitmap))
-	{
-		return;
-	}
-
-	gtk_clist_set_pixmap (GTK_CLIST (bookmark_list_widget),	
-			      row,
-			      BOOKMARK_LIST_COLUMN_ICON,
-			      pixmap,
-			      bitmap);
+	return gtk_tree_selection_get_selected (bookmark_selection, NULL, NULL);
 }
 
 static void
@@ -319,9 +339,8 @@ nautilus_bookmarks_window_restore_geometry (GtkWidget *window)
 
 	window_geometry = nautilus_bookmark_list_get_window_geometry (bookmarks);
 
-	if (window_geometry != NULL) 
-	{	
-		nautilus_gtk_window_set_initial_geometry_from_string 
+	if (window_geometry != NULL) {	
+		eel_gtk_window_set_initial_geometry_from_string 
 			(GTK_WINDOW (window), window_geometry, 
 			 BOOKMARKS_WINDOW_MIN_WIDTH, BOOKMARKS_WINDOW_MIN_HEIGHT);
 
@@ -351,7 +370,8 @@ nautilus_bookmarks_window_save_geometry (GtkWindow *window)
 	if (GTK_WIDGET_VISIBLE (window)) {
 		char *geometry_string;
 		
-		geometry_string = gnome_geometry_string (GTK_WIDGET (window)->window);	
+		geometry_string = eel_gtk_window_get_geometry_string (window);
+
 		nautilus_bookmark_list_set_window_geometry (bookmarks, geometry_string);
 		g_free (geometry_string);
 	}
@@ -370,16 +390,22 @@ static void
 on_name_field_changed (GtkEditable *editable,
 		       gpointer     user_data)
 {
-	g_return_if_fail(GTK_IS_CLIST(bookmark_list_widget));
+	GtkTreeIter   iter;
+	g_return_if_fail(GTK_IS_TREE_VIEW(bookmark_list_widget));
 	g_return_if_fail(GTK_IS_ENTRY(name_field));
 	g_return_if_fail(get_selection_exists());
 
 	/* Update text displayed in list instantly. Also remember that 
 	 * user has changed text so we update real bookmark later. 
 	 */
-	gtk_clist_set_text(GTK_CLIST(bookmark_list_widget), 
-			   get_selected_row(), BOOKMARK_LIST_COLUMN_NAME, 
-			   gtk_entry_get_text(GTK_ENTRY(name_field)));
+	gtk_tree_selection_get_selected (bookmark_selection,
+					 NULL,
+					 &iter);
+	
+	gtk_list_store_set (bookmark_list_store, 
+			    &iter, BOOKMARK_LIST_COLUMN_NAME, 
+			    gtk_entry_get_text (GTK_ENTRY (name_field)),
+			    -1);
 	text_changed = TRUE;
 }
 
@@ -388,19 +414,24 @@ static void
 on_remove_button_clicked (GtkButton *button,
                           gpointer   user_data)
 {
-	g_assert(GTK_IS_CLIST(bookmark_list_widget));
+	GtkTreeIter iter;
+	guint       selected_row;
+	guint       list_length;
+	gchar      *row_path;
+
+	g_assert (GTK_IS_TREE_VIEW (bookmark_list_widget));
+	
 
 	/* Turn off list updating since we're handling the list widget explicitly.
 	 * This allows the selection to move to the next row, instead of leaping
 	 * back to the top.
 	 */
 	gtk_signal_handler_block(GTK_OBJECT(bookmarks), 
-				 bookmark_list_changed_signalID);
+				 bookmark_list_changed_signal_id);
+	selected_row = get_selected_row ();
 	nautilus_bookmark_list_delete_item_at(bookmarks, get_selected_row());
 	gtk_signal_handler_unblock(GTK_OBJECT(bookmarks), 
-				   bookmark_list_changed_signalID);
-
-	gtk_clist_remove(GTK_CLIST(bookmark_list_widget), get_selected_row());
+				   bookmark_list_changed_signal_id);
 
 	/*
 	 * If removing the selected row selected the next row, then we'll
@@ -408,12 +439,40 @@ on_remove_button_clicked (GtkButton *button,
 	 * callback, which will leave the Remove button and text fields
 	 * in the wrong state unless we fix them explicitly here.
 	 */
-	if (nautilus_bookmark_list_length (bookmarks) == 0) {
+	list_length = nautilus_bookmark_list_length (bookmarks);
+	if (!list_length) {
 		repopulate ();
+		return;
 	}
+	gtk_tree_selection_get_selected (bookmark_selection,
+					 NULL,
+					 &iter);
+
+	/* Block signals, so our on_selection_changed won't be called */
+	g_signal_handler_block (bookmark_selection,
+				selection_changed_id);
+	
+	gtk_list_store_remove (bookmark_list_store, &iter);
+
+	g_signal_handler_unblock (bookmark_selection,
+				  selection_changed_id);
+
+	/* If the last item was just removed,
+	 * we need to select the previous one
+	 */
+	if (selected_row >= list_length) {
+		row_path = g_strdup_printf ("%d", selected_row-1);
+		gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (bookmark_list_store),
+						     &iter,
+						     row_path);
+		g_free (row_path);
+	}
+	
+	gtk_tree_selection_select_iter (bookmark_selection, &iter);
+	
 }
 
-
+#if GNOME2_CONVERSION_COMPLETE
 static void
 on_row_move (GtkCList *clist,
 	     int      old_row,
@@ -422,6 +481,7 @@ on_row_move (GtkCList *clist,
 {
 	NautilusBookmark *bookmark;
 
+	puts (__FUNCTION__);
 	bookmark = nautilus_bookmark_copy(
 		nautilus_bookmark_list_item_at(bookmarks, old_row));
 
@@ -429,25 +489,23 @@ on_row_move (GtkCList *clist,
 	 * after repopulate(), thus reordering the correctly-ordered list.
 	 */
 	gtk_signal_handler_block(GTK_OBJECT(bookmarks), 
-				 bookmark_list_changed_signalID);
+				 bookmark_list_changed_signal_id);
 	nautilus_bookmark_list_delete_item_at(bookmarks, old_row);
 	nautilus_bookmark_list_insert_item(bookmarks, bookmark, new_row);
 	gtk_signal_handler_unblock(GTK_OBJECT(bookmarks), 
-				   bookmark_list_changed_signalID);
+				   bookmark_list_changed_signal_id);
 
-	gtk_object_unref(GTK_OBJECT(bookmark));
+	g_object_unref (bookmark);
 }
+#endif
 
 static void
-on_select_row (GtkCList	       *clist,
-	       int		row,
-	       int	 	column,
-	       GdkEventButton  *event,
-	       gpointer		user_data)
+on_selection_changed (GtkTreeSelection *treeselection,
+		      gpointer user_data)
 {
 	NautilusBookmark *selected;
 	char *name, *uri;
-
+	
 	g_assert (GTK_IS_ENTRY (name_field));
 	g_assert (GTK_IS_ENTRY (uri_field));
 
@@ -464,7 +522,7 @@ on_select_row (GtkCList	       *clist,
 
 
 static void
-update_bookmark_from_text ()
+update_bookmark_from_text (void)
 {
 	if (text_changed) {
 		NautilusBookmark *bookmark;
@@ -482,13 +540,13 @@ update_bookmark_from_text ()
 		 * after repopulate(), thus reordering the correctly-ordered list.
 		 */
 		gtk_signal_handler_block (GTK_OBJECT (bookmarks), 
-					  bookmark_list_changed_signalID);
+					  bookmark_list_changed_signal_id);
 		nautilus_bookmark_list_delete_item_at (bookmarks, selected_row);
 		nautilus_bookmark_list_insert_item (bookmarks, bookmark, selected_row);
 		gtk_signal_handler_unblock (GTK_OBJECT (bookmarks), 
-					    bookmark_list_changed_signalID);
+					    bookmark_list_changed_signal_id);
 
-		gtk_object_unref (GTK_OBJECT (bookmark));
+		g_object_unref (bookmark);
 	}
 }
 
@@ -522,22 +580,12 @@ on_uri_field_changed (GtkEditable *editable,
 	text_changed = TRUE;
 }
 
-static void
-save_geometry_and_hide (GtkWindow *window)
-{
-	g_assert (GTK_IS_WINDOW (window));
-
-	nautilus_bookmarks_window_save_geometry (window);
-	gtk_widget_hide (GTK_WIDGET (window));
-}
-
-
 static gboolean
 on_window_delete_event (GtkWidget *widget,
 			GdkEvent *event,
 			gpointer user_data)
 {
-	save_geometry_and_hide (GTK_WINDOW (widget));
+	gtk_widget_hide (widget);
 	return TRUE;
 }
 
@@ -559,8 +607,8 @@ on_window_hide_event (GtkWidget *widget,
 	nautilus_bookmarks_window_save_geometry (GTK_WINDOW (widget));
 
 	/* Disable undo for entry widgets */
-	nautilus_undo_unregister (GTK_OBJECT (name_field));
-	nautilus_undo_unregister (GTK_OBJECT (uri_field));
+	nautilus_undo_unregister (G_OBJECT (name_field));
+	nautilus_undo_unregister (G_OBJECT (uri_field));
 
 	/* restore_geometry only works after window is hidden */
 	gtk_idle_add (restore_geometry, widget);
@@ -577,60 +625,75 @@ on_window_destroy_event (GtkWidget *widget,
 static void
 repopulate (void)
 {
-	GtkCList *clist;
-	guint index;
-	gboolean selection_exists;
-
-	g_assert (GTK_IS_CLIST (bookmark_list_widget));
+	GtkListStore *store;
+	guint         index;
+	GtkTreeIter   iter;
+	gboolean      selection_exists;
+	
+	g_assert (GTK_IS_TREE_VIEW (bookmark_list_widget));
 	g_assert (NAUTILUS_IS_BOOKMARK_LIST (bookmarks));
 	
-	clist = GTK_CLIST (bookmark_list_widget);
+	store = GTK_LIST_STORE (bookmark_list_store);
 
-	/* Freeze while mucking with content so it's not flashy */
-	gtk_clist_freeze (clist);
-	    
-	/* Empty the list. */
-	gtk_clist_clear (clist);
-	   
+	g_signal_handler_block (bookmark_selection,
+				selection_changed_id);
+	
+	gtk_list_store_clear (store);
+	
+	g_signal_handler_unblock (bookmark_selection,
+				  selection_changed_id);
+	
 	/* Fill the list in with the bookmark names. */
 	for (index = 0; index < nautilus_bookmark_list_length(bookmarks); ++index) {
-		char *text[BOOKMARK_LIST_COLUMN_COUNT];
-		char *bookmark_name;
 		NautilusBookmark *bookmark;
-		int new_row;
+		char             *bookmark_name;
+		GdkPixbuf        *bookmark_pixbuf;
+		GtkTreeIter       iter;
 
-		bookmark = nautilus_bookmark_list_item_at(bookmarks, index);
+		bookmark = nautilus_bookmark_list_item_at (bookmarks, index);
 		bookmark_name = nautilus_bookmark_get_name (bookmark);
-		text[BOOKMARK_LIST_COLUMN_ICON] = NULL;
-		text[BOOKMARK_LIST_COLUMN_NAME] = bookmark_name;
-		new_row = gtk_clist_append (clist, text);
-		g_free (bookmark_name);
+		bookmark_pixbuf = nautilus_bookmark_get_pixbuf (bookmark,
+								NAUTILUS_ICON_SIZE_SMALLER,
+								TRUE);
 		
-		install_bookmark_icon (bookmark, new_row);
+		gtk_list_store_append (store, &iter);
+		gtk_list_store_set (store, &iter, 
+				    BOOKMARK_LIST_COLUMN_ICON, bookmark_pixbuf,
+				    BOOKMARK_LIST_COLUMN_NAME, bookmark_name,
+				    -1);
+		
+		g_free (bookmark_name);
+		g_object_unref (bookmark_pixbuf);
+		
+	}
+
+	/* Select the first row on start-up */
+	if (index) {
+		gtk_tree_model_get_iter_root (GTK_TREE_MODEL (bookmark_list_store), &iter);
+		gtk_tree_selection_select_iter (bookmark_selection, &iter);
 	}
 	
 	/* Set the sensitivity of widgets that require a selection */
-	selection_exists = get_selection_exists();
+	selection_exists = get_selection_exists ();
 	gtk_widget_set_sensitive (remove_button, selection_exists);
 	gtk_widget_set_sensitive (name_field, selection_exists);
 	gtk_widget_set_sensitive (uri_field, selection_exists);
 	    
 	if (!selection_exists) {
-		/* Block signals to avoid modifying non-existent selected item. */
+		/* Block signals to avoid modifying nonexistent selected item. */
 		gtk_signal_handler_block (GTK_OBJECT (name_field), 
-					  name_field_changed_signalID);
+					  name_field_changed_signal_id);
 		nautilus_entry_set_text (NAUTILUS_ENTRY (name_field), "");
 		gtk_signal_handler_unblock (GTK_OBJECT (name_field), 
-					    name_field_changed_signalID);
+					    name_field_changed_signal_id);
 
 		gtk_signal_handler_block (GTK_OBJECT (uri_field), 
-					  uri_field_changed_signalID);
+					  uri_field_changed_signal_id);
 		nautilus_entry_set_text (NAUTILUS_ENTRY (uri_field), "");
 		gtk_signal_handler_unblock (GTK_OBJECT (uri_field), 
-					    uri_field_changed_signalID);
+					    uri_field_changed_signal_id);
 	}
 	  
-	gtk_clist_thaw (GTK_CLIST (bookmark_list_widget));
 }
 
 static int
@@ -642,10 +705,8 @@ handle_close_accelerator (GtkWindow *window,
 	g_assert (event != NULL);
 	g_assert (user_data == NULL);
 
-	if (nautilus_gtk_window_event_is_close_accelerator (window, event)) {		
-		save_geometry_and_hide (window);
-		gtk_signal_emit_stop_by_name 
-			(GTK_OBJECT (window), "key_press_event");
+	if (eel_gtk_window_event_is_close_accelerator (window, event)) {		
+		gtk_widget_hide (GTK_WIDGET (window));
 		return TRUE;
 	}
 
@@ -655,12 +716,10 @@ handle_close_accelerator (GtkWindow *window,
 static void
 set_up_close_accelerator (GtkWidget *window)
 {
-	/* Note that we don't call nautilus_gtk_window_set_up_close_accelerator
+	/* Note that we don't call eel_gtk_window_set_up_close_accelerator
 	 * here because we have to handle saving geometry before hiding the
 	 * window.
 	 */
-	gtk_signal_connect (GTK_OBJECT (window),
-			    "key_press_event",
-			    GTK_SIGNAL_FUNC (handle_close_accelerator),
-			    NULL);
+	g_signal_connect (window, "key_press_event",
+			  G_CALLBACK (handle_close_accelerator), NULL);
 }
