@@ -34,9 +34,7 @@
 #include <gtk/gtkeventbox.h>
 #include <gtk/gtksignal.h>
 #include <gtk/gtkvbox.h>
-#include <libgnome/gnome-defs.h>
 #include <libgnome/gnome-i18n.h>
-#include <libgnomeui/gnome-dock.h>
 #include <libgnomeui/gnome-uidefs.h>
 #include <libnautilus-private/nautilus-directory.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
@@ -46,27 +44,27 @@ static void		     real_activate				     (NautilusNavigationBar	       *bar);
 static void                  nautilus_switchable_search_bar_set_location     (NautilusNavigationBar            *bar,
 									      const char                       *location);
 static char *                nautilus_switchable_search_bar_get_location     (NautilusNavigationBar            *bar);
-static void                  nautilus_switchable_search_bar_initialize_class (NautilusSwitchableSearchBarClass *class);
-static void                  nautilus_switchable_search_bar_initialize       (NautilusSwitchableSearchBar      *bar);
-static void  		     nautilus_switchable_search_bar_destroy          (GtkObject                	       *object);
+static void                  nautilus_switchable_search_bar_class_init (NautilusSwitchableSearchBarClass *class);
+static void                  nautilus_switchable_search_bar_init       (NautilusSwitchableSearchBar      *bar);
+static void  		     nautilus_switchable_search_bar_finalize          (GObject                	       *object);
 
 static NautilusSearchBarMode other_search_mode                               (NautilusSearchBarMode            mode);
 static NautilusSearchBarMode nautilus_search_uri_to_search_bar_mode          (const char *uri);
 static gboolean              nautilus_search_uri_is_displayable_by_mode      (const char *uri,
 									      NautilusSearchBarMode mode);
 
-EEL_DEFINE_CLASS_BOILERPLATE (NautilusSwitchableSearchBar,
+EEL_CLASS_BOILERPLATE (NautilusSwitchableSearchBar,
 				   nautilus_switchable_search_bar,
 				   NAUTILUS_TYPE_SEARCH_BAR)
 
 static void
-nautilus_switchable_search_bar_initialize_class (NautilusSwitchableSearchBarClass *klass)
+nautilus_switchable_search_bar_class_init (NautilusSwitchableSearchBarClass *klass)
 {
 	NAUTILUS_NAVIGATION_BAR_CLASS (klass)->activate = real_activate;
 	NAUTILUS_NAVIGATION_BAR_CLASS (klass)->get_location = nautilus_switchable_search_bar_get_location;
 	NAUTILUS_NAVIGATION_BAR_CLASS (klass)->set_location = nautilus_switchable_search_bar_set_location;
 
-	GTK_OBJECT_CLASS (klass)->destroy = nautilus_switchable_search_bar_destroy;
+	G_OBJECT_CLASS (klass)->finalize = nautilus_switchable_search_bar_finalize;
 }
 
 static void
@@ -90,14 +88,14 @@ search_bar_preference_changed_callback (gpointer user_data)
 }
 
 static void
-nautilus_switchable_search_bar_initialize (NautilusSwitchableSearchBar *bar)
+nautilus_switchable_search_bar_init (NautilusSwitchableSearchBar *bar)
 {
 
 }	
 
 
 static void
-nautilus_switchable_search_bar_destroy (GtkObject *object)
+nautilus_switchable_search_bar_finalize (GObject *object)
 {
 	NautilusSwitchableSearchBar *bar;
 
@@ -107,7 +105,7 @@ nautilus_switchable_search_bar_destroy (GtkObject *object)
 					      search_bar_preference_changed_callback,
 					      bar);
 
-	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
 GtkWidget *
@@ -136,11 +134,11 @@ nautilus_switchable_search_bar_new (NautilusWindow *window)
 
 	gtk_signal_connect_object (GTK_OBJECT (bar->complex_search_bar),
 				   "location_changed",
-				   nautilus_navigation_bar_location_changed,
+				   G_CALLBACK (nautilus_navigation_bar_location_changed),
 				   GTK_OBJECT (bar));
 	gtk_signal_connect_object (GTK_OBJECT (bar->simple_search_bar),
 				   "location_changed",
-				   nautilus_navigation_bar_location_changed,
+				   G_CALLBACK (nautilus_navigation_bar_location_changed),
 				   GTK_OBJECT (bar));
 
 	
@@ -193,7 +191,9 @@ nautilus_switchable_search_bar_set_mode (NautilusSwitchableSearchBar *bar,
 					 NautilusSearchBarMode mode)
 {
 	char *location;
+#if GNOME2_CONVERSION_COMPLETE
 	GtkWidget *dock;
+#endif
 
 	g_return_if_fail (NAUTILUS_IS_SWITCHABLE_SEARCH_BAR (bar));
 	g_return_if_fail (mode == NAUTILUS_SIMPLE_SEARCH_BAR
@@ -223,6 +223,7 @@ nautilus_switchable_search_bar_set_mode (NautilusSwitchableSearchBar *bar,
 		break;
 	}
 
+#if GNOME2_CONVERSION_COMPLETE
 	/* FIXME bugzilla.gnome.org 43171:
 	 * We don't know why this line is needed here, but if it's removed
 	 * then the bar won't shrink when we switch to the simple search bar
@@ -232,6 +233,7 @@ nautilus_switchable_search_bar_set_mode (NautilusSwitchableSearchBar *bar,
 	if (dock != NULL) {
 		gtk_widget_queue_resize (dock);
 	}
+#endif
 }
 
 static char *
