@@ -42,7 +42,6 @@
 #include <gtk/gtkmain.h>
 #include <gtk/gtksignal.h>
 #include <gtk/gtkwindow.h>
-#include <libgnome/gnome-defs.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnome/gnome-util.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
@@ -76,9 +75,9 @@ typedef enum
 static guint theme_selector_signals[LAST_SIGNAL];
 
 /* GtkObjectClass methods */
-static void     nautilus_theme_selector_initialize_class              (NautilusThemeSelectorClass  *theme_selector_class);
-static void     nautilus_theme_selector_initialize                    (NautilusThemeSelector       *theme_selector);
-static void     theme_selector_destroy                                (GtkObject                   *object);
+static void     nautilus_theme_selector_class_init              (NautilusThemeSelectorClass  *theme_selector_class);
+static void     nautilus_theme_selector_init                    (NautilusThemeSelector       *theme_selector);
+static void     theme_selector_finalize                               (GObject                     *object);
 
 /* Private stuff */
 static void     theme_selector_populate_list                          (EelImageChooser             *image_chooser,
@@ -100,29 +99,28 @@ static void     theme_selector_update_selected_theme_from_preferences (NautilusT
 static void     theme_selector_update_help_label                      (NautilusThemeSelector       *theme_selector,
 								       gboolean                     removing);
 	
-EEL_DEFINE_CLASS_BOILERPLATE (NautilusThemeSelector, nautilus_theme_selector, GTK_TYPE_VBOX)
+EEL_CLASS_BOILERPLATE (NautilusThemeSelector, nautilus_theme_selector, GTK_TYPE_VBOX)
 
 /* NautilusThemeSelectorClass methods */
 static void
-nautilus_theme_selector_initialize_class (NautilusThemeSelectorClass *theme_selector_class)
+nautilus_theme_selector_class_init (NautilusThemeSelectorClass *theme_selector_class)
 {
-	GtkObjectClass *object_class;
+	GObjectClass *object_class;
 
-	object_class = GTK_OBJECT_CLASS (theme_selector_class);
+	object_class = G_OBJECT_CLASS (theme_selector_class);
 
-	/* GtkObjectClass */
-	object_class->destroy = theme_selector_destroy;
+	/* GObjectClass */
+	object_class->finalize = theme_selector_finalize;
 
 	/* Signals */
-	theme_selector_signals[THEME_CHANGED] = gtk_signal_new ("theme_changed",
-							       GTK_RUN_LAST,
-							       object_class->type,
-							       0,
-							       gtk_marshal_NONE__STRING,
-							       GTK_TYPE_NONE, 
-							       0);
-	
-	gtk_object_class_add_signals (object_class, theme_selector_signals, LAST_SIGNAL);
+	theme_selector_signals[THEME_CHANGED] = g_signal_new
+		("theme_changed",
+		 G_TYPE_FROM_CLASS (object_class),
+		 G_SIGNAL_RUN_LAST,
+		 0,
+		 NULL, NULL,
+		 g_cclosure_marshal_VOID__STRING,
+		 G_TYPE_NONE, 1, G_TYPE_STRING);
 }
 
 static void
@@ -147,7 +145,7 @@ make_widgets_same_size (GtkWidget *one, GtkWidget *two)
 }
 
 static void
-nautilus_theme_selector_initialize (NautilusThemeSelector *theme_selector)
+nautilus_theme_selector_init (NautilusThemeSelector *theme_selector)
 {
 	GtkWidget *button_box;
 	GtkWidget *alignment_box;
@@ -179,21 +177,21 @@ nautilus_theme_selector_initialize (NautilusThemeSelector *theme_selector)
 	gtk_box_pack_end (GTK_BOX (alignment_box), button_box, FALSE, FALSE, 2);
 
 	theme_selector->details->install_theme_button = gtk_button_new_with_label (_("Add New Theme..."));
-	gtk_signal_connect (GTK_OBJECT (theme_selector->details->install_theme_button),
+	g_signal_connect (theme_selector->details->install_theme_button,
 			    "clicked",
-			    GTK_SIGNAL_FUNC (install_theme_button_clicked_callback),
+			    G_CALLBACK (install_theme_button_clicked_callback),
 			    theme_selector);
 
 	theme_selector->details->remove_theme_button = gtk_button_new_with_label (_("Remove Theme..."));
-	gtk_signal_connect (GTK_OBJECT (theme_selector->details->remove_theme_button),
+	g_signal_connect (theme_selector->details->remove_theme_button,
 			    "clicked",
-			    GTK_SIGNAL_FUNC (remove_theme_button_clicked_callback),
+			    G_CALLBACK (remove_theme_button_clicked_callback),
 			    theme_selector);
 
 	theme_selector->details->cancel_remove_button = gtk_button_new_with_label (_("Cancel Remove"));
-	gtk_signal_connect (GTK_OBJECT (theme_selector->details->cancel_remove_button),
+	g_signal_connect (theme_selector->details->cancel_remove_button,
 			    "clicked",
-			    GTK_SIGNAL_FUNC (cancel_remove_button_clicked_callback),
+			    G_CALLBACK (cancel_remove_button_clicked_callback),
 			    theme_selector);
 
 	gtk_box_pack_start (GTK_BOX (button_box), theme_selector->details->cancel_remove_button, TRUE, FALSE, 0);
@@ -222,15 +220,15 @@ nautilus_theme_selector_initialize (NautilusThemeSelector *theme_selector)
 
 	theme_selector_update_remove_theme_button (theme_selector);
 
-	gtk_signal_connect (GTK_OBJECT (theme_selector->details->theme_selector),
+	g_signal_connect (theme_selector->details->theme_selector,
 			    "selection_changed",
-			    GTK_SIGNAL_FUNC (theme_selector_changed_callback),
+			    G_CALLBACK (theme_selector_changed_callback),
 			    theme_selector);
 
 	theme_selector->details->theme_selector_changed_connection =
-		gtk_signal_connect (GTK_OBJECT (theme_selector->details->remove_theme_selector),
+		g_signal_connect (theme_selector->details->remove_theme_selector,
 				    "selection_changed",
-				    GTK_SIGNAL_FUNC (remove_theme_selector_changed_callback),
+				    G_CALLBACK (remove_theme_selector_changed_callback),
 				    theme_selector);
 }
 
@@ -261,10 +259,10 @@ file_selection_ok_clicked_callback (GtkWidget *button,
 	g_return_if_fail (GTK_IS_BUTTON (button));
 	g_return_if_fail (GTK_IS_FILE_SELECTION (callback_data));
 
-	g_return_if_fail (NAUTILUS_IS_THEME_SELECTOR (gtk_object_get_data (GTK_OBJECT (callback_data),
+	g_return_if_fail (NAUTILUS_IS_THEME_SELECTOR (g_object_get_data (G_OBJECT (callback_data),
 									   THEME_SELECTOR_DATA_KEY)));
 
-	theme_selector = NAUTILUS_THEME_SELECTOR (gtk_object_get_data (GTK_OBJECT (callback_data),
+	theme_selector = NAUTILUS_THEME_SELECTOR (g_object_get_data (G_OBJECT (callback_data),
 								       THEME_SELECTOR_DATA_KEY));
 	
 	selected_path = gtk_file_selection_get_filename (GTK_FILE_SELECTION (callback_data));
@@ -333,19 +331,19 @@ install_theme_button_clicked_callback (GtkWidget *button,
 
 	eel_gtk_window_set_up_close_accelerator (GTK_WINDOW (file_selection_dialog));
 
-	gtk_object_set_data (GTK_OBJECT (file_selection_dialog),
-			     THEME_SELECTOR_DATA_KEY,
-			     callback_data);
-
-	gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (file_selection_dialog)->ok_button),
-			    "clicked",
-			    GTK_SIGNAL_FUNC (file_selection_ok_clicked_callback),
-			    file_selection_dialog);
-
-	gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (file_selection_dialog)->cancel_button),
-			    "clicked",
-			    GTK_SIGNAL_FUNC (file_selection_cancel_clicked_callback),
-			    file_selection_dialog);
+	g_object_set_data (G_OBJECT (file_selection_dialog),
+			   THEME_SELECTOR_DATA_KEY,
+			   callback_data);
+	
+	g_signal_connect (GTK_FILE_SELECTION (file_selection_dialog)->ok_button,
+			  "clicked",
+			  G_CALLBACK (file_selection_ok_clicked_callback),
+			  file_selection_dialog);
+	
+	g_signal_connect (GTK_FILE_SELECTION (file_selection_dialog)->cancel_button,
+			  "clicked",
+			  G_CALLBACK (file_selection_cancel_clicked_callback),
+			  file_selection_dialog);
 
 	gtk_window_set_position (GTK_WINDOW (file_selection_dialog), GTK_WIN_POS_MOUSE);
 	if (theme_selector->details->parent_window != NULL) {
@@ -515,13 +513,13 @@ theme_selector_changed_callback (EelImageChooser *image_chooser,
 	
 	selected_row_position = eel_image_chooser_get_selected_row (image_chooser);
 	
-	gtk_signal_emit (GTK_OBJECT (callback_data),
-			 theme_selector_signals[THEME_CHANGED]);
+	g_signal_emit (callback_data,
+		       theme_selector_signals[THEME_CHANGED], 0);
 }
 
 /* GtkObjectClass methods */
 static void
-theme_selector_destroy (GtkObject *object)
+theme_selector_finalize (GObject *object)
 {
 	NautilusThemeSelector *theme_selector;
 	
@@ -532,8 +530,8 @@ theme_selector_destroy (GtkObject *object)
 
 	g_free (theme_selector->details);
 
-	/* Chain destroy */
-	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	/* Chain finalize */
+	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
 /* Private stuff */
